/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <string.h>
#include <assert.h>

#ifdef _MSC_VER
#define CDECL __cdecl
#else
#define CDECL
#endif

/************ Begin %include sections from the grammar ************************/
#line 40 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"

// Allocates a new AST node off the parse state's arena.
#define NEW_AST_NODE(type,name,tok) \
	ZCC_##type *name = static_cast<ZCC_##type *>(stat->InitNode(sizeof(ZCC_##type), AST_##type)); \
	SetNodeLine(name, tok)

static void SetNodeLine(ZCC_TreeNode *name, ZCCToken &tok)
{
	name->SourceLoc = tok.SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, ZCC_TreeNode *node)
{
	if (name == nullptr || node == nullptr)
	{
		I_Error("Fatal parse error");
	}
	name->SourceLoc = node->SourceLoc;
}

static void SetNodeLine(ZCC_TreeNode *name, int line)
{
	name->SourceLoc = line;
}

// If a is non-null, appends b to a. Otherwise, sets a to b.
#define SAFE_APPEND(a,b) \
	if (a == NULL) a = b; else AppendTreeNodeSibling(a, b);

#define UNARY_EXPR(X,T) NEW_AST_NODE(ExprUnary, expr1, X); expr1->Operation = T; expr1->Operand = X; expr1->Type = NULL
#define BINARY_EXPR(X,Y,T) NEW_AST_NODE(ExprBinary, expr2, X); expr2->Operation = T; expr2->Type = NULL; expr2->Left = X; expr2->Right = Y

#define NEW_INTCONST_NODE(name,type,val,tok) \
	NEW_AST_NODE(ExprConstant, name, tok); \
	name->Operation = PEX_ConstValue; \
	name->Type = type; \
	name->IntVal = val

	struct ClassFlagsBlock {
		VM_UWORD Flags;
		ZCC_Identifier *Replaces;
		VersionInfo Version;
	};

	struct StateOpts {
		ZCC_Expression *Offset;
		ZCC_ExprConstant *Lights;
		bool Bright;
		bool Fast;
		bool Slow;
		bool NoDelay;
		bool CanRaise;

		void Zero() {
			Offset = nullptr;
			Lights = nullptr;
			Bright = false;
			Fast = false;
			Slow = false;
			NoDelay = false;
			CanRaise = false;
		}
	};

	struct VarOrFun
	{
		ZCC_VarName *VarNames;
		ZCC_FuncParamDecl *FuncParams;
		ZCC_CompoundStmt *FuncBody;
		ENamedName FuncName;
		int FuncFlags;
		int SourceLoc;
	};
#line 111 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next section is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    ZCCParseTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is ZCCParseTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    ZCCParseARG_SDECL     A static variable declaration for the %extra_argument
**    ZCCParseARG_PDECL     A parameter declaration for the %extra_argument
**    ZCCParseARG_STORE     Code to store %extra_argument into yypParser
**    ZCCParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 269
#define YYACTIONTYPE unsigned short int
#define ZCCParseTOKENTYPE  ZCCToken 
typedef union {
  int yyinit;
  ZCCParseTOKENTYPE yy0;
  ZCC_Class * yy20;
  ZCC_Declarator * yy23;
  ZCC_FlagStmt * yy52;
  ZCC_CompoundStmt * yy55;
  ZCC_LocalVarStmt * yy66;
  ZCC_States * yy70;
  ClassFlagsBlock yy87;
  ZCC_Type * yy104;
  ZCC_StaticArrayStatement * yy106;
  ZCC_FuncParm * yy138;
  ZCC_FlagDef * yy155;
  ZCC_Statement * yy156;
  ZCC_Identifier * yy165;
  ZCC_Enum * yy179;
  ZCC_VarName * yy180;
  ZCC_AssignDeclStmt * yy251;
  ZCC_StatePart * yy266;
  ZCC_AssignStmt * yy271;
  ZCC_VarInit * yy275;
  ZCC_MixinDef * yy282;
  ZCC_DeclFlags * yy295;
  ZCC_TreeNode * yy296;
  ZCC_Struct * yy299;
  ZCC_ExpressionStmt * yy302;
  ZCC_BasicType * yy310;
  ZCC_PropertyStmt * yy315;
  ZCC_Expression * yy318;
  StateOpts yy332;
  ZCC_MixinStmt * yy399;
  ZCC_Default * yy431;
  VarOrFun yy432;
  ZCC_CaseStmt * yy442;
  ZCC_Property * yy443;
  ZCC_ExprFuncCall * yy445;
  ZCC_ExprConstant * yy471;
  ZCC_IfStmt * yy481;
  ZCC_FuncParamDecl * yy491;
  ZCC_ConstantDef * yy499;
  int yy537;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 0
#endif
#define ZCCParseARG_SDECL  ZCCParseState *stat ;
#define ZCCParseARG_PDECL , ZCCParseState *stat 
#define ZCCParseARG_FETCH  ZCCParseState *stat  = yypParser->stat 
#define ZCCParseARG_STORE yypParser->stat  = stat 
#define YYERRORSYMBOL 159
#define YYERRSYMDT yy537
#define YYFALLBACK 1
#define YYNSTATE             403
#define YYNRULE              375
#define YY_MAX_SHIFT         402
#define YY_MIN_SHIFTREDUCE   672
#define YY_MAX_SHIFTREDUCE   1046
#define YY_MIN_REDUCE        1047
#define YY_MAX_REDUCE        1421
#define YY_ERROR_ACTION      1422
#define YY_ACCEPT_ACTION     1423
#define YY_NO_ACTION         1424
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (2948)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   117,  116,   25,  101,  100,   99,   97,   96,   98,  114,
 /*    10 */   115,  148,   34,   37,  796,   65,  966,  778,  176,  675,
 /*    20 */   165,  347,  205,  381, 1423,   17,  705,  803,  957,  757,
 /*    30 */   381,  319,  825,    2,  981,  708,  707,  711,  959,  249,
 /*    40 */   769,  770,  771,  772,  135,  799,  704,  847,  847,  125,
 /*    50 */   892,  706,  712,  713,  709,  710,  714,  279,  810,  811,
 /*    60 */   812,  813,  814,  815,  816,  817,  818,  819,  820,  821,
 /*    70 */   822,  823,  824,  350,  368,  361,  297,  362,  358,  355,
 /*    80 */    82,   95,   94,   93,  103,  107,  101,  100,   99,   97,
 /*    90 */    96,   98,  242,  205,  893,  953,  953,  369,   65,  242,
 /*   100 */   911,  893,   16,  113,  112,  111,  110,  960,  961,  962,
 /*   110 */   963,  964,  965,   45,  332,  331,   33,   10,  327,  324,
 /*   120 */   991,  992,  321, 1256,  320,   53,  285,  674,  676,  677,
 /*   130 */   678,  679,  680,  681, 1103,  697,  847,  117,  116,  149,
 /*   140 */    46,  384,  372,  378,  145,  145,  114,  115,  148,   34,
 /*   150 */    37,  119,   41,  966,   47,  284,  883,  165,  347,  880,
 /*   160 */   182,  381,  698,  744,  243,  957,  298,  827,  319,  825,
 /*   170 */     2,  982,  699,  700,  882,  959,    2,  124,  283,  163,
 /*   180 */   163,  702,  401,  399,  392,   41,  386,  892,  384,  372,
 /*   190 */   154,  839,  827,  840,  312,  810,  811,  812,  813,  814,
 /*   200 */   815,  816,  817,  818,  819,  820,  821,  822,  823,  824,
 /*   210 */   350,  368,  361,   45,  362,  358,  355,   41,   95,   94,
 /*   220 */    93,  103,  107,  101,  100,   99,   97,   96,   98, 1047,
 /*   230 */   242,  182,  893,  884,   44,   65,  317,  317,  396,  827,
 /*   240 */   113,  112,  111,  110,  960,  961,  962,  963,  964,  965,
 /*   250 */    45,  332,  331,   33,   10,  327,  324,  991,  992,  321,
 /*   260 */    45,  320,   53,  839,  827,  840,  130,  352,  120,  352,
 /*   270 */   765,  766,  767,  175,  117,  116,  123, 1014,  738,  854,
 /*   280 */   171,  244,  278,  114,  115,  148,   34,   37,  729,  731,
 /*   290 */   966,  310,  201,  381,  165,  347,  142,  272,  731,  732,
 /*   300 */   733,  386,  957,  384,  372,  319,  825,    2,  732,  733,
 /*   310 */   179,  273,  959,  810,  811,  812,  813,  814,  815,  734,
 /*   320 */   295,   43,   43,  764,  892,  349,  395,  174,  734,  164,
 /*   330 */   164,  730,  810,  811,  812,  813,  814,  815,  816,  817,
 /*   340 */   818,  819,  820,  821,  822,  823,  824,  350,  368,  361,
 /*   350 */   838,  362,  358,  355,  103,  107,  101,  100,   99,   97,
 /*   360 */    96,   98,  242,  201,  893,   16,  277,  846,   65,  118,
 /*   370 */   997,  251,  251,  243,   16,  397,  395,  113,  112,  111,
 /*   380 */   110,  960,  961,  962,  963,  964,  965,   45,  332,  331,
 /*   390 */    33,   10,  327,  324,  991,  992,  321,  148,  320,   53,
 /*   400 */   151,  902,  903,  379,   22,   62,  165,  828,  872,  860,
 /*   410 */   874,  875,    1,  304,  696,  291,  158,  280,  825,  205,
 /*   420 */   381,  281,  315,  697,  991,  992,  876,  786,  205,  381,
 /*   430 */   780,  781,  782,  783,  784,  293,  292,  808,   59,  200,
 /*   440 */   381,  768,  775,  827,  810,  811,  812,  813,  814,  815,
 /*   450 */   816,  817,  818,  819,  820,  821,  822,  823,  824,  826,
 /*   460 */   368,  367,  247,  362,  358,  355,  843,  839,  827,  840,
 /*   470 */   259,  263,  308,  861,  862,  863,  864,  865,  866,  867,
 /*   480 */   869,  870,  871,  873,  877,  117,  116,  252,  366,  242,
 /*   490 */   205,  893,  247,  247,  114,  115,  148,   34,  242,  205,
 /*   500 */   893,  263,  263,  140,   50,  165,  347,  827, 1395,  242,
 /*   510 */   200,  893,  309,  957,   35,  384,  372,  825,  148,  848,
 /*   520 */   159,   59,  773,  959,  759,   59,    9,  165,  828,  980,
 /*   530 */    59,  839,  827,  840,  130,  892,  774,  842, 1010,  825,
 /*   540 */   143,  365, 1011,  810,  811,  812,  813,  814,  815,  816,
 /*   550 */   817,  818,  819,  820,  821,  822,  823,  824,  826,  368,
 /*   560 */   361,  845,  362,  358,  355,  810,  811,  812,  813,  814,
 /*   570 */   815,  816,  817,  818,  819,  820,  821,  822,  823,  824,
 /*   580 */   826,  368,  361,  261,  362,  358,  355,   45,  113,  112,
 /*   590 */   111,  110,  960,  961,  962,  963,  964,  965,   77,   74,
 /*   600 */    73,   72,   76,   75,   71,   70,   68,   67,   66,   69,
 /*   610 */    64,  328,   78,   79,   85,   84,   83,   91,   90,   89,
 /*   620 */    88,   87,   86,   92,   80,   81,   82,   95,   94,   93,
 /*   630 */   103,  107,  101,  100,   99,   97,   96,   98,  363,  684,
 /*   640 */   325,  203,  381,   59,   65,  197,  381,  104,  353,  203,
 /*   650 */   381,  690,  691,  692,  693,  137,  276,  316,  136,  895,
 /*   660 */   333,   77,   74,   73,   72,   76,   75,   71,   70,   68,
 /*   670 */    67,   66,   69,   64,  173,   78,   79,   85,   84,   83,
 /*   680 */    91,   90,   89,   88,   87,   86,   92,   80,   81,   82,
 /*   690 */    95,   94,   93,  103,  107,  101,  100,   99,   97,   96,
 /*   700 */    98,   59,   41,   20,  794,  195,  381,   65,  183,  381,
 /*   710 */   105,  242,  203,  893,  973,  242,  197,  893,  288,  242,
 /*   720 */   203,  893,  896,  787,   77,   74,   73,   72,   76,   75,
 /*   730 */    71,   70,   68,   67,   66,   69,   64,  248,   78,   79,
 /*   740 */    85,   84,   83,   91,   90,   89,   88,   87,   86,   92,
 /*   750 */    80,   81,   82,   95,   94,   93,  103,  107,  101,  100,
 /*   760 */    99,   97,   96,   98,  726,  723,  724,   59,  301,  318,
 /*   770 */    65,   25,  157,  106,   19,  242,  195,  893,  242,  183,
 /*   780 */   893,  725,  973,  899,  338,  897,  177,   77,   74,   73,
 /*   790 */    72,   76,   75,   71,   70,   68,   67,   66,   69,   64,
 /*   800 */   983,   78,   79,   85,   84,   83,   91,   90,   89,   88,
 /*   810 */    87,   86,   92,   80,   81,   82,   95,   94,   93,  103,
 /*   820 */   107,  101,  100,   99,   97,   96,   98, 1016,  721,  306,
 /*   830 */   305,  760,  250,   65,  855,   77,   74,   73,   72,   76,
 /*   840 */    75,   71,   70,   68,   67,   66,   69,   64,  785,   78,
 /*   850 */    79,   85,   84,   83,   91,   90,   89,   88,   87,   86,
 /*   860 */    92,   80,   81,   82,   95,   94,   93,  103,  107,  101,
 /*   870 */   100,   99,   97,   96,   98,  128,   98, 1013,  852,  323,
 /*   880 */   879,   65,  147,   65,   48,  122,   77,   74,   73,   72,
 /*   890 */    76,   75,   71,   70,   68,   67,   66,   69,   64, 1002,
 /*   900 */    78,   79,   85,   84,   83,   91,   90,   89,   88,   87,
 /*   910 */    86,   92,   80,   81,   82,   95,   94,   93,  103,  107,
 /*   920 */   101,  100,   99,   97,   96,   98,  836,  740,  166, 1023,
 /*   930 */   736,  134,   65,  720,   77,   74,   73,   72,   76,   75,
 /*   940 */    71,   70,   68,   67,   66,   69,   64,  371,   78,   79,
 /*   950 */    85,   84,   83,   91,   90,   89,   88,   87,   86,   92,
 /*   960 */    80,   81,   82,   95,   94,   93,  103,  107,  101,  100,
 /*   970 */    99,   97,   96,   98,  957,  402,   15,  240,   13,  286,
 /*   980 */    65,  287,   77,   74,   73,   72,   76,   75,   71,   70,
 /*   990 */    68,   67,   66,   69,   64,    5,   78,   79,   85,   84,
 /*  1000 */    83,   91,   90,   89,   88,   87,   86,   92,   80,   81,
 /*  1010 */    82,   95,   94,   93,  103,  107,  101,  100,   99,   97,
 /*  1020 */    96,   98,  241,  294,   14,  172,  270,  271,   65,  243,
 /*  1030 */    77,   74,   73,   72,   76,   75,   71,   70,   68,   67,
 /*  1040 */    66,   69,   64,    6,   78,   79,   85,   84,   83,   91,
 /*  1050 */    90,   89,   88,   87,   86,   92,   80,   81,   82,   95,
 /*  1060 */    94,   93,  103,  107,  101,  100,   99,   97,   96,   98,
 /*  1070 */   695,  274,  275,  150,  685,  803,   65,   42,   77,   74,
 /*  1080 */    73,   72,   76,   75,   71,   70,   68,   67,   66,   69,
 /*  1090 */    64,    8,   78,   79,   85,   84,   83,   91,   90,   89,
 /*  1100 */    88,   87,   86,   92,   80,   81,   82,   95,   94,   93,
 /*  1110 */   103,  107,  101,  100,   99,   97,   96,   98,  141,  144,
 /*  1120 */   791,  790, 1024,  792,   65,  789,   77,   74,   73,   72,
 /*  1130 */    76,   75,   71,   70,   68,   67,   66,   69,   64,  988,
 /*  1140 */    78,   79,   85,   84,   83,   91,   90,   89,   88,   87,
 /*  1150 */    86,   92,   80,   81,   82,   95,   94,   93,  103,  107,
 /*  1160 */   101,  100,   99,   97,   96,   98,  788,  153,   49,  132,
 /*  1170 */   296,  155,   65,   18,   77,   74,   73,   72,   76,   75,
 /*  1180 */    71,   70,   68,   67,   66,   69,   64,   11,   78,   79,
 /*  1190 */    85,   84,   83,   91,   90,   89,   88,   87,   86,   92,
 /*  1200 */    80,   81,   82,   95,   94,   93,  103,  107,  101,  100,
 /*  1210 */    99,   97,   96,   98,  297,  727,  299,  300,  859,  302,
 /*  1220 */    65,  303,   77,   74,   73,   72,   76,   75,   71,   70,
 /*  1230 */    68,   67,   66,   69,   64,   63,   78,   79,   85,   84,
 /*  1240 */    83,   91,   90,   89,   88,   87,   86,   92,   80,   81,
 /*  1250 */    82,   95,   94,   93,  103,  107,  101,  100,   99,   97,
 /*  1260 */    96,   98,  827,  205,  381,  307,  761,  858,   65,   92,
 /*  1270 */    80,   81,   82,   95,   94,   93,  103,  107,  101,  100,
 /*  1280 */    99,   97,   96,   98,  857,  156,  839,  827,  840,  130,
 /*  1290 */    65,  900,  354,   77,   74,   73,   72,   76,   75,   71,
 /*  1300 */    70,   68,   67,   66,   69,   64,  264,   78,   79,   85,
 /*  1310 */    84,   83,   91,   90,   89,   88,   87,   86,   92,   80,
 /*  1320 */    81,   82,   95,   94,   93,  103,  107,  101,  100,   99,
 /*  1330 */    97,   96,   98,  242,  205,  893,  264,  264,  849,   65,
 /*  1340 */    51,   77,   74,   73,   72,   76,   75,   71,   70,   68,
 /*  1350 */    67,   66,   69,   64,  894,   78,   79,   85,   84,   83,
 /*  1360 */    91,   90,   89,   88,   87,   86,   92,   80,   81,   82,
 /*  1370 */    95,   94,   93,  103,  107,  101,  100,   99,   97,   96,
 /*  1380 */    98,  381,  337,  311,  126,   35, 1012,   65,   36,  735,
 /*  1390 */   342,   77,   74,   73,   72,   76,   75,   71,   70,   68,
 /*  1400 */    67,   66,   69,   64,  160,   78,   79,   85,   84,   83,
 /*  1410 */    91,   90,   89,   88,   87,   86,   92,   80,   81,   82,
 /*  1420 */    95,   94,   93,  103,  107,  101,  100,   99,   97,   96,
 /*  1430 */    98,   25,  148,   52, 1003,    7,   54,   65,   55,   56,
 /*  1440 */   351,  165,  828,  898,  161,  827,  313,  313,   44,   24,
 /*  1450 */   242,  910,  893,  825,   80,   81,   82,   95,   94,   93,
 /*  1460 */   103,  107,  101,  100,   99,   97,   96,   98,   38,  839,
 /*  1470 */   827,  840,  130,   12,   65,  356,   57,  827,   39,  810,
 /*  1480 */   811,  812,  813,  814,  815,  816,  817,  818,  819,  820,
 /*  1490 */   821,  822,  823,  824,  826,  368,  361,  381,  362,  358,
 /*  1500 */   355,  839,  827,  840,  130,  381,  827,  357,   81,   82,
 /*  1510 */    95,   94,   93,  103,  107,  101,  100,   99,   97,   96,
 /*  1520 */    98,  888,  889,  890,  978,  977,   58,   65,  334,  336,
 /*  1530 */   839,  827,  840,  130,  976,   64,  359,   78,   79,   85,
 /*  1540 */    84,   83,   91,   90,   89,   88,   87,   86,   92,   80,
 /*  1550 */    81,   82,   95,   94,   93,  103,  107,  101,  100,   99,
 /*  1560 */    97,   96,   98,  152,  335,  827,  242,  909,  893,   65,
 /*  1570 */   975,  200,  381,  748,  242,  908,  893,   40,  339,  340,
 /*  1580 */   201,  381,  750,  749,  753,  341,  972,  971,  739,  839,
 /*  1590 */   827,  840,  130,  970,  974,  360,  969,  117,  116,  754,
 /*  1600 */   755,  751,  752,  756, 1203,  827,  114,  115,  243,   34,
 /*  1610 */   381,   60,  835,  809,  245,  348,  129,  747,  891,  246,
 /*  1620 */   289,  162,    3,  282,   26,  957,  167,  370,  167,  839,
 /*  1630 */   827,  840,  127,  844,   27,  959,  834,   28,   29,   32,
 /*  1640 */   833,  242,  200,  893,  200,  381,  262,  892,   32,   16,
 /*  1650 */   242,  201,  893,  260,   30,  968,  984,  967,  346,  984,
 /*  1660 */   984,  984,  984,  345,  344,  343,  329,   31,   61,  322,
 /*  1670 */   201,  381,  831,  830,  364,  109,  800,  804,  805,  242,
 /*  1680 */   907,  893,  829,  168,  974,  801,  804,  805,  121,  169,
 /*  1690 */    21,  373,  256,  374,  375,  827,  201,  381,  376, 1034,
 /*  1700 */   113,  112,  111,  110,  960,  961,  962,  963,  964,  965,
 /*  1710 */   901,  298,    4,   65,  242,  200,  893,  102,  958,  839,
 /*  1720 */   827,  840,  127,  283,  108,  383,  745,  170,  399,  392,
 /*  1730 */   178,  386,  717,  384,  372,  154,  387,  388,  201,  381,
 /*  1740 */   242,  201,  893,  381,  389,  968,  984,  967,  346,  984,
 /*  1750 */   984,  984,  984,  345,  344,  343,  329,  390,  391,  322,
 /*  1760 */   729,  731, 1136,  827,  393,  330,  242,  201,  893,  200,
 /*  1770 */   381,  732,  733,  381,  996,  394,  200,  381, 1135,  200,
 /*  1780 */   381,  716,  201,  381,  255,  138,  139,  839,  827,  840,
 /*  1790 */   127,  734,  385,   43,   43,  131,  974,  715,  398,  400,
 /*  1800 */  1049,  802, 1049, 1049, 1049,   45,  696,  827,  242,  201,
 /*  1810 */   893, 1049,  242,  906,  893,  697,  996,  253, 1049,  797,
 /*  1820 */  1049, 1049,  290,  993,  254,  326,  314,  257, 1049, 1049,
 /*  1830 */  1049,  839,  827,  840,  127, 1049, 1049,   16, 1049,  242,
 /*  1840 */   200,  893,  242,  905,  893, 1049,  242,  200,  893,  242,
 /*  1850 */   200,  893,  242,  201,  893,  184,  381,  968,  985,  967,
 /*  1860 */   346,  985,  985,  985,  985,  345,  344,  343,  329, 1049,
 /*  1870 */  1049,  322, 1049, 1049,   79,   85,   84,   83,   91,   90,
 /*  1880 */    89,   88,   87,   86,   92,   80,   81,   82,   95,   94,
 /*  1890 */    93,  103,  107,  101,  100,   99,   97,   96,   98, 1049,
 /*  1900 */   330,  381, 1049, 1049, 1049,   65,  200,  381, 1049, 1049,
 /*  1910 */   133,  381,  117,  116,  138,  139, 1049,  201,  381, 1049,
 /*  1920 */  1049,  114,  115, 1049,   34,  242,  184,  893,  979, 1049,
 /*  1930 */   802,  974, 1049,  891, 1049,  696, 1049, 1049, 1049, 1049,
 /*  1940 */   957, 1049,  827,  330,  697, 1049, 1049, 1049,  798, 1049,
 /*  1950 */   959, 1049, 1049, 1049,  258, 1049,  196,  381, 1049, 1049,
 /*  1960 */   201,  381,  892, 1049, 1049, 1049,  839,  827,  840,  127,
 /*  1970 */   242,  904,  893, 1049,  974, 1049,  242,  200,  893, 1049,
 /*  1980 */   242,  133,  893,  198,  381,  827, 1049,  242,  201,  893,
 /*  1990 */  1049, 1049,  968,  985,  967,  346,  985,  985,  985,  985,
 /*  2000 */   345,  344,  343,  329, 1049, 1049,  322, 1049, 1049,  839,
 /*  2010 */   827,  840,  127, 1049, 1049,  113,  112,  111,  110,  960,
 /*  2020 */   961,  962,  963,  964,  965, 1049,  242,  196,  893, 1049,
 /*  2030 */   242,  201,  893, 1049,  330,  968, 1001,  967,  346, 1001,
 /*  2040 */  1001, 1001, 1001,  345,  344,  343,  329, 1049, 1049,  322,
 /*  2050 */  1049,  201,  381,  242,  198,  893, 1049, 1049,  701, 1049,
 /*  2060 */  1049, 1049,  298, 1049, 1049,  974, 1049, 1049, 1049, 1049,
 /*  2070 */  1049, 1049, 1049, 1049,  283, 1049,  827,  330,  401,  399,
 /*  2080 */   392, 1049,  386, 1049,  384,  372,  154,  185,  381, 1049,
 /*  2090 */   186,  381, 1049, 1049,  201,  381, 1049, 1049, 1049, 1049,
 /*  2100 */   839,  827,  840,  127, 1049, 1049, 1049, 1049,  974, 1049,
 /*  2110 */  1049, 1049, 1049, 1049, 1049, 1049, 1049,  187,  381,  827,
 /*  2120 */  1049,  242,  201,  893, 1049, 1049,  968, 1000,  967,  346,
 /*  2130 */  1000, 1000, 1000, 1000,  345,  344,  343,  329, 1049, 1049,
 /*  2140 */   322, 1049, 1049,  839,  827,  840,  127, 1049, 1049, 1049,
 /*  2150 */  1049, 1049, 1049, 1049, 1049, 1049,   45,  242,  185,  893,
 /*  2160 */   242,  186,  893, 1049,  242,  201,  893, 1049, 1049,  968,
 /*  2170 */   999,  967,  346,  999,  999,  999,  999,  345,  344,  343,
 /*  2180 */   329, 1049, 1049,  322, 1049, 1049, 1049,  242,  187,  893,
 /*  2190 */   330, 1049, 1049, 1049,  188,  381, 1049,  189,  381, 1049,
 /*  2200 */   190,  381, 1049,  117,  116, 1049, 1049,  201,  381, 1049,
 /*  2210 */  1049, 1049,  114,  115, 1049,   34, 1049, 1049, 1049, 1049,
 /*  2220 */  1049,  974, 1049,  377,  891, 1049, 1049, 1049,  199,  381,
 /*  2230 */  1049,  957,  827, 1049, 1049, 1049, 1049, 1049, 1049, 1049,
 /*  2240 */  1049,  959, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,
 /*  2250 */  1049, 1049, 1049,  892,  202,  381,  839,  827,  840,  127,
 /*  2260 */  1049, 1049, 1049,  330,  242,  188,  893,  242,  189,  893,
 /*  2270 */   242,  190,  893, 1049, 1049, 1049, 1049,  242,  201,  893,
 /*  2280 */   201,  381,  968,  990,  967,  346,  990,  990,  990,  990,
 /*  2290 */   345,  344,  343,  329,  974, 1049,  322, 1049,  242,  199,
 /*  2300 */   893, 1049, 1049, 1049,  330,  827,  113,  112,  111,  110,
 /*  2310 */   960,  961,  962,  963,  964,  965, 1049,  204,  381, 1049,
 /*  2320 */  1049,  201,  381, 1049,  242,  202,  893, 1049, 1049,  839,
 /*  2330 */   827,  840,  127, 1049, 1049,  974, 1049, 1049, 1049, 1049,
 /*  2340 */  1049,  191,  381, 1049, 1049, 1049,  827,  219,  381, 1049,
 /*  2350 */   242,  201,  893,  192,  381,  968,  989,  967,  346,  989,
 /*  2360 */   989,  989,  989,  345,  344,  343,  329,  950,  381,  322,
 /*  2370 */   839,  827,  840,  127,  206,  381, 1049, 1049,  207,  381,
 /*  2380 */  1049,  208,  381, 1049,  209,  381, 1049,  242,  204,  893,
 /*  2390 */  1049,  242,  201,  893, 1049, 1049,  968,  146,  967,  346,
 /*  2400 */   146,  146,  146,  146,  345,  344,  343,  329,  210,  381,
 /*  2410 */   322,  242,  191,  893, 1049, 1049,  330,  242,  219,  893,
 /*  2420 */  1049, 1049, 1049,  242,  192,  893, 1049, 1049, 1049, 1049,
 /*  2430 */   211,  381, 1049,  201,  381, 1049, 1049,  242,  950,  893,
 /*  2440 */  1049, 1049, 1049, 1049,  242,  206,  893,  974,  242,  207,
 /*  2450 */   893,  242,  208,  893,  242,  209,  893, 1049,  827, 1049,
 /*  2460 */  1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,
 /*  2470 */  1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,  242,  210,
 /*  2480 */   893, 1049,  839,  827,  840,  127, 1049, 1049, 1049, 1049,
 /*  2490 */  1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,
 /*  2500 */   242,  211,  893,  242,  201,  893, 1049, 1049,  968,  987,
 /*  2510 */   967,  346,  987,  987,  987,  987,  345,  344,  343,  329,
 /*  2520 */  1049, 1049,  322,   85,   84,   83,   91,   90,   89,   88,
 /*  2530 */    87,   86,   92,   80,   81,   82,   95,   94,   93,  103,
 /*  2540 */   107,  101,  100,   99,   97,   96,   98, 1049, 1049, 1049,
 /*  2550 */   212,  381, 1049,   65,   91,   90,   89,   88,   87,   86,
 /*  2560 */    92,   80,   81,   82,   95,   94,   93,  103,  107,  101,
 /*  2570 */   100,   99,   97,   96,   98,  117,  116,  213,  381, 1049,
 /*  2580 */  1049,   65,  214,  381,  114,  115, 1049,   34,  117,  116,
 /*  2590 */   215,  381, 1049,  216,  381, 1049,  891,  114,  115, 1049,
 /*  2600 */    34,  217,  381,  957, 1049, 1049, 1049, 1049,   23,  382,
 /*  2610 */  1049, 1049, 1049,  959, 1049, 1049,  957, 1049,  117,  116,
 /*  2620 */   242,  212,  893, 1049, 1049,  892,  959,  114,  115, 1049,
 /*  2630 */    34,  220,  381, 1049, 1049,  221,  381, 1049,  892,  891,
 /*  2640 */  1049, 1049, 1049, 1049, 1049, 1049,  957,  242,  213,  893,
 /*  2650 */  1049, 1049,  242,  214,  893, 1049,  959, 1049, 1049, 1049,
 /*  2660 */   242,  215,  893,  242,  216,  893, 1049, 1049,  892, 1049,
 /*  2670 */  1049,  242,  217,  893, 1049, 1049, 1049, 1049,  113,  112,
 /*  2680 */   111,  110,  960,  961,  962,  963,  964,  965,  232,  381,
 /*  2690 */  1049,  113,  112,  111,  110,  960,  961,  962,  963,  964,
 /*  2700 */   965,  242,  220,  893, 1049,  242,  221,  893,  233,  381,
 /*  2710 */  1049,  234,  381, 1049,  222,  381, 1049,  223,  381, 1049,
 /*  2720 */  1049,  113,  112,  111,  110,  960,  961,  962,  963,  964,
 /*  2730 */   965, 1049,  224,  381, 1049,  225,  381, 1049,  226,  381,
 /*  2740 */  1049,  227,  381, 1049,  228,  381, 1049,  229,  381, 1049,
 /*  2750 */   230,  381, 1049,  231,  381, 1049, 1049, 1049,  242,  232,
 /*  2760 */   893, 1049,  235,  381, 1049,  236,  381, 1049,  237,  381,
 /*  2770 */  1049,  265,  381, 1049,  266,  381, 1049, 1049,  242,  233,
 /*  2780 */   893,  242,  234,  893,  242,  222,  893,  242,  223,  893,
 /*  2790 */   380,  381, 1049,  267,  381, 1049,  268,  381, 1049,  269,
 /*  2800 */   381, 1049,  242,  224,  893,  242,  225,  893,  242,  226,
 /*  2810 */   893,  242,  227,  893,  242,  228,  893,  242,  229,  893,
 /*  2820 */   242,  230,  893,  242,  231,  893,  218,  381, 1049,  239,
 /*  2830 */   381, 1049,  242,  235,  893,  242,  236,  893,  242,  237,
 /*  2840 */   893,  242,  265,  893,  242,  266,  893, 1049,  193,  381,
 /*  2850 */  1049, 1049, 1049, 1049, 1049,  180,  381, 1049,  181,  381,
 /*  2860 */   242,  380,  893,  242,  267,  893,  242,  268,  893,  242,
 /*  2870 */   269,  893,  238,  381, 1049,  194,  381, 1049, 1049, 1049,
 /*  2880 */  1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,
 /*  2890 */  1049, 1049, 1049, 1049, 1049, 1049,  242,  218,  893,  242,
 /*  2900 */   239,  893, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,
 /*  2910 */  1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,  242,  193,
 /*  2920 */   893, 1049, 1049, 1049, 1049,  242,  180,  893,  242,  181,
 /*  2930 */   893, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049, 1049,
 /*  2940 */  1049, 1049,  242,  238,  893,  242,  194,  893,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    33,   34,   50,   35,   36,   37,   38,   39,   40,   42,
 /*    10 */    43,   44,   45,   46,   62,   47,   49,  211,  212,  159,
 /*    20 */    53,   54,  176,  177,  164,  165,  160,   49,   61,   67,
 /*    30 */   177,   64,   65,   66,   67,  169,  170,  171,   71,   77,
 /*    40 */    78,   79,   80,   81,   82,   67,  180,  162,  163,   54,
 /*    50 */    83,  185,  186,  187,  188,  189,  190,   53,   91,   92,
 /*    60 */    93,   94,   95,   96,   97,   98,   99,  100,  101,  102,
 /*    70 */   103,  104,  105,  106,  107,  108,   72,  110,  111,  112,
 /*    80 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*    90 */    39,   40,  246,  247,  248,  249,  250,   54,   47,  246,
 /*   100 */   247,  248,  236,  136,  137,  138,  139,  140,  141,  142,
 /*   110 */   143,  144,  145,  146,  147,  148,  149,  150,  151,  152,
 /*   120 */   153,  154,  155,   62,  157,  158,   54,  166,  167,  168,
 /*   130 */   169,  170,  171,  172,   67,   63,  251,   33,   34,  178,
 /*   140 */     1,   74,   75,  159,  233,  234,   42,   43,   44,   45,
 /*   150 */    46,   45,   46,   49,   34,   83,  132,   53,   54,   49,
 /*   160 */   176,  177,   54,  202,   44,   61,   52,  201,   64,   65,
 /*   170 */    66,   67,   64,   65,  113,   71,   66,   54,   64,  233,
 /*   180 */   234,   67,   68,   69,   70,   46,   72,   83,   74,   75,
 /*   190 */    76,  225,  226,  227,  228,   91,   92,   93,   94,   95,
 /*   200 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*   210 */   106,  107,  108,  146,  110,  111,  112,   46,   30,   31,
 /*   220 */    32,   33,   34,   35,   36,   37,   38,   39,   40,    0,
 /*   230 */   246,  247,  248,  244,  245,   47,  266,  267,   54,  201,
 /*   240 */   136,  137,  138,  139,  140,  141,  142,  143,  144,  145,
 /*   250 */   146,  147,  148,  149,  150,  151,  152,  153,  154,  155,
 /*   260 */   146,  157,  158,  225,  226,  227,  228,  229,  230,  231,
 /*   270 */   206,  207,  208,  209,   33,   34,  214,   48,  201,  241,
 /*   280 */    51,   52,   53,   42,   43,   44,   45,   46,  159,  160,
 /*   290 */    49,  159,  176,  177,   53,   54,  184,   68,  160,  170,
 /*   300 */   171,   72,   61,   74,   75,   64,   65,   66,  170,  171,
 /*   310 */    49,  184,   71,   91,   92,   93,   94,   95,   96,  190,
 /*   320 */   191,  192,  193,  159,   83,  194,  195,   66,  190,  233,
 /*   330 */   234,  193,   91,   92,   93,   94,   95,   96,   97,   98,
 /*   340 */    99,  100,  101,  102,  103,  104,  105,  106,  107,  108,
 /*   350 */    21,  110,  111,  112,   33,   34,   35,   36,   37,   38,
 /*   360 */    39,   40,  246,  247,  248,  236,  184,  235,   47,  205,
 /*   370 */   254,  239,  240,   44,  236,  194,  195,  136,  137,  138,
 /*   380 */   139,  140,  141,  142,  143,  144,  145,  146,  147,  148,
 /*   390 */   149,  150,  151,  152,  153,  154,  155,   44,  157,  158,
 /*   400 */    54,   42,   43,   44,   45,   46,   53,   54,   55,   56,
 /*   410 */    57,   58,   66,   60,   54,   50,   63,  184,   65,  176,
 /*   420 */   177,  184,  159,   63,  153,  154,   73,   62,  176,  177,
 /*   430 */    84,   85,   86,   87,   88,   89,   90,   49,   50,  176,
 /*   440 */   177,   14,  210,  201,   91,   92,   93,   94,   95,   96,
 /*   450 */    97,   98,   99,  100,  101,  102,  103,  104,  105,  106,
 /*   460 */   107,  108,  219,  110,  111,  112,  113,  225,  226,  227,
 /*   470 */   228,  219,  119,  120,  121,  122,  123,  124,  125,  126,
 /*   480 */   127,  128,  129,  130,  131,   33,   34,  224,   54,  246,
 /*   490 */   247,  248,  249,  250,   42,   43,   44,   45,  246,  247,
 /*   500 */   248,  249,  250,  184,   77,   53,   54,  201,   67,  246,
 /*   510 */   247,  248,   50,   61,   50,   74,   75,   65,   44,   49,
 /*   520 */    50,   50,  210,   71,   62,   50,   62,   53,   54,   49,
 /*   530 */    50,  225,  226,  227,  228,   83,  210,  231,   67,   65,
 /*   540 */   184,  107,   67,   91,   92,   93,   94,   95,   96,   97,
 /*   550 */    98,   99,  100,  101,  102,  103,  104,  105,  106,  107,
 /*   560 */   108,  234,  110,  111,  112,   91,   92,   93,   94,   95,
 /*   570 */    96,   97,   98,   99,  100,  101,  102,  103,  104,  105,
 /*   580 */   106,  107,  108,  184,  110,  111,  112,  146,  136,  137,
 /*   590 */   138,  139,  140,  141,  142,  143,  144,  145,    1,    2,
 /*   600 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   610 */    13,  262,   15,   16,   17,   18,   19,   20,   21,   22,
 /*   620 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*   630 */    33,   34,   35,   36,   37,   38,   39,   40,  184,  181,
 /*   640 */   175,  176,  177,   50,   47,  176,  177,   50,  175,  176,
 /*   650 */   177,   55,   56,   57,   58,   59,   60,    1,   14,   62,
 /*   660 */    67,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*   670 */    10,   11,   12,   13,  182,   15,   16,   17,   18,   19,
 /*   680 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   690 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   700 */    40,   50,   46,   45,  213,  176,  177,   47,  176,  177,
 /*   710 */    50,  246,  247,  248,   49,  246,  247,  248,  216,  246,
 /*   720 */   247,  248,   62,   61,    1,    2,    3,    4,    5,    6,
 /*   730 */     7,    8,    9,   10,   11,   12,   13,  217,   15,   16,
 /*   740 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*   750 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*   760 */    37,   38,   39,   40,   56,   57,   58,   50,   60,  118,
 /*   770 */    47,   50,   45,   50,   66,  246,  247,  248,  246,  247,
 /*   780 */   248,   73,   49,   62,   67,   62,  215,    1,    2,    3,
 /*   790 */     4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   800 */    67,   15,   16,   17,   18,   19,   20,   21,   22,   23,
 /*   810 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*   820 */    34,   35,   36,   37,   38,   39,   40,   49,  173,   50,
 /*   830 */   242,   54,  195,   47,  215,    1,    2,    3,    4,    5,
 /*   840 */     6,    7,    8,    9,   10,   11,   12,   13,   62,   15,
 /*   850 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*   860 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*   870 */    36,   37,   38,   39,   40,   54,   40,  267,  240,  240,
 /*   880 */    74,   47,   20,   47,   50,  238,    1,    2,    3,    4,
 /*   890 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   900 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*   910 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*   920 */    35,   36,   37,   38,   39,   40,  232,  199,   50,  174,
 /*   930 */   173,   14,   47,  173,    1,    2,    3,    4,    5,    6,
 /*   940 */     7,    8,    9,   10,   11,   12,   13,  200,   15,   16,
 /*   950 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*   960 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*   970 */    37,   38,   39,   40,   61,  177,  203,  183,  179,  216,
 /*   980 */    47,  216,    1,    2,    3,    4,    5,    6,    7,    8,
 /*   990 */     9,   10,   11,   12,   13,   62,   15,   16,   17,   18,
 /*  1000 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1010 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1020 */    39,   40,  196,  216,  179,   66,   54,   53,   47,   44,
 /*  1030 */     1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
 /*  1040 */    11,   12,   13,   62,   15,   16,   17,   18,   19,   20,
 /*  1050 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*  1060 */    31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
 /*  1070 */    62,   61,   45,   54,   54,   49,   47,   66,    1,    2,
 /*  1080 */     3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
 /*  1090 */    13,   62,   15,   16,   17,   18,   19,   20,   21,   22,
 /*  1100 */    23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
 /*  1110 */    33,   34,   35,   36,   37,   38,   39,   40,   47,   47,
 /*  1120 */    67,   67,   49,   49,   47,   67,    1,    2,    3,    4,
 /*  1130 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   62,
 /*  1140 */    15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
 /*  1150 */    25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
 /*  1160 */    35,   36,   37,   38,   39,   40,   61,   45,   45,   66,
 /*  1170 */    54,   67,   47,   66,    1,    2,    3,    4,    5,    6,
 /*  1180 */     7,    8,    9,   10,   11,   12,   13,   62,   15,   16,
 /*  1190 */    17,   18,   19,   20,   21,   22,   23,   24,   25,   26,
 /*  1200 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1210 */    37,   38,   39,   40,   72,   62,   61,   45,   62,   61,
 /*  1220 */    47,   45,    1,    2,    3,    4,    5,    6,    7,    8,
 /*  1230 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  1240 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1250 */    29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
 /*  1260 */    39,   40,  201,  176,  177,   45,   54,   62,   47,   26,
 /*  1270 */    27,   28,   29,   30,   31,   32,   33,   34,   35,   36,
 /*  1280 */    37,   38,   39,   40,   61,   61,  225,  226,  227,  228,
 /*  1290 */    47,  118,  231,    1,    2,    3,    4,    5,    6,    7,
 /*  1300 */     8,    9,   10,   11,   12,   13,  219,   15,   16,   17,
 /*  1310 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*  1320 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  1330 */    38,   39,   40,  246,  247,  248,  249,  250,   49,   47,
 /*  1340 */     1,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1350 */    10,   11,   12,   13,   62,   15,   16,   17,   18,   19,
 /*  1360 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1370 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1380 */    40,  177,   46,   54,   50,   50,   67,   47,   66,   49,
 /*  1390 */    54,    1,    2,    3,    4,    5,    6,    7,    8,    9,
 /*  1400 */    10,   11,   12,   13,   50,   15,   16,   17,   18,   19,
 /*  1410 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*  1420 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1430 */    40,   50,   44,    1,   14,  156,   45,   47,   45,   14,
 /*  1440 */   237,   53,   54,   62,   45,  201,  243,  244,  245,   49,
 /*  1450 */   246,  247,  248,   65,   27,   28,   29,   30,   31,   32,
 /*  1460 */    33,   34,   35,   36,   37,   38,   39,   40,   49,  225,
 /*  1470 */   226,  227,  228,   45,   47,  231,   45,  201,   66,   91,
 /*  1480 */    92,   93,   94,   95,   96,   97,   98,   99,  100,  101,
 /*  1490 */   102,  103,  104,  105,  106,  107,  108,  177,  110,  111,
 /*  1500 */   112,  225,  226,  227,  228,  177,  201,  231,   28,   29,
 /*  1510 */    30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*  1520 */    40,  133,  134,  135,   49,   49,   45,   47,    1,  118,
 /*  1530 */   225,  226,  227,  228,   49,   13,  231,   15,   16,   17,
 /*  1540 */    18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
 /*  1550 */    28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
 /*  1560 */    38,   39,   40,  159,   54,  201,  246,  247,  248,   47,
 /*  1570 */    49,  176,  177,  160,  246,  247,  248,   66,    1,  118,
 /*  1580 */   176,  177,  169,  170,  171,   46,   49,   49,  159,  225,
 /*  1590 */   226,  227,  228,   49,  190,  231,   49,   33,   34,  186,
 /*  1600 */   187,  188,  189,  190,   54,  201,   42,   43,   44,   45,
 /*  1610 */   177,    1,   21,   49,  159,  118,   46,  204,   54,  224,
 /*  1620 */   216,   62,  218,  159,   50,   61,  197,  198,  199,  225,
 /*  1630 */   226,  227,  228,  118,   20,   71,   21,   50,   20,  184,
 /*  1640 */    21,  246,  247,  248,  176,  177,   20,   83,  184,  236,
 /*  1650 */   246,  247,  248,  159,   50,  251,  252,  253,  254,  255,
 /*  1660 */   256,  257,  258,  259,  260,  261,  262,   20,    1,  265,
 /*  1670 */   176,  177,   21,   21,   54,  220,  221,  222,  223,  246,
 /*  1680 */   247,  248,   54,   67,  190,  221,  222,  223,   66,   54,
 /*  1690 */    45,   62,  224,   21,   54,  201,  176,  177,   20,   62,
 /*  1700 */   136,  137,  138,  139,  140,  141,  142,  143,  144,  145,
 /*  1710 */    54,   52,  218,   47,  246,  247,  248,   14,   61,  225,
 /*  1720 */   226,  227,  228,   64,    1,   54,   67,   67,   69,   70,
 /*  1730 */    54,   72,   49,   74,   75,   76,   71,   50,  176,  177,
 /*  1740 */   246,  247,  248,  177,   54,  251,  252,  253,  254,  255,
 /*  1750 */   256,  257,  258,  259,  260,  261,  262,   14,   54,  265,
 /*  1760 */   159,  160,   50,  201,   54,  159,  246,  247,  248,  176,
 /*  1770 */   177,  170,  171,  177,  254,   50,  176,  177,   50,  176,
 /*  1780 */   177,   49,  176,  177,  264,   33,   34,  225,  226,  227,
 /*  1790 */   228,  190,  191,  192,  193,   14,  190,   49,   54,   54,
 /*  1800 */   268,   49,  268,  268,  268,  146,   54,  201,  246,  247,
 /*  1810 */   248,  268,  246,  247,  248,   63,  254,  224,  268,   67,
 /*  1820 */   268,  268,  216,  261,  224,  263,  264,  224,  268,  268,
 /*  1830 */   268,  225,  226,  227,  228,  268,  268,  236,  268,  246,
 /*  1840 */   247,  248,  246,  247,  248,  268,  246,  247,  248,  246,
 /*  1850 */   247,  248,  246,  247,  248,  176,  177,  251,  252,  253,
 /*  1860 */   254,  255,  256,  257,  258,  259,  260,  261,  262,  268,
 /*  1870 */   268,  265,  268,  268,   16,   17,   18,   19,   20,   21,
 /*  1880 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
 /*  1890 */    32,   33,   34,   35,   36,   37,   38,   39,   40,  268,
 /*  1900 */   159,  177,  268,  268,  268,   47,  176,  177,  268,  268,
 /*  1910 */   176,  177,   33,   34,   33,   34,  268,  176,  177,  268,
 /*  1920 */   268,   42,   43,  268,   45,  246,  247,  248,   49,  268,
 /*  1930 */    49,  190,  268,   54,  268,   54,  268,  268,  268,  268,
 /*  1940 */    61,  268,  201,  159,   63,  268,  268,  268,   67,  268,
 /*  1950 */    71,  268,  268,  268,  224,  268,  176,  177,  268,  268,
 /*  1960 */   176,  177,   83,  268,  268,  268,  225,  226,  227,  228,
 /*  1970 */   246,  247,  248,  268,  190,  268,  246,  247,  248,  268,
 /*  1980 */   246,  247,  248,  176,  177,  201,  268,  246,  247,  248,
 /*  1990 */   268,  268,  251,  252,  253,  254,  255,  256,  257,  258,
 /*  2000 */   259,  260,  261,  262,  268,  268,  265,  268,  268,  225,
 /*  2010 */   226,  227,  228,  268,  268,  136,  137,  138,  139,  140,
 /*  2020 */   141,  142,  143,  144,  145,  268,  246,  247,  248,  268,
 /*  2030 */   246,  247,  248,  268,  159,  251,  252,  253,  254,  255,
 /*  2040 */   256,  257,  258,  259,  260,  261,  262,  268,  268,  265,
 /*  2050 */   268,  176,  177,  246,  247,  248,  268,  268,   48,  268,
 /*  2060 */   268,  268,   52,  268,  268,  190,  268,  268,  268,  268,
 /*  2070 */   268,  268,  268,  268,   64,  268,  201,  159,   68,   69,
 /*  2080 */    70,  268,   72,  268,   74,   75,   76,  176,  177,  268,
 /*  2090 */   176,  177,  268,  268,  176,  177,  268,  268,  268,  268,
 /*  2100 */   225,  226,  227,  228,  268,  268,  268,  268,  190,  268,
 /*  2110 */   268,  268,  268,  268,  268,  268,  268,  176,  177,  201,
 /*  2120 */   268,  246,  247,  248,  268,  268,  251,  252,  253,  254,
 /*  2130 */   255,  256,  257,  258,  259,  260,  261,  262,  268,  268,
 /*  2140 */   265,  268,  268,  225,  226,  227,  228,  268,  268,  268,
 /*  2150 */   268,  268,  268,  268,  268,  268,  146,  246,  247,  248,
 /*  2160 */   246,  247,  248,  268,  246,  247,  248,  268,  268,  251,
 /*  2170 */   252,  253,  254,  255,  256,  257,  258,  259,  260,  261,
 /*  2180 */   262,  268,  268,  265,  268,  268,  268,  246,  247,  248,
 /*  2190 */   159,  268,  268,  268,  176,  177,  268,  176,  177,  268,
 /*  2200 */   176,  177,  268,   33,   34,  268,  268,  176,  177,  268,
 /*  2210 */   268,  268,   42,   43,  268,   45,  268,  268,  268,  268,
 /*  2220 */   268,  190,  268,   53,   54,  268,  268,  268,  176,  177,
 /*  2230 */   268,   61,  201,  268,  268,  268,  268,  268,  268,  268,
 /*  2240 */   268,   71,  268,  268,  268,  268,  268,  268,  268,  268,
 /*  2250 */   268,  268,  268,   83,  176,  177,  225,  226,  227,  228,
 /*  2260 */   268,  268,  268,  159,  246,  247,  248,  246,  247,  248,
 /*  2270 */   246,  247,  248,  268,  268,  268,  268,  246,  247,  248,
 /*  2280 */   176,  177,  251,  252,  253,  254,  255,  256,  257,  258,
 /*  2290 */   259,  260,  261,  262,  190,  268,  265,  268,  246,  247,
 /*  2300 */   248,  268,  268,  268,  159,  201,  136,  137,  138,  139,
 /*  2310 */   140,  141,  142,  143,  144,  145,  268,  176,  177,  268,
 /*  2320 */   268,  176,  177,  268,  246,  247,  248,  268,  268,  225,
 /*  2330 */   226,  227,  228,  268,  268,  190,  268,  268,  268,  268,
 /*  2340 */   268,  176,  177,  268,  268,  268,  201,  176,  177,  268,
 /*  2350 */   246,  247,  248,  176,  177,  251,  252,  253,  254,  255,
 /*  2360 */   256,  257,  258,  259,  260,  261,  262,  176,  177,  265,
 /*  2370 */   225,  226,  227,  228,  176,  177,  268,  268,  176,  177,
 /*  2380 */   268,  176,  177,  268,  176,  177,  268,  246,  247,  248,
 /*  2390 */   268,  246,  247,  248,  268,  268,  251,  252,  253,  254,
 /*  2400 */   255,  256,  257,  258,  259,  260,  261,  262,  176,  177,
 /*  2410 */   265,  246,  247,  248,  268,  268,  159,  246,  247,  248,
 /*  2420 */   268,  268,  268,  246,  247,  248,  268,  268,  268,  268,
 /*  2430 */   176,  177,  268,  176,  177,  268,  268,  246,  247,  248,
 /*  2440 */   268,  268,  268,  268,  246,  247,  248,  190,  246,  247,
 /*  2450 */   248,  246,  247,  248,  246,  247,  248,  268,  201,  268,
 /*  2460 */   268,  268,  268,  268,  268,  268,  268,  268,  268,  268,
 /*  2470 */   268,  268,  268,  268,  268,  268,  268,  268,  246,  247,
 /*  2480 */   248,  268,  225,  226,  227,  228,  268,  268,  268,  268,
 /*  2490 */   268,  268,  268,  268,  268,  268,  268,  268,  268,  268,
 /*  2500 */   246,  247,  248,  246,  247,  248,  268,  268,  251,  252,
 /*  2510 */   253,  254,  255,  256,  257,  258,  259,  260,  261,  262,
 /*  2520 */   268,  268,  265,   17,   18,   19,   20,   21,   22,   23,
 /*  2530 */    24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
 /*  2540 */    34,   35,   36,   37,   38,   39,   40,  268,  268,  268,
 /*  2550 */   176,  177,  268,   47,   20,   21,   22,   23,   24,   25,
 /*  2560 */    26,   27,   28,   29,   30,   31,   32,   33,   34,   35,
 /*  2570 */    36,   37,   38,   39,   40,   33,   34,  176,  177,  268,
 /*  2580 */   268,   47,  176,  177,   42,   43,  268,   45,   33,   34,
 /*  2590 */   176,  177,  268,  176,  177,  268,   54,   42,   43,  268,
 /*  2600 */    45,  176,  177,   61,  268,  268,  268,  268,   66,   54,
 /*  2610 */   268,  268,  268,   71,  268,  268,   61,  268,   33,   34,
 /*  2620 */   246,  247,  248,  268,  268,   83,   71,   42,   43,  268,
 /*  2630 */    45,  176,  177,  268,  268,  176,  177,  268,   83,   54,
 /*  2640 */   268,  268,  268,  268,  268,  268,   61,  246,  247,  248,
 /*  2650 */   268,  268,  246,  247,  248,  268,   71,  268,  268,  268,
 /*  2660 */   246,  247,  248,  246,  247,  248,  268,  268,   83,  268,
 /*  2670 */   268,  246,  247,  248,  268,  268,  268,  268,  136,  137,
 /*  2680 */   138,  139,  140,  141,  142,  143,  144,  145,  176,  177,
 /*  2690 */   268,  136,  137,  138,  139,  140,  141,  142,  143,  144,
 /*  2700 */   145,  246,  247,  248,  268,  246,  247,  248,  176,  177,
 /*  2710 */   268,  176,  177,  268,  176,  177,  268,  176,  177,  268,
 /*  2720 */   268,  136,  137,  138,  139,  140,  141,  142,  143,  144,
 /*  2730 */   145,  268,  176,  177,  268,  176,  177,  268,  176,  177,
 /*  2740 */   268,  176,  177,  268,  176,  177,  268,  176,  177,  268,
 /*  2750 */   176,  177,  268,  176,  177,  268,  268,  268,  246,  247,
 /*  2760 */   248,  268,  176,  177,  268,  176,  177,  268,  176,  177,
 /*  2770 */   268,  176,  177,  268,  176,  177,  268,  268,  246,  247,
 /*  2780 */   248,  246,  247,  248,  246,  247,  248,  246,  247,  248,
 /*  2790 */   176,  177,  268,  176,  177,  268,  176,  177,  268,  176,
 /*  2800 */   177,  268,  246,  247,  248,  246,  247,  248,  246,  247,
 /*  2810 */   248,  246,  247,  248,  246,  247,  248,  246,  247,  248,
 /*  2820 */   246,  247,  248,  246,  247,  248,  176,  177,  268,  176,
 /*  2830 */   177,  268,  246,  247,  248,  246,  247,  248,  246,  247,
 /*  2840 */   248,  246,  247,  248,  246,  247,  248,  268,  176,  177,
 /*  2850 */   268,  268,  268,  268,  268,  176,  177,  268,  176,  177,
 /*  2860 */   246,  247,  248,  246,  247,  248,  246,  247,  248,  246,
 /*  2870 */   247,  248,  176,  177,  268,  176,  177,  268,  268,  268,
 /*  2880 */   268,  268,  268,  268,  268,  268,  268,  268,  268,  268,
 /*  2890 */   268,  268,  268,  268,  268,  268,  246,  247,  248,  246,
 /*  2900 */   247,  248,  268,  268,  268,  268,  268,  268,  268,  268,
 /*  2910 */   268,  268,  268,  268,  268,  268,  268,  268,  246,  247,
 /*  2920 */   248,  268,  268,  268,  268,  246,  247,  248,  246,  247,
 /*  2930 */   248,  268,  268,  268,  268,  268,  268,  268,  268,  268,
 /*  2940 */   268,  268,  246,  247,  248,  246,  247,  248,
};
#define YY_SHIFT_USE_DFLT (2948)
#define YY_SHIFT_COUNT    (402)
#define YY_SHIFT_MIN      (-48)
#define YY_SHIFT_MAX      (2585)
static const short yy_shift_ofst[] = {
 /*     0 */  2948,  241,  -33,  241,  104,  241,  241,  241,  241,  241,
 /*    10 */   241,  241,  452,  114, 2010, 1659,  353,  229,   67,   67,
 /*    20 */  2555, 2555, 2555, 2585, 2585, 2555,  474,  474,  474,  474,
 /*    30 */   474,  474, 1564, 1879, 2170, 2585, 2585, 2585, 2585, 2585,
 /*    40 */  2585, 2585, 1752,  441, 1388,  474, 2542, 2585, 2585, 2585,
 /*    50 */  2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585,
 /*    60 */  2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585,
 /*    70 */  2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585,
 /*    80 */  2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585,
 /*    90 */  2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585,
 /*   100 */  2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585, 1881,
 /*   110 */  2585, 2585, 2585, 2585, 2585, 2585, 2585, 2585,  -38,   61,
 /*   120 */    -5,   43,  110,  346,  139,  106,   24,  123,  171,  184,
 /*   130 */   171,  184, 2948, 1390,  222,   72,  360,  360,  360,  360,
 /*   140 */   120,  360,  120,  120,  360,  656,  271,  360,  360,  261,
 /*   150 */   644,  658,  665,  662,  727,  778,  779,  777,  727,  821,
 /*   160 */   123,  821,  806,  171,  171,  862,   43,  878,  778,  917,
 /*   170 */   778,  913, 2948, 2948, 2948, 2948, 2948, 2948, 2948, 2948,
 /*   180 */   597,  660,  723,  786,  834,  885,  933,  981, 1029, 1077,
 /*   190 */  1125, 1173, 1221, 1292, 1340, 1390, 1390, 1390, 1390, 1390,
 /*   200 */  1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390,
 /*   210 */  1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1522,
 /*   220 */  1858, 2506, 2534, 2534, 2534, 1243, 1243, 1243, 1243, 1243,
 /*   230 */  1243, 1427, 1480,   51,  188,  321,  321,  321,  -32,  -32,
 /*   240 */   596,  708,  359,  108,    4,  -22,  388,  -48,  365,  427,
 /*   250 */   462,  470,  471,  475,  651,  464,  480,  593,  717, 1336,
 /*   260 */   733,  329,  434,  721, 1381,  836,  836,  836,  836,  836,
 /*   270 */   959,  972,  974,  985, 1008, 1010, 1027,  985, 1019, 1020,
 /*   280 */   985,  985, 1026, 1011, 1071, 1072, 1073, 1074, 1053, 1054,
 /*   290 */  1058, 1105, 1122, 1123, 1103, 1104, 1107, 1116, 1142, 1153,
 /*   300 */  1155, 1172, 1156, 1158, 1176, 1205, 1223, 1224, 1220, 1212,
 /*   310 */  1289, 1339, 1329, 1334, 1335, 1319, 1322, 1354, 1432, 1420,
 /*   320 */  1391, 1393, 1279, 1425, 1399, 1400, 1419, 1428, 1431, 1481,
 /*   330 */   665, 1475, 1476, 1485, 1412, 1527, 1510, 1411, 1521, 1511,
 /*   340 */  1577, 1461, 1539, 1537, 1538, 1544, 1547, 1550, 1610, 1497,
 /*   350 */  1570, 1559, 1574, 1515, 1591, 1614, 1615, 1587, 1618, 1619,
 /*   360 */  1604, 1626, 1647,  985, 1651, 1620, 1652, 1626, 1628, 1667,
 /*   370 */  1616, 1622, 1635, 1645, 1629, 1672, 1640, 1678, 1637, 1656,
 /*   380 */  1666, 1657, 1703, 1723, 1671, 1660, 1676, 1683, 1665, 1687,
 /*   390 */  1690, 1743, 1704, 1712, 1710, 1725, 1728, 1732, 1781, 1744,
 /*   400 */  1748, 1745, 1657,
};
#define YY_REDUCE_USE_DFLT (-195)
#define YY_REDUCE_COUNT (179)
#define YY_REDUCE_MIN   (-194)
#define YY_REDUCE_MAX   (2699)
static const short yy_reduce_ofst[] = {
 /*     0 */  -140, 1404, 1494, 1606, 1741, 1784, 1875, 1918, 2031, 2104,
 /*    10 */  2145, 2257, 1562, -134, -134, 1413,   38,  -39,  129, 1601,
 /*    20 */   243,  252, 1087,  263, 1520, -154,  306, 1061, 1244, 1276,
 /*    30 */  1305, 1364, 1395, 1468,  -16,  116, 1593, 1600,  465, 1603,
 /*    40 */  1730,  473, 1455,  138,  -34,  242,  469,  529,  532, 1679,
 /*    50 */  1734, 1780, 1807, 1911, 1914, 1941, 2018, 2021, 2024, 2052,
 /*    60 */  2078, 2141, 2165, 2171, 2177, 2191, 2198, 2202, 2205, 2208,
 /*    70 */  2232, 2254, 2374, 2401, 2406, 2414, 2417, 2425, 2455, 2459,
 /*    80 */  2512, 2532, 2535, 2538, 2541, 2556, 2559, 2562, 2565, 2568,
 /*    90 */  2571, 2574, 2577, 2586, 2589, 2592, 2595, 2598, 2614, 2617,
 /*   100 */  2620, 2623, 2650, 2653, 2672, 2679, 2682, 2696, 2699, 1464,
 /*   110 */  -147, 1204, 1320, 1328, 1433, 1566, 1596, 1724,   64, 1203,
 /*   120 */   132, 1429, -115, -194,  -89,  -54,  -11,  -30,  -54,  131,
 /*   130 */    96,  181,  164,   62,   77,  112,  127,  182,  233,  237,
 /*   140 */   232,  319,  312,  326,  356,  327,  349,  399,  454,  458,
 /*   150 */   492,  491,  502,  520,  571,  655,  588,  637,  619,  638,
 /*   160 */   610,  639,  647,  327,  327,  694,  728,  755,  757,  747,
 /*   170 */   760,  798,  773,  794,  799,  763,  765,  807,  826,  845,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1048, 1137, 1422, 1137, 1422, 1422, 1422, 1422, 1422, 1422,
 /*    10 */  1422, 1422, 1370, 1228, 1228, 1228, 1422, 1422, 1228, 1228,
 /*    20 */  1329, 1329, 1329, 1422, 1370, 1329, 1422, 1422, 1422, 1422,
 /*    30 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1057, 1422,
 /*    40 */  1422, 1057, 1422, 1228, 1422, 1422, 1422, 1422, 1422, 1422,
 /*    50 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*    60 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*    70 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*    80 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*    90 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   100 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   110 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1262,
 /*   120 */  1422, 1116, 1422, 1168, 1382, 1225, 1262, 1422, 1225, 1422,
 /*   130 */  1401, 1422, 1138, 1154, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   140 */  1151, 1422, 1151, 1151, 1422, 1383, 1422, 1422, 1422, 1422,
 /*   150 */  1062, 1170, 1137, 1422, 1133, 1390, 1231, 1422, 1133, 1422,
 /*   160 */  1422, 1422, 1253, 1226, 1216, 1212, 1393, 1392, 1390, 1112,
 /*   170 */  1390, 1422, 1121, 1064, 1078, 1137, 1137, 1137, 1097, 1078,
 /*   180 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   190 */  1422, 1422, 1422, 1422, 1422, 1152, 1261, 1384, 1379, 1327,
 /*   200 */  1412, 1361, 1380, 1394, 1118, 1331, 1324, 1323, 1322, 1321,
 /*   210 */  1320, 1319, 1318, 1317, 1316, 1315, 1314, 1313, 1330, 1326,
 /*   220 */  1312, 1311, 1307, 1306, 1305, 1304, 1303, 1302, 1301, 1300,
 /*   230 */  1299, 1298, 1310, 1309, 1308, 1297, 1296, 1295, 1287, 1288,
 /*   240 */  1061, 1422, 1410, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   250 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   260 */  1422, 1422, 1422, 1422, 1422, 1294, 1293, 1291, 1290, 1289,
 /*   270 */  1422, 1422, 1422, 1063, 1422, 1422, 1422, 1069, 1422, 1422,
 /*   280 */  1182, 1181, 1422, 1422, 1422, 1071, 1422, 1422, 1422, 1422,
 /*   290 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   300 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   310 */  1422, 1260, 1422, 1407, 1369, 1422, 1422, 1381, 1422, 1422,
 /*   320 */  1422, 1422, 1373, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   330 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   340 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1266, 1422, 1422,
 /*   350 */  1201, 1422, 1403, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   360 */  1422, 1422, 1422, 1207, 1422, 1422, 1422, 1243, 1422, 1117,
 /*   370 */  1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   380 */  1292, 1415, 1266, 1422, 1422, 1422, 1422, 1422, 1422, 1422,
 /*   390 */  1422, 1422, 1422, 1094, 1422, 1422, 1093, 1422, 1422, 1422,
 /*   400 */  1422, 1422, 1058,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*         EQ => nothing */
    0,  /*      MULEQ => nothing */
    0,  /*      DIVEQ => nothing */
    0,  /*      MODEQ => nothing */
    0,  /*      ADDEQ => nothing */
    0,  /*      SUBEQ => nothing */
    0,  /*      LSHEQ => nothing */
    0,  /*      RSHEQ => nothing */
    0,  /*      ANDEQ => nothing */
    0,  /*       OREQ => nothing */
    0,  /*      XOREQ => nothing */
    0,  /*     URSHEQ => nothing */
    0,  /*   QUESTION => nothing */
    0,  /*      COLON => nothing */
    0,  /*       OROR => nothing */
    0,  /*     ANDAND => nothing */
    0,  /*       EQEQ => nothing */
    0,  /*        NEQ => nothing */
    0,  /*   APPROXEQ => nothing */
    0,  /*         LT => nothing */
    0,  /*         GT => nothing */
    0,  /*       LTEQ => nothing */
    0,  /*       GTEQ => nothing */
    0,  /*     LTGTEQ => nothing */
    0,  /*         IS => nothing */
    0,  /*     DOTDOT => nothing */
    0,  /*         OR => nothing */
    0,  /*        XOR => nothing */
    0,  /*        AND => nothing */
    0,  /*        LSH => nothing */
    0,  /*        RSH => nothing */
    0,  /*       URSH => nothing */
    0,  /*        SUB => nothing */
    0,  /*        ADD => nothing */
    0,  /*        MUL => nothing */
    0,  /*        DIV => nothing */
    0,  /*        MOD => nothing */
    0,  /*  CROSSPROD => nothing */
    0,  /*    DOTPROD => nothing */
    0,  /*        POW => nothing */
    0,  /*      UNARY => nothing */
    0,  /*     ADDADD => nothing */
    0,  /*     SUBSUB => nothing */
    0,  /*        DOT => nothing */
    0,  /*     LPAREN => nothing */
    0,  /*   LBRACKET => nothing */
    0,  /*      SCOPE => nothing */
    0,  /*        EOF => nothing */
    0,  /*  SEMICOLON => nothing */
    0,  /*      COMMA => nothing */
    0,  /*    INCLUDE => nothing */
    0,  /*     EXTEND => nothing */
    0,  /*      CLASS => nothing */
    0,  /* IDENTIFIER => nothing */
    0,  /*   ABSTRACT => nothing */
    0,  /*     NATIVE => nothing */
    0,  /*         UI => nothing */
    0,  /*       PLAY => nothing */
    0,  /*   REPLACES => nothing */
    0,  /*    VERSION => nothing */
    0,  /*   STRCONST => nothing */
    0,  /*     RPAREN => nothing */
    0,  /*     ACTION => nothing */
   54,  /*    DEFAULT => IDENTIFIER */
   54,  /*      COLOR => IDENTIFIER */
    0,  /*     LBRACE => nothing */
    0,  /*     RBRACE => nothing */
    0,  /*      MIXIN => nothing */
   54,  /*   PROPERTY => IDENTIFIER */
    0,  /*    FLAGDEF => nothing */
    0,  /*   INTCONST => nothing */
    0,  /*     STRUCT => nothing */
    0,  /* CLEARSCOPE => nothing */
    0,  /*      CONST => nothing */
    0,  /*       ENUM => nothing */
    0,  /*     STATES => nothing */
    0,  /*        NWS => nothing */
    0,  /*       STOP => nothing */
    0,  /*       WAIT => nothing */
    0,  /*       FAIL => nothing */
    0,  /*       LOOP => nothing */
    0,  /*       GOTO => nothing */
    0,  /*      SUPER => nothing */
    0,  /*     BRIGHT => nothing */
    0,  /*       FAST => nothing */
    0,  /*       SLOW => nothing */
    0,  /*    NODELAY => nothing */
    0,  /*   CANRAISE => nothing */
    0,  /*     OFFSET => nothing */
    0,  /*      LIGHT => nothing */
   54,  /*      SBYTE => IDENTIFIER */
   54,  /*       BYTE => IDENTIFIER */
   54,  /*      SHORT => IDENTIFIER */
   54,  /*     USHORT => IDENTIFIER */
   54,  /*        INT => IDENTIFIER */
   54,  /*       UINT => IDENTIFIER */
   54,  /*       BOOL => IDENTIFIER */
   54,  /*      FLOAT => IDENTIFIER */
   54,  /*     DOUBLE => IDENTIFIER */
   54,  /*    VECTOR2 => IDENTIFIER */
   54,  /*    VECTOR3 => IDENTIFIER */
   54,  /*    VECTOR4 => IDENTIFIER */
   54,  /*       NAME => IDENTIFIER */
   54,  /*      SOUND => IDENTIFIER */
   54,  /*      STATE => IDENTIFIER */
    0,  /*        LET => nothing */
    0,  /*     ATSIGN => nothing */
    0,  /*   READONLY => nothing */
   54,  /*     STRING => IDENTIFIER */
   54,  /*        MAP => IDENTIFIER */
   54,  /* MAPITERATOR => IDENTIFIER */
   54,  /*      ARRAY => IDENTIFIER */
   54,  /*       VOID => IDENTIFIER */
   54,  /*      UINT8 => IDENTIFIER */
   54,  /*       INT8 => IDENTIFIER */
   54,  /*     UINT16 => IDENTIFIER */
   54,  /*      INT16 => IDENTIFIER */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  ZCCParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "EQ",            "MULEQ",         "DIVEQ",       
  "MODEQ",         "ADDEQ",         "SUBEQ",         "LSHEQ",       
  "RSHEQ",         "ANDEQ",         "OREQ",          "XOREQ",       
  "URSHEQ",        "QUESTION",      "COLON",         "OROR",        
  "ANDAND",        "EQEQ",          "NEQ",           "APPROXEQ",    
  "LT",            "GT",            "LTEQ",          "GTEQ",        
  "LTGTEQ",        "IS",            "DOTDOT",        "OR",          
  "XOR",           "AND",           "LSH",           "RSH",         
  "URSH",          "SUB",           "ADD",           "MUL",         
  "DIV",           "MOD",           "CROSSPROD",     "DOTPROD",     
  "POW",           "UNARY",         "ADDADD",        "SUBSUB",      
  "DOT",           "LPAREN",        "LBRACKET",      "SCOPE",       
  "EOF",           "SEMICOLON",     "COMMA",         "INCLUDE",     
  "EXTEND",        "CLASS",         "IDENTIFIER",    "ABSTRACT",    
  "NATIVE",        "UI",            "PLAY",          "REPLACES",    
  "VERSION",       "STRCONST",      "RPAREN",        "ACTION",      
  "DEFAULT",       "COLOR",         "LBRACE",        "RBRACE",      
  "MIXIN",         "PROPERTY",      "FLAGDEF",       "INTCONST",    
  "STRUCT",        "CLEARSCOPE",    "CONST",         "ENUM",        
  "STATES",        "NWS",           "STOP",          "WAIT",        
  "FAIL",          "LOOP",          "GOTO",          "SUPER",       
  "BRIGHT",        "FAST",          "SLOW",          "NODELAY",     
  "CANRAISE",      "OFFSET",        "LIGHT",         "SBYTE",       
  "BYTE",          "SHORT",         "USHORT",        "INT",         
  "UINT",          "BOOL",          "FLOAT",         "DOUBLE",      
  "VECTOR2",       "VECTOR3",       "VECTOR4",       "NAME",        
  "SOUND",         "STATE",         "LET",           "ATSIGN",      
  "READONLY",      "STRING",        "MAP",           "MAPITERATOR", 
  "ARRAY",         "VOID",          "UINT8",         "INT8",        
  "UINT16",        "INT16",         "RBRACKET",      "DEPRECATED",  
  "STATIC",        "PRIVATE",       "PROTECTED",     "LATENT",      
  "FINAL",         "META",          "TRANSIENT",     "INTERNAL",    
  "VIRTUAL",       "OVERRIDE",      "VARARG",        "VIRTUALSCOPE",
  "ELLIPSIS",      "IN",            "OUT",           "OPTIONAL",    
  "TILDE",         "BANG",          "SIZEOF",        "ALIGNOF",     
  "UINTCONST",     "FLOATCONST",    "NAMECONST",     "FALSE",       
  "TRUE",          "NULLPTR",       "STATICCONST",   "CONTINUE",    
  "BREAK",         "RETURN",        "DO",            "FOR",         
  "FOREACH",       "WHILE",         "UNTIL",         "IF",          
  "ELSE",          "SWITCH",        "CASE",          "error",       
  "declarator",    "declarator_no_fun",  "opt_func_body",  "function_body",
  "main",          "translation_unit",  "external_declaration",  "mixin_definition",
  "class_definition",  "struct_def",    "enum_def",      "const_def",   
  "include_def",   "opt_semicolon",  "opt_comma",     "opt_expr",    
  "expr",          "string_constant",  "class_head",    "class_innards",
  "class_member",  "class_body",    "class_ancestry",  "class_flags", 
  "dottable_id",   "mixin_statement",  "property_def",  "flag_def",    
  "states_def",    "default_def",   "staticarray_statement",  "opt_struct_body",
  "struct_body",   "struct_member",  "identifier_list",  "states_opt",  
  "struct_flags",  "enum_list",     "opt_enum_list",  "enumerator",  
  "enum_type",     "int_type",      "mixin_class_definition",  "mixin_class_body",
  "mixin_class_member",  "states_body",   "state_line",    "state_label", 
  "state_flow",    "state_flow_type",  "state_goto_offset",  "state_action",
  "state_call",    "state_call_params",  "state_opts",    "states_opts", 
  "scanner_mode",  "light_list",    "statement_list",  "func_expr_list",
  "default_statement_list",  "default_statement",  "property_statement",  "flag_statement",
  "expr_list",     "type_name",     "type_name1",    "aggregate_type",
  "type",          "type_list",     "type_list_or_void",  "type_or_array",
  "class_restrictor",  "array_size",    "array_size_expr",  "variables_or_function",
  "decl_flags",    "func_params",   "func_const",    "variable_list",
  "variable_name",  "decl_flag",     "opt_deprecation_message",  "func_param_list",
  "func_param",    "func_param_flags",  "primary",       "unary_expr",  
  "constant",      "func_expr_item",  "named_expr",    "compound_statement",
  "statement",     "labeled_statement",  "expression_statement",  "selection_statement",
  "iteration_statement",  "array_iteration_statement",  "jump_statement",  "assign_statement",
  "assign_decl_statement",  "local_var",     "while_or_until",  "for_init",    
  "for_bump",      "if_front",      "variable_list_with_init",  "var_init",    
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "main ::= translation_unit",
 /*   1 */ "translation_unit ::=",
 /*   2 */ "translation_unit ::= translation_unit external_declaration",
 /*   3 */ "translation_unit ::= error",
 /*   4 */ "external_declaration ::= mixin_definition",
 /*   5 */ "external_declaration ::= class_definition",
 /*   6 */ "external_declaration ::= struct_def",
 /*   7 */ "external_declaration ::= enum_def",
 /*   8 */ "external_declaration ::= const_def",
 /*   9 */ "external_declaration ::= include_def",
 /*  10 */ "opt_expr ::=",
 /*  11 */ "include_def ::= INCLUDE string_constant",
 /*  12 */ "class_definition ::= class_head class_body",
 /*  13 */ "class_head ::= EXTEND CLASS IDENTIFIER",
 /*  14 */ "class_head ::= CLASS IDENTIFIER class_ancestry class_flags",
 /*  15 */ "class_ancestry ::=",
 /*  16 */ "class_ancestry ::= COLON dottable_id",
 /*  17 */ "class_flags ::=",
 /*  18 */ "class_flags ::= class_flags ABSTRACT",
 /*  19 */ "class_flags ::= class_flags NATIVE",
 /*  20 */ "class_flags ::= class_flags UI",
 /*  21 */ "class_flags ::= class_flags PLAY",
 /*  22 */ "class_flags ::= class_flags REPLACES dottable_id",
 /*  23 */ "class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN",
 /*  24 */ "dottable_id ::= IDENTIFIER",
 /*  25 */ "dottable_id ::= ACTION",
 /*  26 */ "dottable_id ::= dottable_id DOT IDENTIFIER",
 /*  27 */ "dottable_id ::= dottable_id DOT DEFAULT",
 /*  28 */ "dottable_id ::= dottable_id DOT COLOR",
 /*  29 */ "class_body ::= SEMICOLON class_innards EOF",
 /*  30 */ "class_body ::= LBRACE class_innards RBRACE",
 /*  31 */ "class_innards ::=",
 /*  32 */ "class_innards ::= class_innards class_member",
 /*  33 */ "class_member ::= declarator",
 /*  34 */ "class_member ::= mixin_statement",
 /*  35 */ "class_member ::= enum_def",
 /*  36 */ "class_member ::= struct_def",
 /*  37 */ "class_member ::= states_def",
 /*  38 */ "class_member ::= default_def",
 /*  39 */ "class_member ::= const_def",
 /*  40 */ "class_member ::= property_def",
 /*  41 */ "class_member ::= flag_def",
 /*  42 */ "class_member ::= staticarray_statement",
 /*  43 */ "mixin_statement ::= MIXIN IDENTIFIER SEMICOLON",
 /*  44 */ "property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON",
 /*  45 */ "flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON",
 /*  46 */ "identifier_list ::= IDENTIFIER",
 /*  47 */ "identifier_list ::= states_opt COMMA IDENTIFIER",
 /*  48 */ "struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  49 */ "struct_def ::= EXTEND STRUCT IDENTIFIER LBRACE opt_struct_body RBRACE opt_semicolon",
 /*  50 */ "struct_flags ::=",
 /*  51 */ "struct_flags ::= struct_flags UI",
 /*  52 */ "struct_flags ::= struct_flags PLAY",
 /*  53 */ "struct_flags ::= struct_flags CLEARSCOPE",
 /*  54 */ "struct_flags ::= struct_flags NATIVE",
 /*  55 */ "struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN",
 /*  56 */ "opt_struct_body ::=",
 /*  57 */ "opt_struct_body ::= error",
 /*  58 */ "struct_body ::= struct_body struct_member",
 /*  59 */ "struct_member ::= declarator",
 /*  60 */ "struct_member ::= enum_def",
 /*  61 */ "struct_member ::= const_def",
 /*  62 */ "struct_member ::= staticarray_statement",
 /*  63 */ "const_def ::= CONST IDENTIFIER EQ expr SEMICOLON",
 /*  64 */ "enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon",
 /*  65 */ "enum_type ::=",
 /*  66 */ "enum_type ::= COLON int_type",
 /*  67 */ "enum_list ::= error",
 /*  68 */ "enum_list ::= enum_list COMMA enumerator",
 /*  69 */ "opt_enum_list ::=",
 /*  70 */ "enumerator ::= IDENTIFIER",
 /*  71 */ "enumerator ::= IDENTIFIER EQ expr",
 /*  72 */ "mixin_definition ::= mixin_class_definition",
 /*  73 */ "mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE",
 /*  74 */ "mixin_class_body ::=",
 /*  75 */ "mixin_class_body ::= mixin_class_body mixin_class_member",
 /*  76 */ "mixin_class_member ::= declarator",
 /*  77 */ "mixin_class_member ::= enum_def",
 /*  78 */ "mixin_class_member ::= struct_def",
 /*  79 */ "mixin_class_member ::= states_def",
 /*  80 */ "mixin_class_member ::= default_def",
 /*  81 */ "mixin_class_member ::= const_def",
 /*  82 */ "mixin_class_member ::= property_def",
 /*  83 */ "mixin_class_member ::= flag_def",
 /*  84 */ "mixin_class_member ::= staticarray_statement",
 /*  85 */ "states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE",
 /*  86 */ "states_opts ::=",
 /*  87 */ "states_opts ::= LPAREN states_opt RPAREN",
 /*  88 */ "states_opt ::= IDENTIFIER",
 /*  89 */ "states_opt ::= states_opt COMMA IDENTIFIER",
 /*  90 */ "scanner_mode ::=",
 /*  91 */ "states_body ::=",
 /*  92 */ "states_body ::= error",
 /*  93 */ "states_body ::= states_body state_line",
 /*  94 */ "states_body ::= states_body state_label",
 /*  95 */ "states_body ::= states_body state_flow",
 /*  96 */ "state_label ::= NWS COLON",
 /*  97 */ "state_flow_type ::= STOP",
 /*  98 */ "state_flow_type ::= WAIT",
 /*  99 */ "state_flow_type ::= FAIL",
 /* 100 */ "state_flow_type ::= LOOP",
 /* 101 */ "state_flow_type ::= GOTO dottable_id state_goto_offset",
 /* 102 */ "state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset",
 /* 103 */ "state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset",
 /* 104 */ "state_goto_offset ::=",
 /* 105 */ "state_goto_offset ::= ADD expr",
 /* 106 */ "state_line ::= NWS NWS expr state_opts state_action",
 /* 107 */ "state_opts ::=",
 /* 108 */ "state_opts ::= state_opts BRIGHT",
 /* 109 */ "state_opts ::= state_opts FAST",
 /* 110 */ "state_opts ::= state_opts SLOW",
 /* 111 */ "state_opts ::= state_opts NODELAY",
 /* 112 */ "state_opts ::= state_opts CANRAISE",
 /* 113 */ "state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN",
 /* 114 */ "state_opts ::= state_opts LIGHT LPAREN light_list RPAREN",
 /* 115 */ "light_list ::= STRCONST",
 /* 116 */ "light_list ::= light_list COMMA STRCONST",
 /* 117 */ "state_action ::= LBRACE statement_list scanner_mode RBRACE",
 /* 118 */ "state_action ::= LBRACE scanner_mode RBRACE",
 /* 119 */ "state_action ::= LBRACE error scanner_mode RBRACE",
 /* 120 */ "state_action ::= state_call scanner_mode SEMICOLON",
 /* 121 */ "state_call ::=",
 /* 122 */ "state_call ::= IDENTIFIER state_call_params",
 /* 123 */ "state_call_params ::=",
 /* 124 */ "state_call_params ::= LPAREN func_expr_list RPAREN",
 /* 125 */ "default_def ::= DEFAULT LBRACE RBRACE",
 /* 126 */ "default_def ::= DEFAULT LBRACE default_statement_list RBRACE",
 /* 127 */ "default_def ::= DEFAULT LBRACE error RBRACE",
 /* 128 */ "default_statement_list ::= default_statement",
 /* 129 */ "default_statement_list ::= default_statement_list default_statement",
 /* 130 */ "default_statement ::= SEMICOLON",
 /* 131 */ "default_statement ::= error SEMICOLON",
 /* 132 */ "default_statement ::= property_statement",
 /* 133 */ "default_statement ::= flag_statement",
 /* 134 */ "flag_statement ::= ADD dottable_id",
 /* 135 */ "flag_statement ::= SUB dottable_id",
 /* 136 */ "property_statement ::= dottable_id expr_list SEMICOLON",
 /* 137 */ "property_statement ::= dottable_id SEMICOLON",
 /* 138 */ "int_type ::= SBYTE",
 /* 139 */ "int_type ::= BYTE",
 /* 140 */ "int_type ::= SHORT",
 /* 141 */ "int_type ::= USHORT",
 /* 142 */ "int_type ::= INT",
 /* 143 */ "int_type ::= UINT",
 /* 144 */ "type_name1 ::= BOOL",
 /* 145 */ "type_name1 ::= FLOAT",
 /* 146 */ "type_name1 ::= DOUBLE",
 /* 147 */ "type_name1 ::= VECTOR2",
 /* 148 */ "type_name1 ::= VECTOR3",
 /* 149 */ "type_name1 ::= VECTOR4",
 /* 150 */ "type_name1 ::= NAME",
 /* 151 */ "type_name1 ::= SOUND",
 /* 152 */ "type_name1 ::= STATE",
 /* 153 */ "type_name1 ::= COLOR",
 /* 154 */ "type_name1 ::= LET",
 /* 155 */ "type_name ::= type_name1",
 /* 156 */ "type_name ::= IDENTIFIER",
 /* 157 */ "type_name ::= ATSIGN IDENTIFIER",
 /* 158 */ "type_name ::= READONLY LT IDENTIFIER GT",
 /* 159 */ "type_name ::= READONLY LT ATSIGN IDENTIFIER GT",
 /* 160 */ "type_name ::= DOT dottable_id",
 /* 161 */ "aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT",
 /* 162 */ "aggregate_type ::= MAPITERATOR LT type_or_array COMMA type_or_array GT",
 /* 163 */ "aggregate_type ::= ARRAY LT type_or_array GT",
 /* 164 */ "aggregate_type ::= CLASS class_restrictor",
 /* 165 */ "class_restrictor ::=",
 /* 166 */ "class_restrictor ::= LT dottable_id GT",
 /* 167 */ "type ::= type_name",
 /* 168 */ "type ::= aggregate_type",
 /* 169 */ "type_or_array ::= type array_size",
 /* 170 */ "type_list ::= type_list COMMA type_or_array",
 /* 171 */ "type_list_or_void ::= VOID",
 /* 172 */ "array_size_expr ::= LBRACKET opt_expr RBRACKET",
 /* 173 */ "array_size ::= array_size array_size_expr",
 /* 174 */ "declarator ::= decl_flags type_list_or_void variables_or_function",
 /* 175 */ "variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body",
 /* 176 */ "variables_or_function ::= variable_list SEMICOLON",
 /* 177 */ "variables_or_function ::= error SEMICOLON",
 /* 178 */ "variable_name ::= IDENTIFIER",
 /* 179 */ "variable_name ::= IDENTIFIER array_size",
 /* 180 */ "variable_list ::= variable_list COMMA variable_name",
 /* 181 */ "decl_flags ::=",
 /* 182 */ "decl_flags ::= decl_flags decl_flag",
 /* 183 */ "decl_flags ::= decl_flags ACTION states_opts",
 /* 184 */ "opt_deprecation_message ::=",
 /* 185 */ "opt_deprecation_message ::= COMMA STRCONST",
 /* 186 */ "decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN",
 /* 187 */ "decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN",
 /* 188 */ "decl_flag ::= NATIVE",
 /* 189 */ "decl_flag ::= STATIC",
 /* 190 */ "decl_flag ::= PRIVATE",
 /* 191 */ "decl_flag ::= PROTECTED",
 /* 192 */ "decl_flag ::= LATENT",
 /* 193 */ "decl_flag ::= FINAL",
 /* 194 */ "decl_flag ::= META",
 /* 195 */ "decl_flag ::= TRANSIENT",
 /* 196 */ "decl_flag ::= READONLY",
 /* 197 */ "decl_flag ::= INTERNAL",
 /* 198 */ "decl_flag ::= VIRTUAL",
 /* 199 */ "decl_flag ::= OVERRIDE",
 /* 200 */ "decl_flag ::= ABSTRACT",
 /* 201 */ "decl_flag ::= VARARG",
 /* 202 */ "decl_flag ::= UI",
 /* 203 */ "decl_flag ::= PLAY",
 /* 204 */ "decl_flag ::= CLEARSCOPE",
 /* 205 */ "decl_flag ::= VIRTUALSCOPE",
 /* 206 */ "func_const ::=",
 /* 207 */ "func_const ::= CONST",
 /* 208 */ "opt_func_body ::= SEMICOLON",
 /* 209 */ "func_params ::=",
 /* 210 */ "func_params ::= VOID",
 /* 211 */ "func_params ::= func_param_list COMMA ELLIPSIS",
 /* 212 */ "func_param_list ::= func_param_list COMMA func_param",
 /* 213 */ "func_param ::= func_param_flags type IDENTIFIER",
 /* 214 */ "func_param ::= func_param_flags type IDENTIFIER EQ expr",
 /* 215 */ "func_param_flags ::=",
 /* 216 */ "func_param_flags ::= func_param_flags IN",
 /* 217 */ "func_param_flags ::= func_param_flags OUT",
 /* 218 */ "func_param_flags ::= func_param_flags OPTIONAL",
 /* 219 */ "primary ::= IDENTIFIER",
 /* 220 */ "primary ::= SUPER",
 /* 221 */ "primary ::= constant",
 /* 222 */ "primary ::= LPAREN expr COMMA expr COMMA expr COMMA expr RPAREN",
 /* 223 */ "primary ::= LPAREN expr COMMA expr COMMA expr RPAREN",
 /* 224 */ "primary ::= LPAREN expr COMMA expr RPAREN",
 /* 225 */ "primary ::= LPAREN expr RPAREN",
 /* 226 */ "primary ::= primary LPAREN func_expr_list RPAREN",
 /* 227 */ "primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN",
 /* 228 */ "primary ::= primary LBRACKET expr RBRACKET",
 /* 229 */ "primary ::= primary DOT IDENTIFIER",
 /* 230 */ "primary ::= primary ADDADD",
 /* 231 */ "primary ::= primary SUBSUB",
 /* 232 */ "unary_expr ::= SUB unary_expr",
 /* 233 */ "unary_expr ::= ADD unary_expr",
 /* 234 */ "unary_expr ::= SUBSUB unary_expr",
 /* 235 */ "unary_expr ::= ADDADD unary_expr",
 /* 236 */ "unary_expr ::= TILDE unary_expr",
 /* 237 */ "unary_expr ::= BANG unary_expr",
 /* 238 */ "unary_expr ::= SIZEOF unary_expr",
 /* 239 */ "unary_expr ::= ALIGNOF unary_expr",
 /* 240 */ "expr ::= expr ADD expr",
 /* 241 */ "expr ::= expr SUB expr",
 /* 242 */ "expr ::= expr MUL expr",
 /* 243 */ "expr ::= expr DIV expr",
 /* 244 */ "expr ::= expr MOD expr",
 /* 245 */ "expr ::= expr POW expr",
 /* 246 */ "expr ::= expr CROSSPROD expr",
 /* 247 */ "expr ::= expr DOTPROD expr",
 /* 248 */ "expr ::= expr LSH expr",
 /* 249 */ "expr ::= expr RSH expr",
 /* 250 */ "expr ::= expr URSH expr",
 /* 251 */ "expr ::= expr DOTDOT expr",
 /* 252 */ "expr ::= expr LT expr",
 /* 253 */ "expr ::= expr GT expr",
 /* 254 */ "expr ::= expr LTEQ expr",
 /* 255 */ "expr ::= expr GTEQ expr",
 /* 256 */ "expr ::= expr LTGTEQ expr",
 /* 257 */ "expr ::= expr IS expr",
 /* 258 */ "expr ::= expr EQEQ expr",
 /* 259 */ "expr ::= expr NEQ expr",
 /* 260 */ "expr ::= expr APPROXEQ expr",
 /* 261 */ "expr ::= expr AND expr",
 /* 262 */ "expr ::= expr XOR expr",
 /* 263 */ "expr ::= expr OR expr",
 /* 264 */ "expr ::= expr ANDAND expr",
 /* 265 */ "expr ::= expr OROR expr",
 /* 266 */ "expr ::= expr EQ expr",
 /* 267 */ "expr ::= expr ADDEQ expr",
 /* 268 */ "expr ::= expr SUBEQ expr",
 /* 269 */ "expr ::= expr MULEQ expr",
 /* 270 */ "expr ::= expr DIVEQ expr",
 /* 271 */ "expr ::= expr MODEQ expr",
 /* 272 */ "expr ::= expr LSHEQ expr",
 /* 273 */ "expr ::= expr RSHEQ expr",
 /* 274 */ "expr ::= expr URSHEQ expr",
 /* 275 */ "expr ::= expr ANDEQ expr",
 /* 276 */ "expr ::= expr OREQ expr",
 /* 277 */ "expr ::= expr XOREQ expr",
 /* 278 */ "expr ::= expr SCOPE expr",
 /* 279 */ "expr ::= expr QUESTION expr COLON expr",
 /* 280 */ "expr_list ::= expr_list COMMA expr",
 /* 281 */ "func_expr_list ::= func_expr_list COMMA func_expr_item",
 /* 282 */ "func_expr_item ::=",
 /* 283 */ "named_expr ::= IDENTIFIER COLON expr",
 /* 284 */ "named_expr ::= expr",
 /* 285 */ "string_constant ::= STRCONST",
 /* 286 */ "string_constant ::= string_constant STRCONST",
 /* 287 */ "constant ::= INTCONST",
 /* 288 */ "constant ::= UINTCONST",
 /* 289 */ "constant ::= FLOATCONST",
 /* 290 */ "constant ::= NAMECONST",
 /* 291 */ "constant ::= FALSE",
 /* 292 */ "constant ::= TRUE",
 /* 293 */ "constant ::= NULLPTR",
 /* 294 */ "statement ::= SEMICOLON",
 /* 295 */ "statement ::= labeled_statement",
 /* 296 */ "statement ::= compound_statement",
 /* 297 */ "statement ::= expression_statement SEMICOLON",
 /* 298 */ "statement ::= assign_statement SEMICOLON",
 /* 299 */ "statement ::= assign_decl_statement SEMICOLON",
 /* 300 */ "statement ::= local_var SEMICOLON",
 /* 301 */ "statement ::= error SEMICOLON",
 /* 302 */ "statement ::= staticarray_statement",
 /* 303 */ "staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 304 */ "staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON",
 /* 305 */ "jump_statement ::= CONTINUE SEMICOLON",
 /* 306 */ "jump_statement ::= BREAK SEMICOLON",
 /* 307 */ "jump_statement ::= RETURN SEMICOLON",
 /* 308 */ "jump_statement ::= RETURN expr_list SEMICOLON",
 /* 309 */ "compound_statement ::= LBRACE RBRACE",
 /* 310 */ "compound_statement ::= LBRACE statement_list RBRACE",
 /* 311 */ "compound_statement ::= LBRACE error RBRACE",
 /* 312 */ "statement_list ::= statement",
 /* 313 */ "statement_list ::= statement_list statement",
 /* 314 */ "expression_statement ::= expr",
 /* 315 */ "iteration_statement ::= while_or_until LPAREN expr RPAREN statement",
 /* 316 */ "iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN",
 /* 317 */ "iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement",
 /* 318 */ "array_iteration_statement ::= FOREACH LPAREN variable_name COLON expr RPAREN statement",
 /* 319 */ "while_or_until ::= WHILE",
 /* 320 */ "while_or_until ::= UNTIL",
 /* 321 */ "for_init ::= local_var",
 /* 322 */ "for_init ::= for_bump",
 /* 323 */ "for_bump ::=",
 /* 324 */ "for_bump ::= expression_statement",
 /* 325 */ "for_bump ::= for_bump COMMA expression_statement",
 /* 326 */ "selection_statement ::= if_front",
 /* 327 */ "selection_statement ::= if_front ELSE statement",
 /* 328 */ "if_front ::= IF LPAREN expr RPAREN statement",
 /* 329 */ "selection_statement ::= SWITCH LPAREN expr RPAREN statement",
 /* 330 */ "labeled_statement ::= CASE expr COLON",
 /* 331 */ "labeled_statement ::= DEFAULT COLON",
 /* 332 */ "assign_statement ::= LBRACKET expr_list RBRACKET EQ expr",
 /* 333 */ "assign_decl_statement ::= LET LBRACKET identifier_list RBRACKET EQ expr",
 /* 334 */ "local_var ::= type variable_list_with_init",
 /* 335 */ "var_init ::= IDENTIFIER",
 /* 336 */ "var_init ::= IDENTIFIER array_size",
 /* 337 */ "var_init ::= IDENTIFIER EQ expr",
 /* 338 */ "var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE",
 /* 339 */ "var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE",
 /* 340 */ "var_init ::= IDENTIFIER EQ LBRACE error RBRACE",
 /* 341 */ "variable_list_with_init ::= variable_list_with_init COMMA var_init",
 /* 342 */ "translation_unit ::= translation_unit EOF",
 /* 343 */ "opt_semicolon ::=",
 /* 344 */ "opt_semicolon ::= SEMICOLON",
 /* 345 */ "opt_comma ::=",
 /* 346 */ "opt_comma ::= COMMA",
 /* 347 */ "opt_expr ::= expr",
 /* 348 */ "opt_struct_body ::= struct_body",
 /* 349 */ "struct_body ::= struct_member",
 /* 350 */ "enum_list ::= enumerator",
 /* 351 */ "opt_enum_list ::= enum_list opt_comma",
 /* 352 */ "state_flow ::= state_flow_type scanner_mode SEMICOLON",
 /* 353 */ "type_name1 ::= int_type",
 /* 354 */ "type_or_array ::= type",
 /* 355 */ "type_list ::= type_or_array",
 /* 356 */ "type_list_or_void ::= type_list",
 /* 357 */ "array_size ::= array_size_expr",
 /* 358 */ "variable_list ::= variable_name",
 /* 359 */ "opt_func_body ::= function_body",
 /* 360 */ "func_params ::= func_param_list",
 /* 361 */ "func_param_list ::= func_param",
 /* 362 */ "primary ::= LPAREN error RPAREN",
 /* 363 */ "unary_expr ::= primary",
 /* 364 */ "expr ::= unary_expr",
 /* 365 */ "expr_list ::= expr",
 /* 366 */ "func_expr_list ::= func_expr_item",
 /* 367 */ "func_expr_item ::= named_expr",
 /* 368 */ "constant ::= string_constant",
 /* 369 */ "function_body ::= compound_statement",
 /* 370 */ "statement ::= selection_statement",
 /* 371 */ "statement ::= iteration_statement",
 /* 372 */ "statement ::= array_iteration_statement",
 /* 373 */ "statement ::= jump_statement",
 /* 374 */ "variable_list_with_init ::= var_init",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = (yyStackEntry *)malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = (yyStackEntry *)realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
      fflush(yyTraceFILE);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to ZCCParseAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to ZCCParse and ZCCParseFree.
*/
void *ZCCParseAlloc(void *(CDECL *mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  ZCCParseARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
      /* TERMINAL Destructor */
    case 1: /* EQ */
    case 2: /* MULEQ */
    case 3: /* DIVEQ */
    case 4: /* MODEQ */
    case 5: /* ADDEQ */
    case 6: /* SUBEQ */
    case 7: /* LSHEQ */
    case 8: /* RSHEQ */
    case 9: /* ANDEQ */
    case 10: /* OREQ */
    case 11: /* XOREQ */
    case 12: /* URSHEQ */
    case 13: /* QUESTION */
    case 14: /* COLON */
    case 15: /* OROR */
    case 16: /* ANDAND */
    case 17: /* EQEQ */
    case 18: /* NEQ */
    case 19: /* APPROXEQ */
    case 20: /* LT */
    case 21: /* GT */
    case 22: /* LTEQ */
    case 23: /* GTEQ */
    case 24: /* LTGTEQ */
    case 25: /* IS */
    case 26: /* DOTDOT */
    case 27: /* OR */
    case 28: /* XOR */
    case 29: /* AND */
    case 30: /* LSH */
    case 31: /* RSH */
    case 32: /* URSH */
    case 33: /* SUB */
    case 34: /* ADD */
    case 35: /* MUL */
    case 36: /* DIV */
    case 37: /* MOD */
    case 38: /* CROSSPROD */
    case 39: /* DOTPROD */
    case 40: /* POW */
    case 41: /* UNARY */
    case 42: /* ADDADD */
    case 43: /* SUBSUB */
    case 44: /* DOT */
    case 45: /* LPAREN */
    case 46: /* LBRACKET */
    case 47: /* SCOPE */
    case 48: /* EOF */
    case 49: /* SEMICOLON */
    case 50: /* COMMA */
    case 51: /* INCLUDE */
    case 52: /* EXTEND */
    case 53: /* CLASS */
    case 54: /* IDENTIFIER */
    case 55: /* ABSTRACT */
    case 56: /* NATIVE */
    case 57: /* UI */
    case 58: /* PLAY */
    case 59: /* REPLACES */
    case 60: /* VERSION */
    case 61: /* STRCONST */
    case 62: /* RPAREN */
    case 63: /* ACTION */
    case 64: /* DEFAULT */
    case 65: /* COLOR */
    case 66: /* LBRACE */
    case 67: /* RBRACE */
    case 68: /* MIXIN */
    case 69: /* PROPERTY */
    case 70: /* FLAGDEF */
    case 71: /* INTCONST */
    case 72: /* STRUCT */
    case 73: /* CLEARSCOPE */
    case 74: /* CONST */
    case 75: /* ENUM */
    case 76: /* STATES */
    case 77: /* NWS */
    case 78: /* STOP */
    case 79: /* WAIT */
    case 80: /* FAIL */
    case 81: /* LOOP */
    case 82: /* GOTO */
    case 83: /* SUPER */
    case 84: /* BRIGHT */
    case 85: /* FAST */
    case 86: /* SLOW */
    case 87: /* NODELAY */
    case 88: /* CANRAISE */
    case 89: /* OFFSET */
    case 90: /* LIGHT */
    case 91: /* SBYTE */
    case 92: /* BYTE */
    case 93: /* SHORT */
    case 94: /* USHORT */
    case 95: /* INT */
    case 96: /* UINT */
    case 97: /* BOOL */
    case 98: /* FLOAT */
    case 99: /* DOUBLE */
    case 100: /* VECTOR2 */
    case 101: /* VECTOR3 */
    case 102: /* VECTOR4 */
    case 103: /* NAME */
    case 104: /* SOUND */
    case 105: /* STATE */
    case 106: /* LET */
    case 107: /* ATSIGN */
    case 108: /* READONLY */
    case 109: /* STRING */
    case 110: /* MAP */
    case 111: /* MAPITERATOR */
    case 112: /* ARRAY */
    case 113: /* VOID */
    case 114: /* UINT8 */
    case 115: /* INT8 */
    case 116: /* UINT16 */
    case 117: /* INT16 */
    case 118: /* RBRACKET */
    case 119: /* DEPRECATED */
    case 120: /* STATIC */
    case 121: /* PRIVATE */
    case 122: /* PROTECTED */
    case 123: /* LATENT */
    case 124: /* FINAL */
    case 125: /* META */
    case 126: /* TRANSIENT */
    case 127: /* INTERNAL */
    case 128: /* VIRTUAL */
    case 129: /* OVERRIDE */
    case 130: /* VARARG */
    case 131: /* VIRTUALSCOPE */
    case 132: /* ELLIPSIS */
    case 133: /* IN */
    case 134: /* OUT */
    case 135: /* OPTIONAL */
    case 136: /* TILDE */
    case 137: /* BANG */
    case 138: /* SIZEOF */
    case 139: /* ALIGNOF */
    case 140: /* UINTCONST */
    case 141: /* FLOATCONST */
    case 142: /* NAMECONST */
    case 143: /* FALSE */
    case 144: /* TRUE */
    case 145: /* NULLPTR */
    case 146: /* STATICCONST */
    case 147: /* CONTINUE */
    case 148: /* BREAK */
    case 149: /* RETURN */
    case 150: /* DO */
    case 151: /* FOR */
    case 152: /* FOREACH */
    case 153: /* WHILE */
    case 154: /* UNTIL */
    case 155: /* IF */
    case 156: /* ELSE */
    case 157: /* SWITCH */
    case 158: /* CASE */
{
#line 117 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"

#line 1959 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
    fflush(yyTraceFILE);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void ZCCParseFree(
  void *p,                    /* The parser to be deleted */
  void (CDECL *freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int ZCCParseStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
          fflush(yyTraceFILE);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
            fflush(yyTraceFILE);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   ZCCParseARG_FETCH;
   yypParser->yytos--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
     fflush(yyTraceFILE);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
/******** End %stack_overflow code ********************************************/
   ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
    fflush(yyTraceFILE);
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  ZCCParseTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 164, 1 },
  { 165, 0 },
  { 165, 2 },
  { 165, 1 },
  { 166, 1 },
  { 166, 1 },
  { 166, 1 },
  { 166, 1 },
  { 166, 1 },
  { 166, 1 },
  { 175, 0 },
  { 172, 2 },
  { 168, 2 },
  { 178, 3 },
  { 178, 4 },
  { 182, 0 },
  { 182, 2 },
  { 183, 0 },
  { 183, 2 },
  { 183, 2 },
  { 183, 2 },
  { 183, 2 },
  { 183, 3 },
  { 183, 5 },
  { 184, 1 },
  { 184, 1 },
  { 184, 3 },
  { 184, 3 },
  { 184, 3 },
  { 181, 3 },
  { 181, 3 },
  { 179, 0 },
  { 179, 2 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 185, 3 },
  { 186, 5 },
  { 187, 7 },
  { 194, 1 },
  { 194, 3 },
  { 169, 7 },
  { 169, 7 },
  { 196, 0 },
  { 196, 2 },
  { 196, 2 },
  { 196, 2 },
  { 196, 2 },
  { 196, 5 },
  { 191, 0 },
  { 191, 1 },
  { 192, 2 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 171, 5 },
  { 170, 7 },
  { 200, 0 },
  { 200, 2 },
  { 197, 1 },
  { 197, 3 },
  { 198, 0 },
  { 199, 1 },
  { 199, 3 },
  { 167, 1 },
  { 202, 6 },
  { 203, 0 },
  { 203, 2 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 204, 1 },
  { 188, 6 },
  { 215, 0 },
  { 215, 3 },
  { 195, 1 },
  { 195, 3 },
  { 216, 0 },
  { 205, 0 },
  { 205, 1 },
  { 205, 2 },
  { 205, 2 },
  { 205, 2 },
  { 207, 2 },
  { 209, 1 },
  { 209, 1 },
  { 209, 1 },
  { 209, 1 },
  { 209, 3 },
  { 209, 5 },
  { 209, 5 },
  { 210, 0 },
  { 210, 2 },
  { 206, 5 },
  { 214, 0 },
  { 214, 2 },
  { 214, 2 },
  { 214, 2 },
  { 214, 2 },
  { 214, 2 },
  { 214, 7 },
  { 214, 5 },
  { 217, 1 },
  { 217, 3 },
  { 211, 4 },
  { 211, 3 },
  { 211, 4 },
  { 211, 3 },
  { 212, 0 },
  { 212, 2 },
  { 213, 0 },
  { 213, 3 },
  { 189, 3 },
  { 189, 4 },
  { 189, 4 },
  { 220, 1 },
  { 220, 2 },
  { 221, 1 },
  { 221, 2 },
  { 221, 1 },
  { 221, 1 },
  { 223, 2 },
  { 223, 2 },
  { 222, 3 },
  { 222, 2 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 201, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 226, 1 },
  { 225, 1 },
  { 225, 1 },
  { 225, 2 },
  { 225, 4 },
  { 225, 5 },
  { 225, 2 },
  { 227, 6 },
  { 227, 6 },
  { 227, 4 },
  { 227, 2 },
  { 232, 0 },
  { 232, 3 },
  { 228, 1 },
  { 228, 1 },
  { 231, 2 },
  { 229, 3 },
  { 230, 1 },
  { 234, 3 },
  { 233, 2 },
  { 160, 3 },
  { 235, 6 },
  { 235, 2 },
  { 235, 2 },
  { 240, 1 },
  { 240, 2 },
  { 239, 3 },
  { 236, 0 },
  { 236, 2 },
  { 236, 3 },
  { 242, 0 },
  { 242, 2 },
  { 236, 6 },
  { 236, 5 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 238, 0 },
  { 238, 1 },
  { 162, 1 },
  { 237, 0 },
  { 237, 1 },
  { 237, 3 },
  { 243, 3 },
  { 244, 3 },
  { 244, 5 },
  { 245, 0 },
  { 245, 2 },
  { 245, 2 },
  { 245, 2 },
  { 246, 1 },
  { 246, 1 },
  { 246, 1 },
  { 246, 9 },
  { 246, 7 },
  { 246, 5 },
  { 246, 3 },
  { 246, 4 },
  { 246, 9 },
  { 246, 4 },
  { 246, 3 },
  { 246, 2 },
  { 246, 2 },
  { 247, 2 },
  { 247, 2 },
  { 247, 2 },
  { 247, 2 },
  { 247, 2 },
  { 247, 2 },
  { 247, 2 },
  { 247, 2 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 3 },
  { 176, 5 },
  { 224, 3 },
  { 219, 3 },
  { 249, 0 },
  { 250, 3 },
  { 250, 1 },
  { 177, 1 },
  { 177, 2 },
  { 248, 1 },
  { 248, 1 },
  { 248, 1 },
  { 248, 1 },
  { 248, 1 },
  { 248, 1 },
  { 248, 1 },
  { 252, 1 },
  { 252, 1 },
  { 252, 1 },
  { 252, 2 },
  { 252, 2 },
  { 252, 2 },
  { 252, 2 },
  { 252, 2 },
  { 252, 1 },
  { 190, 10 },
  { 190, 10 },
  { 258, 2 },
  { 258, 2 },
  { 258, 2 },
  { 258, 3 },
  { 251, 2 },
  { 251, 3 },
  { 251, 3 },
  { 218, 1 },
  { 218, 2 },
  { 254, 1 },
  { 256, 5 },
  { 256, 6 },
  { 256, 9 },
  { 257, 7 },
  { 262, 1 },
  { 262, 1 },
  { 263, 1 },
  { 263, 1 },
  { 264, 0 },
  { 264, 1 },
  { 264, 3 },
  { 255, 1 },
  { 255, 3 },
  { 265, 5 },
  { 255, 5 },
  { 253, 3 },
  { 253, 2 },
  { 259, 5 },
  { 260, 6 },
  { 261, 2 },
  { 267, 1 },
  { 267, 2 },
  { 267, 3 },
  { 267, 5 },
  { 267, 6 },
  { 267, 5 },
  { 266, 3 },
  { 165, 2 },
  { 173, 0 },
  { 173, 1 },
  { 174, 0 },
  { 174, 1 },
  { 175, 1 },
  { 191, 1 },
  { 192, 1 },
  { 197, 1 },
  { 198, 2 },
  { 208, 3 },
  { 226, 1 },
  { 231, 1 },
  { 229, 1 },
  { 230, 1 },
  { 233, 1 },
  { 239, 1 },
  { 162, 1 },
  { 237, 1 },
  { 243, 1 },
  { 246, 3 },
  { 247, 1 },
  { 176, 1 },
  { 224, 1 },
  { 219, 1 },
  { 249, 1 },
  { 248, 1 },
  { 163, 1 },
  { 252, 1 },
  { 252, 1 },
  { 252, 1 },
  { 252, 1 },
  { 266, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  ZCCParseARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
    fflush(yyTraceFILE);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* main ::= translation_unit */
#line 173 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ stat->TopNode = yymsp[0].minor.yy296; DPrintf(DMSG_SPAMMY, "Parse complete\n"); }
#line 2648 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 1: /* translation_unit ::= */
      case 31: /*class_innards ::= */ yytestcase(yyruleno==31);
      case 56: /*opt_struct_body ::= */ yytestcase(yyruleno==56);
      case 74: /*mixin_class_body ::= */ yytestcase(yyruleno==74);
#line 176 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy296 = NULL; }
#line 2656 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 2: /* translation_unit ::= translation_unit external_declaration */
      case 32: /*class_innards ::= class_innards class_member */ yytestcase(yyruleno==32);
      case 75: /*mixin_class_body ::= mixin_class_body mixin_class_member */ yytestcase(yyruleno==75);
#line 177 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy296,yymsp[0].minor.yy296); }
#line 2663 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 3: /* translation_unit ::= error */
      case 57: /*opt_struct_body ::= error */ yytestcase(yyruleno==57);
#line 179 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = NULL; }
#line 2669 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 4: /* external_declaration ::= mixin_definition */
#line 182 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy282; /*X-overwrites-A*/ }
#line 2674 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 5: /* external_declaration ::= class_definition */
#line 183 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy20; /*X-overwrites-A*/ }
#line 2679 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 6: /* external_declaration ::= struct_def */
      case 36: /*class_member ::= struct_def */ yytestcase(yyruleno==36);
      case 78: /*mixin_class_member ::= struct_def */ yytestcase(yyruleno==78);
#line 184 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy299; /*X-overwrites-A*/ }
#line 2686 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 7: /* external_declaration ::= enum_def */
      case 35: /*class_member ::= enum_def */ yytestcase(yyruleno==35);
      case 60: /*struct_member ::= enum_def */ yytestcase(yyruleno==60);
      case 77: /*mixin_class_member ::= enum_def */ yytestcase(yyruleno==77);
#line 185 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy179; /*X-overwrites-A*/ }
#line 2694 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 8: /* external_declaration ::= const_def */
      case 39: /*class_member ::= const_def */ yytestcase(yyruleno==39);
      case 61: /*struct_member ::= const_def */ yytestcase(yyruleno==61);
      case 81: /*mixin_class_member ::= const_def */ yytestcase(yyruleno==81);
#line 186 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy499; /*X-overwrites-A*/ }
#line 2702 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 9: /* external_declaration ::= include_def */
#line 187 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = nullptr; }
#line 2707 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 10: /* opt_expr ::= */
#line 198 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[1].minor.yy318 = NULL;
}
#line 2714 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 11: /* include_def ::= INCLUDE string_constant */
{  yy_destructor(yypParser,51,&yymsp[-1].minor);
#line 205 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	AddInclude(yymsp[0].minor.yy471);
}
#line 2722 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 12: /* class_definition ::= class_head class_body */
#line 219 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-1].minor.yy20->Body = yymsp[0].minor.yy296;
	yymsp[-1].minor.yy20 = yymsp[-1].minor.yy20; /*X-overwrites-A*/
}
#line 2731 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 13: /* class_head ::= EXTEND CLASS IDENTIFIER */
{  yy_destructor(yypParser,52,&yymsp[-2].minor);
#line 225 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-1].minor.yy0);
	head->NodeName = yymsp[0].minor.yy0.Name();
	head->ParentName = nullptr;
	head->Flags =  ZCC_Extension;
	head->Replaces = nullptr;
	head->Version = {0, 0};
	head->Type = nullptr;
	head->Symbol = nullptr;
	yymsp[-2].minor.yy20 = head;
}
#line 2747 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 14: /* class_head ::= CLASS IDENTIFIER class_ancestry class_flags */
#line 239 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Class,head,yymsp[-3].minor.yy0);
	head->NodeName = yymsp[-2].minor.yy0.Name();
	head->ParentName = yymsp[-1].minor.yy165;
	head->Flags = yymsp[0].minor.yy87.Flags;
	head->Replaces = yymsp[0].minor.yy87.Replaces;
	head->Version = yymsp[0].minor.yy87.Version;
	head->Type = nullptr;
	head->Symbol = nullptr;
	yylhsminor.yy20 = head;
}
#line 2763 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-3].minor.yy20 = yylhsminor.yy20;
        break;
      case 15: /* class_ancestry ::= */
      case 165: /*class_restrictor ::= */ yytestcase(yyruleno==165);
#line 252 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy165 = NULL; }
#line 2770 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 16: /* class_ancestry ::= COLON dottable_id */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 253 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy165 = yymsp[0].minor.yy165; /*yymsp[-1].minor.yy165-overwrites-yymsp[0].minor.yy165*/ }
#line 2776 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 17: /* class_flags ::= */
#line 256 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy87.Flags = 0; yymsp[1].minor.yy87.Replaces = NULL; yymsp[1].minor.yy87.Version = {0,0}; }
#line 2782 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 18: /* class_flags ::= class_flags ABSTRACT */
#line 257 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_Abstract; yylhsminor.yy87.Replaces = yymsp[-1].minor.yy87.Replaces; }
#line 2787 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,55,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 19: /* class_flags ::= class_flags NATIVE */
#line 258 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_Native; yylhsminor.yy87.Replaces = yymsp[-1].minor.yy87.Replaces; }
#line 2794 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 20: /* class_flags ::= class_flags UI */
#line 259 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_UIFlag; yylhsminor.yy87.Replaces = yymsp[-1].minor.yy87.Replaces; }
#line 2801 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 21: /* class_flags ::= class_flags PLAY */
#line 260 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_Play; yylhsminor.yy87.Replaces = yymsp[-1].minor.yy87.Replaces; }
#line 2808 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 22: /* class_flags ::= class_flags REPLACES dottable_id */
#line 261 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-2].minor.yy87.Flags; yylhsminor.yy87.Replaces = yymsp[0].minor.yy165; }
#line 2815 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,59,&yymsp[-1].minor);
  yymsp[-2].minor.yy87 = yylhsminor.yy87;
        break;
      case 23: /* class_flags ::= class_flags VERSION LPAREN STRCONST RPAREN */
#line 262 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-4].minor.yy87.Flags | ZCC_Version; yylhsminor.yy87.Replaces = yymsp[-4].minor.yy87.Replaces; yylhsminor.yy87.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 2822 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy87 = yylhsminor.yy87;
        break;
      case 24: /* dottable_id ::= IDENTIFIER */
      case 46: /*identifier_list ::= IDENTIFIER */ yytestcase(yyruleno==46);
      case 88: /*states_opt ::= IDENTIFIER */ yytestcase(yyruleno==88);
#line 270 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy165 = id;
}
#line 2837 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy165 = yylhsminor.yy165;
        break;
      case 25: /* dottable_id ::= ACTION */
#line 277 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = NAME_Action;
	yylhsminor.yy165 = id;
}
#line 2847 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy165 = yylhsminor.yy165;
        break;
      case 26: /* dottable_id ::= dottable_id DOT IDENTIFIER */
#line 283 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy165);
	id2->Id = yymsp[0].minor.yy0.Name();
	AppendTreeNodeSibling(yymsp[-2].minor.yy165, id2);
	yymsp[-2].minor.yy165 = yymsp[-2].minor.yy165; /*X-overwrites-A*/
}
#line 2858 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
        break;
      case 27: /* dottable_id ::= dottable_id DOT DEFAULT */
#line 290 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy165);
	id2->Id = NAME_Default;
	AppendTreeNodeSibling(yymsp[-2].minor.yy165, id2);
	yymsp[-2].minor.yy165 = yymsp[-2].minor.yy165; /*X-overwrites-A*/
}
#line 2869 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,64,&yymsp[0].minor);
        break;
      case 28: /* dottable_id ::= dottable_id DOT COLOR */
#line 301 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id2,yymsp[-2].minor.yy165);
	id2->Id = NAME_Color;
	AppendTreeNodeSibling(yymsp[-2].minor.yy165, id2);
	yymsp[-2].minor.yy165 = yymsp[-2].minor.yy165; /*X-overwrites-A*/
}
#line 2881 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yy_destructor(yypParser,65,&yymsp[0].minor);
        break;
      case 29: /* class_body ::= SEMICOLON class_innards EOF */
{  yy_destructor(yypParser,49,&yymsp[-2].minor);
#line 318 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy296 = yymsp[-1].minor.yy296; /*yymsp[-2].minor.yy296-overwrites-yymsp[-1].minor.yy296*/ }
#line 2889 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
}
        break;
      case 30: /* class_body ::= LBRACE class_innards RBRACE */
{  yy_destructor(yypParser,66,&yymsp[-2].minor);
#line 319 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy296 = yymsp[-1].minor.yy296; /*yymsp[-2].minor.yy296-overwrites-yymsp[-1].minor.yy296*/ }
#line 2897 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
}
        break;
      case 33: /* class_member ::= declarator */
      case 59: /*struct_member ::= declarator */ yytestcase(yyruleno==59);
      case 76: /*mixin_class_member ::= declarator */ yytestcase(yyruleno==76);
#line 332 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy23; /*X-overwrites-A*/ }
#line 2906 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 34: /* class_member ::= mixin_statement */
#line 333 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy399; /*X-overwrites-A*/ }
#line 2911 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 37: /* class_member ::= states_def */
      case 79: /*mixin_class_member ::= states_def */ yytestcase(yyruleno==79);
#line 336 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy70; /*X-overwrites-A*/ }
#line 2917 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 38: /* class_member ::= default_def */
      case 80: /*mixin_class_member ::= default_def */ yytestcase(yyruleno==80);
#line 337 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy431; /*X-overwrites-A*/ }
#line 2923 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 40: /* class_member ::= property_def */
      case 82: /*mixin_class_member ::= property_def */ yytestcase(yyruleno==82);
#line 339 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy443; /*X-overwrites-A*/ }
#line 2929 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 41: /* class_member ::= flag_def */
      case 83: /*mixin_class_member ::= flag_def */ yytestcase(yyruleno==83);
#line 340 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy155; /*X-overwrites-A*/ }
#line 2935 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 42: /* class_member ::= staticarray_statement */
      case 62: /*struct_member ::= staticarray_statement */ yytestcase(yyruleno==62);
      case 84: /*mixin_class_member ::= staticarray_statement */ yytestcase(yyruleno==84);
#line 341 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy296 = yymsp[0].minor.yy106; /*X-overwrites-A*/ }
#line 2942 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 43: /* mixin_statement ::= MIXIN IDENTIFIER SEMICOLON */
#line 346 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinStmt,stmt,yymsp[-2].minor.yy0);
	stmt->MixinName = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy399 = stmt;
}
#line 2951 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy399 = yylhsminor.yy399;
        break;
      case 44: /* property_def ::= PROPERTY IDENTIFIER COLON identifier_list SEMICOLON */
#line 361 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Property,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Body = yymsp[-1].minor.yy165;
	yylhsminor.yy443 = def;
}
#line 2963 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy443 = yylhsminor.yy443;
        break;
      case 45: /* flag_def ::= FLAGDEF IDENTIFIER COLON IDENTIFIER COMMA INTCONST SEMICOLON */
#line 369 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagDef,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->RefName = yymsp[-3].minor.yy0.Name();
	def->BitValue = yymsp[-1].minor.yy0.Int;
	yylhsminor.yy155 = def;
}
#line 2977 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-6].minor.yy155 = yylhsminor.yy155;
        break;
      case 47: /* identifier_list ::= states_opt COMMA IDENTIFIER */
      case 89: /*states_opt ::= states_opt COMMA IDENTIFIER */ yytestcase(yyruleno==89);
#line 386 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Identifier,id,yymsp[0].minor.yy0);
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-2].minor.yy165 = yymsp[-2].minor.yy165; /*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy165, id);
}
#line 2992 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 48: /* struct_def ::= STRUCT IDENTIFIER struct_flags LBRACE opt_struct_body RBRACE opt_semicolon */
#line 394 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy296;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Version = yymsp[-4].minor.yy87.Version;
	def->Flags = yymsp[-4].minor.yy87.Flags;
	yylhsminor.yy299 = def;
}
#line 3007 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[-3].minor);
  yy_destructor(yypParser,67,&yymsp[-1].minor);
  yymsp[-6].minor.yy299 = yylhsminor.yy299;
        break;
      case 49: /* struct_def ::= EXTEND STRUCT IDENTIFIER LBRACE opt_struct_body RBRACE opt_semicolon */
{  yy_destructor(yypParser,52,&yymsp[-6].minor);
#line 406 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Struct,def,yymsp[-5].minor.yy0);
	def->NodeName = yymsp[-4].minor.yy0.Name();
	def->Body = yymsp[-2].minor.yy296;
	def->Type = nullptr;
	def->Symbol = nullptr;
	def->Flags = ZCC_Extension;
	yymsp[-6].minor.yy299 = def;
}
#line 3024 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[-3].minor);
  yy_destructor(yypParser,67,&yymsp[-1].minor);
}
        break;
      case 50: /* struct_flags ::= */
#line 417 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy87.Flags = 0; yymsp[1].minor.yy87.Version = {0, 0}; }
#line 3032 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 51: /* struct_flags ::= struct_flags UI */
#line 418 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_UIFlag; }
#line 3037 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,57,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 52: /* struct_flags ::= struct_flags PLAY */
#line 419 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_Play; }
#line 3044 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,58,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 53: /* struct_flags ::= struct_flags CLEARSCOPE */
#line 420 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_ClearScope; }
#line 3051 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,73,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 54: /* struct_flags ::= struct_flags NATIVE */
#line 421 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-1].minor.yy87.Flags | ZCC_Native; }
#line 3058 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,56,&yymsp[0].minor);
  yymsp[-1].minor.yy87 = yylhsminor.yy87;
        break;
      case 55: /* struct_flags ::= struct_flags VERSION LPAREN STRCONST RPAREN */
#line 422 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy87.Flags = yymsp[-4].minor.yy87.Flags | ZCC_Version; yylhsminor.yy87.Version = yymsp[-1].minor.yy0.String->GetChars(); }
#line 3065 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,60,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy87 = yylhsminor.yy87;
        break;
      case 58: /* struct_body ::= struct_body struct_member */
#line 430 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy296 = yymsp[-1].minor.yy296; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-1].minor.yy296, yymsp[0].minor.yy296); }
#line 3074 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 63: /* const_def ::= CONST IDENTIFIER EQ expr SEMICOLON */
#line 440 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,def,yymsp[-4].minor.yy0);
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->Value = yymsp[-1].minor.yy318;
	def->Symbol = NULL;
	yylhsminor.yy499 = def;
}
#line 3085 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-2].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-4].minor.yy499 = yylhsminor.yy499;
        break;
      case 64: /* enum_def ::= ENUM IDENTIFIER enum_type LBRACE opt_enum_list RBRACE opt_semicolon */
#line 457 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Enum,def,yymsp[-6].minor.yy0);
	def->NodeName = yymsp[-5].minor.yy0.Name();
	def->EnumType = (EZCCBuiltinType)yymsp[-4].minor.yy0.Int;
	def->Elements = yymsp[-2].minor.yy499;
	def->Symbol = nullptr;

	// If the first element does not have an explicit value, make it 0.
	if (yymsp[-2].minor.yy499 != NULL)
	{
		ZCC_ConstantDef *node = yymsp[-2].minor.yy499, *prev = node;

		if (node->Value == NULL)
		{
			NEW_INTCONST_NODE(zero, TypeSInt32, 0, yymsp[-2].minor.yy499);
			node->Value = zero;
		}
		for (node = static_cast<ZCC_ConstantDef *>(node->SiblingNext);
			node != yymsp[-2].minor.yy499;
			prev = node, node = static_cast<ZCC_ConstantDef *>(node->SiblingNext))
		{
			assert(node->NodeType == AST_ConstantDef);
			// Leave explicit values alone.
			if (node->Value != NULL)
			{
				continue;
			}
			// Compute implicit values by adding one to the preceding value.
			assert(prev->Value != NULL);
			// If the preceding node is a constant, then we can do this now.
			if (prev->Value->Operation == PEX_ConstValue && prev->Value->Type->isInt())
			{
				NEW_INTCONST_NODE(cval, prev->Value->Type, static_cast<ZCC_ExprConstant *>(prev->Value)->IntVal + 1, node);
				node->Value = cval;
			}
			// Otherwise, create a new addition expression to add 1.
			else
			{
				NEW_INTCONST_NODE(one, TypeSInt32, 1, yymsp[-6].minor.yy0);
				NEW_AST_NODE(ExprID, label, node);
				label->Operation = PEX_ID;
				label->Identifier = prev->NodeName;
				label->Type = NULL;

				BINARY_EXPR(label, one, PEX_Add);
				node->Value = expr2;
			}
		}
		// Add a new terminating node, to indicate that the ConstantDefs for this enum are done.
		NEW_AST_NODE(EnumTerminator,term,yymsp[-1].minor.yy0);
		AppendTreeNodeSibling(yymsp[-2].minor.yy499, term);
	}
	if (yymsp[-2].minor.yy499 != NULL)
	{
		AppendTreeNodeSibling(def, yymsp[-2].minor.yy499);
	}
	yylhsminor.yy179 = def;
}
#line 3150 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[-3].minor);
  yymsp[-6].minor.yy179 = yylhsminor.yy179;
        break;
      case 65: /* enum_type ::= */
#line 516 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = ZCC_IntAuto; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 3157 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 66: /* enum_type ::= COLON int_type */
{  yy_destructor(yypParser,14,&yymsp[-1].minor);
#line 517 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; /*yymsp[-1].minor.yy0-overwrites-yymsp[0].minor.yy0*/ }
#line 3163 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 67: /* enum_list ::= error */
#line 519 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy499 = NULL; }
#line 3169 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 68: /* enum_list ::= enum_list COMMA enumerator */
#line 521 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy499 = yymsp[-2].minor.yy499; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy499, yymsp[0].minor.yy499); }
#line 3174 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 69: /* opt_enum_list ::= */
#line 523 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy499 = NULL; }
#line 3180 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 70: /* enumerator ::= IDENTIFIER */
#line 527 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[0].minor.yy0);
	node->NodeName = yymsp[0].minor.yy0.Name();
	node->Value = NULL;
	node->Symbol = NULL;
	yylhsminor.yy499 = node;
}
#line 3191 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy499 = yylhsminor.yy499;
        break;
      case 71: /* enumerator ::= IDENTIFIER EQ expr */
#line 535 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ConstantDef,node,yymsp[-2].minor.yy0);
	node->NodeName = yymsp[-2].minor.yy0.Name();
	node->Value = yymsp[0].minor.yy318;
	node->Symbol = NULL;
	yylhsminor.yy499 = node;
}
#line 3203 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy499 = yylhsminor.yy499;
        break;
      case 72: /* mixin_definition ::= mixin_class_definition */
#line 549 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy282 = yymsp[0].minor.yy282; /*X-overwrites-A*/ }
#line 3210 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 73: /* mixin_class_definition ::= MIXIN CLASS IDENTIFIER LBRACE mixin_class_body RBRACE */
#line 556 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MixinDef,def,yymsp[-5].minor.yy0);
	def->Body = yymsp[-1].minor.yy296;
	def->NodeName = yymsp[-3].minor.yy0.Name();
	def->MixinType = ZCC_Mixin_Class;
	def->Symbol = nullptr;
	yylhsminor.yy282 = def;
}
#line 3222 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-4].minor);
  yy_destructor(yypParser,66,&yymsp[-2].minor);
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-5].minor.yy282 = yylhsminor.yy282;
        break;
      case 85: /* states_def ::= STATES states_opts scanner_mode LBRACE states_body RBRACE */
#line 605 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(States,def,yymsp[-5].minor.yy0);
	def->Flags = yymsp[-4].minor.yy165;
	def->Body = yymsp[-1].minor.yy266;
	yylhsminor.yy70 = def;
}
#line 3236 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,66,&yymsp[-2].minor);
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-5].minor.yy70 = yylhsminor.yy70;
        break;
      case 86: /* states_opts ::= */
#line 612 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy165 = nullptr; }
#line 3244 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 87: /* states_opts ::= LPAREN states_opt RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 613 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy165 = yymsp[-1].minor.yy165; /*yymsp[-2].minor.yy165-overwrites-yymsp[-1].minor.yy165*/ }
#line 3250 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 90: /* scanner_mode ::= */
#line 642 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ stat->sc->SetStateMode(true); }
#line 3257 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 91: /* states_body ::= */
#line 644 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy266 = NULL; }
#line 3262 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 92: /* states_body ::= error */
#line 645 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy266 = NULL; }
#line 3267 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 93: /* states_body ::= states_body state_line */
      case 94: /*states_body ::= states_body state_label */ yytestcase(yyruleno==94);
      case 95: /*states_body ::= states_body state_flow */ yytestcase(yyruleno==95);
#line 646 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ SAFE_APPEND(yymsp[-1].minor.yy266,yymsp[0].minor.yy266); }
#line 3274 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 96: /* state_label ::= NWS COLON */
#line 651 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLabel, label, yymsp[-1].minor.yy0);
	label->Label = yymsp[-1].minor.yy0.Name();
	yylhsminor.yy266 = label;
}
#line 3283 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy266 = yylhsminor.yy266;
        break;
      case 97: /* state_flow_type ::= STOP */
#line 659 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateStop, flow, yymsp[0].minor.yy0); yylhsminor.yy266 = flow; }
#line 3290 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy266 = yylhsminor.yy266;
        break;
      case 98: /* state_flow_type ::= WAIT */
#line 660 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateWait, flow, yymsp[0].minor.yy0); yylhsminor.yy266 = flow; }
#line 3296 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy266 = yylhsminor.yy266;
        break;
      case 99: /* state_flow_type ::= FAIL */
#line 661 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateFail, flow, yymsp[0].minor.yy0); yylhsminor.yy266 = flow; }
#line 3302 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy266 = yylhsminor.yy266;
        break;
      case 100: /* state_flow_type ::= LOOP */
#line 662 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ NEW_AST_NODE(StateLoop, flow, yymsp[0].minor.yy0); yylhsminor.yy266 = flow; }
#line 3308 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy266 = yylhsminor.yy266;
        break;
      case 101: /* state_flow_type ::= GOTO dottable_id state_goto_offset */
#line 664 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-2].minor.yy0);
	flow->Label = yymsp[-1].minor.yy165;
	flow->Offset = yymsp[0].minor.yy318;
	flow->Qualifier = nullptr;
	yylhsminor.yy266 = flow;
}
#line 3320 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-2].minor.yy266 = yylhsminor.yy266;
        break;
      case 102: /* state_flow_type ::= GOTO IDENTIFIER SCOPE dottable_id state_goto_offset */
#line 673 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy165;
	flow->Offset = yymsp[0].minor.yy318;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = yymsp[-3].minor.yy0.Name();
	flow->Qualifier =id;
	yylhsminor.yy266 = flow;
}
#line 3335 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy266 = yylhsminor.yy266;
        break;
      case 103: /* state_flow_type ::= GOTO SUPER SCOPE dottable_id state_goto_offset */
#line 685 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateGoto, flow, yymsp[-4].minor.yy0);
	flow->Label = yymsp[-1].minor.yy165;
	flow->Offset = yymsp[0].minor.yy318;

	NEW_AST_NODE(Identifier,id,yymsp[-3].minor.yy0);
	id->Id = NAME_Super;
	flow->Qualifier =id;
	yylhsminor.yy266 = flow;
}
#line 3351 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-2].minor);
  yymsp[-4].minor.yy266 = yylhsminor.yy266;
        break;
      case 104: /* state_goto_offset ::= */
#line 696 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy318 = NULL; }
#line 3358 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 105: /* state_goto_offset ::= ADD expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 697 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy318 = yymsp[0].minor.yy318; /*yymsp[-1].minor.yy318-overwrites-yymsp[0].minor.yy318*/ }
#line 3364 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 106: /* state_line ::= NWS NWS expr state_opts state_action */
#line 700 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StateLine, line, yymsp[-4].minor.yy0);
	line->Sprite = stat->Strings.Alloc(FName(yymsp[-4].minor.yy0.Name()).GetChars());
	line->Frames = stat->Strings.Alloc(FName(yymsp[-3].minor.yy0.Name()).GetChars());
	line->Duration = yymsp[-2].minor.yy318;
	line->bBright = yymsp[-1].minor.yy332.Bright;
	line->bFast = yymsp[-1].minor.yy332.Fast;
	line->bSlow = yymsp[-1].minor.yy332.Slow;
	line->bNoDelay = yymsp[-1].minor.yy332.NoDelay;
	line->bCanRaise = yymsp[-1].minor.yy332.CanRaise;
	line->Offset = yymsp[-1].minor.yy332.Offset;
	line->Lights = yymsp[-1].minor.yy332.Lights;
	line->Action = yymsp[0].minor.yy296;
	yylhsminor.yy266 = line;
}
#line 3384 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-4].minor.yy266 = yylhsminor.yy266;
        break;
      case 107: /* state_opts ::= */
#line 716 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ StateOpts opts; opts.Zero(); yymsp[1].minor.yy332 = opts; }
#line 3390 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 108: /* state_opts ::= state_opts BRIGHT */
#line 717 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy332.Bright = true; yymsp[-1].minor.yy332 = yymsp[-1].minor.yy332; /*X-overwrites-A*/ }
#line 3395 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,84,&yymsp[0].minor);
        break;
      case 109: /* state_opts ::= state_opts FAST */
#line 718 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy332.Fast = true; yymsp[-1].minor.yy332 = yymsp[-1].minor.yy332; /*X-overwrites-A*/ }
#line 3401 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,85,&yymsp[0].minor);
        break;
      case 110: /* state_opts ::= state_opts SLOW */
#line 719 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy332.Slow = true; yymsp[-1].minor.yy332 = yymsp[-1].minor.yy332; /*X-overwrites-A*/ }
#line 3407 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,86,&yymsp[0].minor);
        break;
      case 111: /* state_opts ::= state_opts NODELAY */
#line 720 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy332.NoDelay = true; yymsp[-1].minor.yy332 = yymsp[-1].minor.yy332; /*X-overwrites-A*/ }
#line 3413 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,87,&yymsp[0].minor);
        break;
      case 112: /* state_opts ::= state_opts CANRAISE */
#line 721 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy332.CanRaise = true; yymsp[-1].minor.yy332 = yymsp[-1].minor.yy332; /*X-overwrites-A*/ }
#line 3419 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,88,&yymsp[0].minor);
        break;
      case 113: /* state_opts ::= state_opts OFFSET LPAREN expr COMMA expr RPAREN */
#line 722 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-6].minor.yy332.Offset = yymsp[-3].minor.yy318; AppendTreeNodeSibling(yymsp[-3].minor.yy318, yymsp[-1].minor.yy318); yymsp[-6].minor.yy332 = yymsp[-6].minor.yy332; /*X-overwrites-A*/ }
#line 3425 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,89,&yymsp[-5].minor);
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 114: /* state_opts ::= state_opts LIGHT LPAREN light_list RPAREN */
#line 723 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-4].minor.yy332 = yymsp[-4].minor.yy332; /*X-overwrites-A*/ yymsp[-4].minor.yy332.Lights = yymsp[-1].minor.yy471; }
#line 3434 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,90,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
        break;
      case 115: /* light_list ::= STRCONST */
      case 285: /*string_constant ::= STRCONST */ yytestcase(yyruleno==285);
#line 728 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	yylhsminor.yy471 = strconst;
}
#line 3449 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 116: /* light_list ::= light_list COMMA STRCONST */
#line 737 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[0].minor.yy0);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = yymsp[0].minor.yy0.String;
	AppendTreeNodeSibling(yymsp[-2].minor.yy471, strconst); 
	yymsp[-2].minor.yy471 = yymsp[-2].minor.yy471; /*X-overwrites-A*/
}
#line 3462 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 117: /* state_action ::= LBRACE statement_list scanner_mode RBRACE */
#line 748 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-3].minor.yy0);
	stmt->Content = yymsp[-2].minor.yy156;
	yylhsminor.yy296 = stmt;
}
#line 3472 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-3].minor.yy296 = yylhsminor.yy296;
        break;
      case 118: /* state_action ::= LBRACE scanner_mode RBRACE */
{  yy_destructor(yypParser,66,&yymsp[-2].minor);
#line 754 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy296 = NULL;
}
#line 3482 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
}
        break;
      case 119: /* state_action ::= LBRACE error scanner_mode RBRACE */
{  yy_destructor(yypParser,66,&yymsp[-3].minor);
#line 757 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-3].minor.yy296 = NULL; }
#line 3490 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
}
        break;
      case 120: /* state_action ::= state_call scanner_mode SEMICOLON */
#line 758 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy296 = yymsp[-2].minor.yy445; /*X-overwrites-A*/ }
#line 3497 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 121: /* state_call ::= */
#line 760 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy445 = NULL; }
#line 3503 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 122: /* state_call ::= IDENTIFIER state_call_params */
#line 762 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-1].minor.yy0);
	NEW_AST_NODE(ExprID, func, yymsp[-1].minor.yy0);

	func->Operation = PEX_ID;
	func->Identifier = yymsp[-1].minor.yy0.Name();
	expr->Operation = PEX_FuncCall;
	expr->Function = func;
	expr->Parameters = yymsp[0].minor.yy138;
	yylhsminor.yy445 = expr;
}
#line 3518 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy445 = yylhsminor.yy445;
        break;
      case 123: /* state_call_params ::= */
#line 774 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy138 = NULL; }
#line 3524 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 124: /* state_call_params ::= LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 775 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy138 = yymsp[-1].minor.yy138; /*yymsp[-2].minor.yy138-overwrites-yymsp[-1].minor.yy138*/ }
#line 3530 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 125: /* default_def ::= DEFAULT LBRACE RBRACE */
{  yy_destructor(yypParser,64,&yymsp[-2].minor);
#line 783 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yymsp[-2].minor.yy431 = stmt;
}
#line 3542 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
}
        break;
      case 126: /* default_def ::= DEFAULT LBRACE default_statement_list RBRACE */
{  yy_destructor(yypParser,64,&yymsp[-3].minor);
#line 789 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy156;
	yymsp[-3].minor.yy431 = stmt;
}
#line 3554 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
}
        break;
      case 127: /* default_def ::= DEFAULT LBRACE error RBRACE */
{  yy_destructor(yypParser,64,&yymsp[-3].minor);
#line 795 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Default,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yymsp[-3].minor.yy431 = stmt;
}
#line 3566 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
}
        break;
      case 128: /* default_statement_list ::= default_statement */
      case 312: /*statement_list ::= statement */ yytestcase(yyruleno==312);
#line 802 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[0].minor.yy156 = yymsp[0].minor.yy156; /*X-overwrites-A*/
}
#line 3576 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 129: /* default_statement_list ::= default_statement_list default_statement */
      case 313: /*statement_list ::= statement_list statement */ yytestcase(yyruleno==313);
#line 806 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	SAFE_APPEND(yymsp[-1].minor.yy156,yymsp[0].minor.yy156);
}
#line 3584 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 130: /* default_statement ::= SEMICOLON */
      case 294: /*statement ::= SEMICOLON */ yytestcase(yyruleno==294);
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 811 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = NULL; }
#line 3591 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 131: /* default_statement ::= error SEMICOLON */
      case 301: /*statement ::= error SEMICOLON */ yytestcase(yyruleno==301);
#line 812 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy156 = NULL; }
#line 3598 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 132: /* default_statement ::= property_statement */
#line 814 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy315; /*X-overwrites-A*/ }
#line 3604 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 133: /* default_statement ::= flag_statement */
#line 815 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy52; /*X-overwrites-A*/ }
#line 3609 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 134: /* flag_statement ::= ADD dottable_id */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 820 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy165);
	type->set = true;
	type->name = yymsp[0].minor.yy165;
	yymsp[-1].minor.yy52 = type;
}
#line 3620 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 135: /* flag_statement ::= SUB dottable_id */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 827 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FlagStmt, type, yymsp[0].minor.yy165);
	type->set = false;
	type->name = yymsp[0].minor.yy165;
	yymsp[-1].minor.yy52 = type;
}
#line 3632 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 136: /* property_statement ::= dottable_id expr_list SEMICOLON */
#line 837 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-2].minor.yy165);
	stmt->Prop = yymsp[-2].minor.yy165;
	stmt->Values = yymsp[-1].minor.yy318;
	yylhsminor.yy315 = stmt;
}
#line 3643 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy315 = yylhsminor.yy315;
        break;
      case 137: /* property_statement ::= dottable_id SEMICOLON */
#line 845 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(PropertyStmt,stmt,yymsp[-1].minor.yy165);
	stmt->Prop = yymsp[-1].minor.yy165;
	stmt->Values = nullptr;
	yylhsminor.yy315 = stmt;
}
#line 3655 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy315 = yylhsminor.yy315;
        break;
      case 138: /* int_type ::= SBYTE */
#line 857 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3662 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 139: /* int_type ::= BYTE */
#line 858 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt8; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3668 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 140: /* int_type ::= SHORT */
#line 859 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3674 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 141: /* int_type ::= USHORT */
#line 860 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt16; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3680 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 142: /* int_type ::= INT */
#line 861 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_SInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3686 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 143: /* int_type ::= UINT */
#line 862 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UInt32; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3692 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 144: /* type_name1 ::= BOOL */
#line 864 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Bool; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3698 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 145: /* type_name1 ::= FLOAT */
#line 866 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FloatAuto; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3704 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 146: /* type_name1 ::= DOUBLE */
#line 867 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Float64; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3710 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 147: /* type_name1 ::= VECTOR2 */
#line 869 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector2; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3716 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 148: /* type_name1 ::= VECTOR3 */
#line 870 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector3; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3722 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 149: /* type_name1 ::= VECTOR4 */
#line 871 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Vector4; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3728 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 150: /* type_name1 ::= NAME */
#line 872 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Name; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3734 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 151: /* type_name1 ::= SOUND */
#line 873 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Sound; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3740 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 152: /* type_name1 ::= STATE */
#line 874 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_State; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3746 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 153: /* type_name1 ::= COLOR */
#line 875 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Color; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3752 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 154: /* type_name1 ::= LET */
#line 876 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Let; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 3758 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 155: /* type_name ::= type_name1 */
#line 879 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	type->Type = (EZCCBuiltinType)yymsp[0].minor.yy0.Int;
	type->UserType = NULL;
	type->isconst = false;
	yylhsminor.yy310 = type;
}
#line 3770 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy310 = yylhsminor.yy310;
        break;
      case 156: /* type_name ::= IDENTIFIER */
#line 887 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yylhsminor.yy310 = type;
}
#line 3784 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy310 = yylhsminor.yy310;
        break;
      case 157: /* type_name ::= ATSIGN IDENTIFIER */
{  yy_destructor(yypParser,107,&yymsp[-1].minor);
#line 898 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[0].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = false;
	id->Id = yymsp[0].minor.yy0.Name();
	yymsp[-1].minor.yy310 = type;
}
#line 3799 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 158: /* type_name ::= READONLY LT IDENTIFIER GT */
{  yy_destructor(yypParser,108,&yymsp[-3].minor);
#line 909 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_UserType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-3].minor.yy310 = type;
}
#line 3814 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 159: /* type_name ::= READONLY LT ATSIGN IDENTIFIER GT */
{  yy_destructor(yypParser,108,&yymsp[-4].minor);
#line 920 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[-1].minor.yy0);
	NEW_AST_NODE(Identifier, id, yymsp[-1].minor.yy0);
	type->Type = ZCC_NativeType;
	type->UserType = id;
	type->isconst = true;
	id->Id = yymsp[-1].minor.yy0.Name();
	yymsp[-4].minor.yy310 = type;
}
#line 3831 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-3].minor);
  yy_destructor(yypParser,107,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 160: /* type_name ::= DOT dottable_id */
{  yy_destructor(yypParser,44,&yymsp[-1].minor);
#line 931 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BasicType, type, yymsp[0].minor.yy165);
	type->Type = ZCC_UserType;
	type->UserType = yymsp[0].minor.yy165;
	type->isconst = false;
	yymsp[-1].minor.yy310 = type;
}
#line 3847 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 161: /* aggregate_type ::= MAP LT type_or_array COMMA type_or_array GT */
#line 955 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MapType,map,yymsp[-5].minor.yy0);
	map->KeyType = yymsp[-3].minor.yy104;
	map->ValueType = yymsp[-1].minor.yy104;
	yylhsminor.yy104 = map;
}
#line 3858 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-5].minor.yy104 = yylhsminor.yy104;
        break;
      case 162: /* aggregate_type ::= MAPITERATOR LT type_or_array COMMA type_or_array GT */
#line 963 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(MapIteratorType,map_it,yymsp[-5].minor.yy0);
	map_it->KeyType = yymsp[-3].minor.yy104;
	map_it->ValueType = yymsp[-1].minor.yy104;
	yylhsminor.yy104 = map_it;
}
#line 3872 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-5].minor.yy104 = yylhsminor.yy104;
        break;
      case 163: /* aggregate_type ::= ARRAY LT type_or_array GT */
#line 971 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(DynArrayType,arr,yymsp[-3].minor.yy0);
	arr->ElementType = yymsp[-1].minor.yy104;
	yylhsminor.yy104 = arr;
}
#line 3885 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-2].minor);
  yy_destructor(yypParser,21,&yymsp[0].minor);
  yymsp[-3].minor.yy104 = yylhsminor.yy104;
        break;
      case 164: /* aggregate_type ::= CLASS class_restrictor */
#line 978 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassType,cls,yymsp[-1].minor.yy0);
	cls->Restriction = yymsp[0].minor.yy165;
	yylhsminor.yy104 = cls;
}
#line 3897 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy104 = yylhsminor.yy104;
        break;
      case 166: /* class_restrictor ::= LT dottable_id GT */
{  yy_destructor(yypParser,20,&yymsp[-2].minor);
#line 984 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy165 = yymsp[-1].minor.yy165; /*yymsp[-2].minor.yy165-overwrites-yymsp[-1].minor.yy165*/ }
#line 3904 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[0].minor);
}
        break;
      case 167: /* type ::= type_name */
#line 986 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy104 = yymsp[0].minor.yy310; /*X-overwrites-A*/ yymsp[0].minor.yy104->ArraySize = NULL; }
#line 3911 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 168: /* type ::= aggregate_type */
#line 987 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy104 = yymsp[0].minor.yy104; /*X-overwrites-A*/ yymsp[0].minor.yy104->ArraySize = NULL; }
#line 3916 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 169: /* type_or_array ::= type array_size */
#line 990 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy104 = yymsp[-1].minor.yy104; /*X-overwrites-A*/ yymsp[-1].minor.yy104->ArraySize = yymsp[0].minor.yy318; }
#line 3921 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 170: /* type_list ::= type_list COMMA type_or_array */
#line 993 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy104 = yymsp[-2].minor.yy104; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy104, yymsp[0].minor.yy104); }
#line 3926 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 171: /* type_list_or_void ::= VOID */
{  yy_destructor(yypParser,113,&yymsp[0].minor);
#line 995 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy104 = NULL; }
#line 3933 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 172: /* array_size_expr ::= LBRACKET opt_expr RBRACKET */
#line 999 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy318 == NULL)
	{
		NEW_AST_NODE(Expression,nil,yymsp[-2].minor.yy0.SourceLoc);
		nil->Operation = PEX_Nil;
		nil->Type = NULL;
		yylhsminor.yy318 = nil;
	}
	else
	{
		yylhsminor.yy318 = yymsp[-1].minor.yy318;
	}
}
#line 3951 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,118,&yymsp[0].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 173: /* array_size ::= array_size array_size_expr */
#line 1014 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-1].minor.yy318, yymsp[0].minor.yy318);
	yymsp[-1].minor.yy318 = yymsp[-1].minor.yy318; /*X-overwrites-A*/
}
#line 3961 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 174: /* declarator ::= decl_flags type_list_or_void variables_or_function */
#line 1023 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[0].minor.yy432.FuncName == NAME_None && yymsp[0].minor.yy432.VarNames == NULL)
	{ // An error. yymsp[-2].minor.yy295 message was already printed.
		yylhsminor.yy23 = NULL;
	}
	else if (yymsp[0].minor.yy432.FuncName != NAME_None)
	{ // yymsp[-2].minor.yy295 function
		NEW_AST_NODE(FuncDeclarator, decl, yymsp[-2].minor.yy295 == nullptr? yymsp[0].minor.yy432.SourceLoc : yymsp[-2].minor.yy295->SourceLoc);
		decl->Type = yymsp[-1].minor.yy104;
		decl->Params = yymsp[0].minor.yy432.FuncParams;
		decl->Name = yymsp[0].minor.yy432.FuncName;
		decl->UseFlags = yymsp[-2].minor.yy295 == nullptr? nullptr : yymsp[-2].minor.yy295->Id;
		decl->Flags = (yymsp[-2].minor.yy295 == nullptr? 0 : yymsp[-2].minor.yy295->Flags) | yymsp[0].minor.yy432.FuncFlags;
		decl->DeprecationMessage = yymsp[-2].minor.yy295 == nullptr ? nullptr : yymsp[-2].minor.yy295->DeprecationMessage;
		if (yymsp[-2].minor.yy295 == nullptr) decl->Version = {0,0,0};
		else decl->Version = yymsp[-2].minor.yy295->Version;

		decl->Body = yymsp[0].minor.yy432.FuncBody;
		yylhsminor.yy23 = decl;
	}
	else if (yymsp[-1].minor.yy104 != NULL && yymsp[-1].minor.yy104->SiblingNext == yymsp[-1].minor.yy104)
	{ // yymsp[-2].minor.yy295 variable
		NEW_AST_NODE(VarDeclarator, decl, yymsp[-2].minor.yy295 == nullptr? yymsp[-1].minor.yy104->SourceLoc : yymsp[-2].minor.yy295->SourceLoc);
		decl->Type = yymsp[-1].minor.yy104;
		decl->Names = yymsp[0].minor.yy432.VarNames;
		if (yymsp[-2].minor.yy295 == nullptr)
		{
			decl->Flags = 0;
			decl->Version = {0,0,0};
			decl->DeprecationMessage = nullptr;
		}
		else
		{
			decl->Flags = yymsp[-2].minor.yy295->Flags;
			decl->Version = yymsp[-2].minor.yy295->Version;
			decl->DeprecationMessage = yymsp[-2].minor.yy295->DeprecationMessage;
		}
		yylhsminor.yy23 = decl;
	}
	else
	{ // An invalid
		if (yymsp[-1].minor.yy104 == NULL)
		{
			stat->sc->ScriptMessage("Variables may not be of type void.\n");
		}
		else
		{
			stat->sc->ScriptMessage("Variables may be of only one type.\n");
		}
		yylhsminor.yy23 = NULL;
	}
}
#line 4017 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-2].minor.yy23 = yylhsminor.yy23;
        break;
      case 175: /* variables_or_function ::= IDENTIFIER LPAREN func_params RPAREN func_const opt_func_body */
#line 1078 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun fun;

	fun.VarNames = NULL;
	fun.FuncParams = yymsp[-3].minor.yy491;
	fun.FuncFlags = yymsp[-1].minor.yy0.Int;
	fun.FuncName = yymsp[-5].minor.yy0.Name();
	fun.FuncBody = yymsp[0].minor.yy55;
	fun.SourceLoc = yymsp[-5].minor.yy0.SourceLoc;
	yylhsminor.yy432 = fun;
}
#line 4033 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-2].minor);
  yymsp[-5].minor.yy432 = yylhsminor.yy432;
        break;
      case 176: /* variables_or_function ::= variable_list SEMICOLON */
#line 1090 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun var;

	var.VarNames = yymsp[-1].minor.yy180;
	var.FuncParams = NULL;
	var.FuncFlags = 0;
	var.FuncName = NAME_None;
	var.FuncBody = NULL;
	var.SourceLoc = yymsp[-1].minor.yy180->SourceLoc;
	yylhsminor.yy432 = var;
}
#line 4051 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy432 = yylhsminor.yy432;
        break;
      case 177: /* variables_or_function ::= error SEMICOLON */
#line 1102 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	VarOrFun bad;
	bad.VarNames = NULL;
	bad.FuncParams = NULL;
	bad.FuncFlags = 0;
	bad.FuncName = NAME_None;
	bad.FuncBody = NULL;
	bad.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
	yymsp[-1].minor.yy432 = bad;
}
#line 4067 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 178: /* variable_name ::= IDENTIFIER */
#line 1119 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	yylhsminor.yy180 = var;
}
#line 4077 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy180 = yylhsminor.yy180;
        break;
      case 179: /* variable_name ::= IDENTIFIER array_size */
#line 1126 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarName,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy318;
	yylhsminor.yy180 = var;
}
#line 4088 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy180 = yylhsminor.yy180;
        break;
      case 180: /* variable_list ::= variable_list COMMA variable_name */
#line 1135 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy180, yymsp[0].minor.yy180);
	yymsp[-2].minor.yy180 = yymsp[-2].minor.yy180; /*X-overwrites-A*/
}
#line 4097 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 181: /* decl_flags ::= */
#line 1141 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy295 = NULL; }
#line 4103 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 182: /* decl_flags ::= decl_flags decl_flag */
#line 1143 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-1].minor.yy295 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[0].minor.yy0);
		yylhsminor.yy295 = nil_f;
		yylhsminor.yy295->Id = nullptr;
		yylhsminor.yy295->Flags = yymsp[0].minor.yy0.Int;
		yylhsminor.yy295->Version = { 0, 0 };
		yylhsminor.yy295->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy295 = yymsp[-1].minor.yy295;
		yylhsminor.yy295->Flags |= yymsp[0].minor.yy0.Int;
	}
}
#line 4123 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy295 = yylhsminor.yy295;
        break;
      case 183: /* decl_flags ::= decl_flags ACTION states_opts */
#line 1162 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-2].minor.yy295 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-1].minor.yy0.SourceLoc);
		yylhsminor.yy295 = nil_f;
		yylhsminor.yy295->Flags = ZCC_Action;
		yylhsminor.yy295->Id = nullptr;
		yylhsminor.yy295->Version = { 0, 0 };
		yylhsminor.yy295->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy295 = yymsp[-2].minor.yy295;
		yylhsminor.yy295->Flags |= ZCC_Action;
	}
	yylhsminor.yy295->Id = yymsp[0].minor.yy165;
}
#line 4145 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-2].minor.yy295 = yylhsminor.yy295;
        break;
      case 184: /* opt_deprecation_message ::= */
#line 1180 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.String = nullptr; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4151 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 185: /* opt_deprecation_message ::= COMMA STRCONST */
{  yy_destructor(yypParser,50,&yymsp[-1].minor);
#line 1181 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4157 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 186: /* decl_flags ::= decl_flags DEPRECATED LPAREN STRCONST opt_deprecation_message RPAREN */
#line 1184 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	if (yymsp[-5].minor.yy295 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-4].minor.yy0.SourceLoc);
		yylhsminor.yy295 = nil_f;
		yylhsminor.yy295->Flags = ZCC_Deprecated;
		yylhsminor.yy295->Id = nullptr;
		yylhsminor.yy295->Version = { 0, 0 };
	}
	else
	{
		yylhsminor.yy295 = yymsp[-5].minor.yy295;
		yylhsminor.yy295->Flags |= ZCC_Deprecated;
	}
	yylhsminor.yy295->Version = yymsp[-2].minor.yy0.String->GetChars();
	yylhsminor.yy295->DeprecationMessage = yymsp[-1].minor.yy0.String;
}
#line 4179 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy295 = yylhsminor.yy295;
        break;
      case 187: /* decl_flags ::= decl_flags VERSION LPAREN STRCONST RPAREN */
#line 1203 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	if (yymsp[-4].minor.yy295 == nullptr)
	{
		NEW_AST_NODE(DeclFlags,nil_f,yymsp[-3].minor.yy0.SourceLoc);
		yylhsminor.yy295 = nil_f;
		yylhsminor.yy295->Flags = ZCC_Version;
		yylhsminor.yy295->Id = nullptr;
		yylhsminor.yy295->Version = { 0, 0 };
		yylhsminor.yy295->DeprecationMessage = nullptr;
	}
	else
	{
		yylhsminor.yy295 = yymsp[-4].minor.yy295;
		yylhsminor.yy295->Flags |= ZCC_Version;
	}
	yylhsminor.yy295->Version = yymsp[-1].minor.yy0.String->GetChars();
}
#line 4203 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-4].minor.yy295 = yylhsminor.yy295;
        break;
      case 188: /* decl_flag ::= NATIVE */
#line 1221 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Native; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4211 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 189: /* decl_flag ::= STATIC */
#line 1222 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Static; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4217 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 190: /* decl_flag ::= PRIVATE */
#line 1223 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Private; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4223 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 191: /* decl_flag ::= PROTECTED */
#line 1224 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Protected; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4229 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 192: /* decl_flag ::= LATENT */
#line 1225 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Latent; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4235 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 193: /* decl_flag ::= FINAL */
#line 1226 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Final; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4241 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 194: /* decl_flag ::= META */
#line 1227 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Meta; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4247 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 195: /* decl_flag ::= TRANSIENT */
#line 1228 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Transient; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4253 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 196: /* decl_flag ::= READONLY */
#line 1229 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ReadOnly; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4259 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 197: /* decl_flag ::= INTERNAL */
#line 1230 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Internal; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4265 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 198: /* decl_flag ::= VIRTUAL */
#line 1231 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Virtual; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4271 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 199: /* decl_flag ::= OVERRIDE */
#line 1232 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Override; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4277 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 200: /* decl_flag ::= ABSTRACT */
#line 1233 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Abstract; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4283 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 201: /* decl_flag ::= VARARG */
#line 1234 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VarArg; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4289 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 202: /* decl_flag ::= UI */
#line 1235 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_UIFlag; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4295 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 203: /* decl_flag ::= PLAY */
#line 1236 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_Play; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4301 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 204: /* decl_flag ::= CLEARSCOPE */
#line 1237 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_ClearScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4307 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 205: /* decl_flag ::= VIRTUALSCOPE */
#line 1238 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_VirtualScope; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4313 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 206: /* func_const ::= */
#line 1240 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = stat->sc->GetMessageLine(); }
#line 4319 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 207: /* func_const ::= CONST */
#line 1241 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = ZCC_FuncConst; yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc; }
#line 4324 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 208: /* opt_func_body ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 1243 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy55 = NULL; }
#line 4331 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 209: /* func_params ::= */
#line 1250 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy491 = NULL; }
#line 4337 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 210: /* func_params ::= VOID */
{  yy_destructor(yypParser,113,&yymsp[0].minor);
#line 1251 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy491 = NULL; }
#line 4343 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 211: /* func_params ::= func_param_list COMMA ELLIPSIS */
#line 1255 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,stat->sc->GetMessageLine());
	parm->Type = nullptr;
	parm->Name = NAME_None;
	parm->Flags = 0;
	parm->Default = nullptr;
	yymsp[-2].minor.yy491 = yymsp[-2].minor.yy491; /*X-overwrites-A*/ 
	AppendTreeNodeSibling(yymsp[-2].minor.yy491, parm);
}
#line 4357 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
  yy_destructor(yypParser,132,&yymsp[0].minor);
        break;
      case 212: /* func_param_list ::= func_param_list COMMA func_param */
#line 1266 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy491 = yymsp[-2].minor.yy491; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy491, yymsp[0].minor.yy491); }
#line 4364 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 213: /* func_param ::= func_param_flags type IDENTIFIER */
#line 1269 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-2].minor.yy0.SourceLoc ? yymsp[-2].minor.yy0.SourceLoc : yymsp[-1].minor.yy104->SourceLoc);
	parm->Type = yymsp[-1].minor.yy104;
	parm->Name = yymsp[0].minor.yy0.Name();
	parm->Flags = yymsp[-2].minor.yy0.Int;
	parm->Default = nullptr;
	yylhsminor.yy491 = parm;
}
#line 4377 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-2].minor.yy491 = yylhsminor.yy491;
        break;
      case 214: /* func_param ::= func_param_flags type IDENTIFIER EQ expr */
#line 1279 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParamDecl,parm,yymsp[-4].minor.yy0.SourceLoc ? yymsp[-4].minor.yy0.SourceLoc : yymsp[-3].minor.yy104->SourceLoc);
	parm->Type = yymsp[-3].minor.yy104;
	parm->Name = yymsp[-2].minor.yy0.Name();
	parm->Flags = yymsp[-4].minor.yy0.Int;
	parm->Default = yymsp[0].minor.yy318;
	yylhsminor.yy491 = parm;
}
#line 4390 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-4].minor.yy491 = yylhsminor.yy491;
        break;
      case 215: /* func_param_flags ::= */
#line 1288 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy0.Int = 0; yymsp[1].minor.yy0.SourceLoc = 0; }
#line 4397 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 216: /* func_param_flags ::= func_param_flags IN */
#line 1289 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_In; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4402 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 217: /* func_param_flags ::= func_param_flags OUT */
#line 1290 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Out; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4408 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 218: /* func_param_flags ::= func_param_flags OPTIONAL */
#line 1291 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yylhsminor.yy0.Int = yymsp[-1].minor.yy0.Int | ZCC_Optional; yylhsminor.yy0.SourceLoc =  yymsp[0].minor.yy0.SourceLoc; }
#line 4414 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy0 = yylhsminor.yy0;
        break;
      case 219: /* primary ::= IDENTIFIER */
#line 1307 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprID, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_ID;
	expr->Identifier = yymsp[0].minor.yy0.Name();
	expr->Type = NULL;
	yylhsminor.yy318 = expr;
}
#line 4426 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy318 = yylhsminor.yy318;
        break;
      case 220: /* primary ::= SUPER */
#line 1315 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(Expression, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_Super;
	expr->Type = NULL;
	yylhsminor.yy318 = expr;
}
#line 4437 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy318 = yylhsminor.yy318;
        break;
      case 221: /* primary ::= constant */
#line 1321 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy318 = yymsp[0].minor.yy471; /*X-overwrites-A*/ }
#line 4443 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 222: /* primary ::= LPAREN expr COMMA expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1323 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-7].minor.yy318);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector4;
	expr->X = yymsp[-7].minor.yy318;
	expr->Y = yymsp[-5].minor.yy318;
	expr->Z = yymsp[-3].minor.yy318;
	expr->W = yymsp[-1].minor.yy318;
	yymsp[-8].minor.yy318 = expr;
}
#line 4458 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-6].minor);
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 223: /* primary ::= LPAREN expr COMMA expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-6].minor);
#line 1334 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-5].minor.yy318);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector3;
	expr->X = yymsp[-5].minor.yy318;
	expr->Y = yymsp[-3].minor.yy318;
	expr->Z = yymsp[-1].minor.yy318;
	expr->W = nullptr;
	yymsp[-6].minor.yy318 = expr;
}
#line 4478 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-4].minor);
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 224: /* primary ::= LPAREN expr COMMA expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-4].minor);
#line 1345 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VectorValue, expr, yymsp[-3].minor.yy318);
	expr->Operation = PEX_Vector;
	expr->Type = TypeVector2;
	expr->X = yymsp[-3].minor.yy318;
	expr->Y = yymsp[-1].minor.yy318;
	expr->Z = nullptr;
	expr->W = nullptr;
	yymsp[-4].minor.yy318 = expr;
}
#line 4497 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 225: /* primary ::= LPAREN expr RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1356 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy318 = yymsp[-1].minor.yy318; /*yymsp[-2].minor.yy318-overwrites-yymsp[-1].minor.yy318*/
}
#line 4508 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 226: /* primary ::= primary LPAREN func_expr_list RPAREN */
#line 1361 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprFuncCall, expr, yymsp[-3].minor.yy318);
	expr->Operation = PEX_FuncCall;
	expr->Type = NULL;
	expr->Function = yymsp[-3].minor.yy318;
	expr->Parameters = yymsp[-1].minor.yy138;
	yylhsminor.yy318 = expr;
}
#line 4522 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-3].minor.yy318 = yylhsminor.yy318;
        break;
      case 227: /* primary ::= LPAREN CLASS LT IDENTIFIER GT RPAREN LPAREN func_expr_list RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-8].minor);
#line 1370 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ClassCast, expr, yymsp[-5].minor.yy0);
	expr->Operation = PEX_ClassCast;
	expr->ClassName = ENamedName(yymsp[-5].minor.yy0.Int);
	expr->Parameters = yymsp[-1].minor.yy138;
	yymsp[-8].minor.yy318 = expr;
}
#line 4537 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,53,&yymsp[-7].minor);
  yy_destructor(yypParser,20,&yymsp[-6].minor);
  yy_destructor(yypParser,21,&yymsp[-4].minor);
  yy_destructor(yypParser,62,&yymsp[-3].minor);
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      case 228: /* primary ::= primary LBRACKET expr RBRACKET */
#line 1378 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprBinary, expr, yymsp[-1].minor.yy318);
	expr->Operation = PEX_ArrayAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-3].minor.yy318;
	expr->Right = yymsp[-1].minor.yy318;
	yylhsminor.yy318 = expr;
}
#line 4556 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-2].minor);
  yy_destructor(yypParser,118,&yymsp[0].minor);
  yymsp[-3].minor.yy318 = yylhsminor.yy318;
        break;
      case 229: /* primary ::= primary DOT IDENTIFIER */
#line 1387 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprMemberAccess, expr, yymsp[0].minor.yy0);
	expr->Operation = PEX_MemberAccess;
	expr->Type = NULL;
	expr->Left = yymsp[-2].minor.yy318;
	expr->Right = ENamedName(yymsp[0].minor.yy0.Int);
	yylhsminor.yy318 = expr;
}
#line 4571 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,44,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 230: /* primary ::= primary ADDADD */
#line 1396 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy318,PEX_PostInc);
	yylhsminor.yy318 = expr1;
}
#line 4581 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,42,&yymsp[0].minor);
  yymsp[-1].minor.yy318 = yylhsminor.yy318;
        break;
      case 231: /* primary ::= primary SUBSUB */
#line 1401 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[-1].minor.yy318,PEX_PostDec);
	yylhsminor.yy318 = expr1;
}
#line 4591 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,43,&yymsp[0].minor);
  yymsp[-1].minor.yy318 = yylhsminor.yy318;
        break;
      case 232: /* unary_expr ::= SUB unary_expr */
{  yy_destructor(yypParser,33,&yymsp[-1].minor);
#line 1417 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy318);
	if (yymsp[0].minor.yy318->Operation == PEX_ConstValue && (con->Type->isInt() || con->Type->isFloat()))
	{ // For constants, manipulate the child node directly, and don't create a new node.
		if (con->Type->isInt())
		{
			con->IntVal = -con->IntVal;
		}
		else
		{
			con->DoubleVal = -con->DoubleVal;
		}
		yymsp[-1].minor.yy318 = yymsp[0].minor.yy318;
	}
	else
	{ // For everything else, create a new node and do the negation later.
		UNARY_EXPR(yymsp[0].minor.yy318,PEX_Negate);
		yymsp[-1].minor.yy318 = expr1;
	}
}
#line 4618 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 233: /* unary_expr ::= ADD unary_expr */
{  yy_destructor(yypParser,34,&yymsp[-1].minor);
#line 1438 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	// Even though this is really a no-op, we still need to make a node for
	// it so we can type check that it is being applied to something numeric.
	// But we can do that right now for constant numerals.
	ZCC_ExprConstant *con = static_cast<ZCC_ExprConstant *>(yymsp[0].minor.yy318);
	if (yymsp[0].minor.yy318->Operation != PEX_ConstValue || (!con->Type->isInt() && !con->Type->isFloat()))
	{
		UNARY_EXPR(yymsp[0].minor.yy318,PEX_AntiNegate);
		yymsp[-1].minor.yy318 = expr1;
	}
	else
	{
		yymsp[-1].minor.yy318 = yymsp[0].minor.yy318;
	}
}
#line 4639 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 234: /* unary_expr ::= SUBSUB unary_expr */
{  yy_destructor(yypParser,43,&yymsp[-1].minor);
#line 1454 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy318,PEX_PreDec);
	yymsp[-1].minor.yy318 = expr1;
}
#line 4649 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 235: /* unary_expr ::= ADDADD unary_expr */
{  yy_destructor(yypParser,42,&yymsp[-1].minor);
#line 1459 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy318,PEX_PreInc);
	yymsp[-1].minor.yy318 = expr1;
}
#line 4659 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 236: /* unary_expr ::= TILDE unary_expr */
{  yy_destructor(yypParser,136,&yymsp[-1].minor);
#line 1464 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy318,PEX_BitNot);
	yymsp[-1].minor.yy318 = expr1;
}
#line 4669 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 237: /* unary_expr ::= BANG unary_expr */
{  yy_destructor(yypParser,137,&yymsp[-1].minor);
#line 1469 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy318,PEX_BoolNot);
	yymsp[-1].minor.yy318 = expr1;
}
#line 4679 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 238: /* unary_expr ::= SIZEOF unary_expr */
{  yy_destructor(yypParser,138,&yymsp[-1].minor);
#line 1474 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy318,PEX_SizeOf);
	yymsp[-1].minor.yy318 = expr1;
}
#line 4689 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 239: /* unary_expr ::= ALIGNOF unary_expr */
{  yy_destructor(yypParser,139,&yymsp[-1].minor);
#line 1479 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	UNARY_EXPR(yymsp[0].minor.yy318,PEX_AlignOf);
	yymsp[-1].minor.yy318 = expr1;
}
#line 4699 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 240: /* expr ::= expr ADD expr */
#line 1492 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Add);
	yylhsminor.yy318 = expr2;
}
#line 4708 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,34,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 241: /* expr ::= expr SUB expr */
#line 1497 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Sub);
	yylhsminor.yy318 = expr2;
}
#line 4718 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,33,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 242: /* expr ::= expr MUL expr */
#line 1502 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Mul);
	yylhsminor.yy318 = expr2;
}
#line 4728 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,35,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 243: /* expr ::= expr DIV expr */
#line 1507 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Div);
	yylhsminor.yy318 = expr2;
}
#line 4738 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,36,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 244: /* expr ::= expr MOD expr */
#line 1512 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Mod);
	yylhsminor.yy318 = expr2;
}
#line 4748 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,37,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 245: /* expr ::= expr POW expr */
#line 1517 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Pow);
	yylhsminor.yy318 = expr2;
}
#line 4758 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,40,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 246: /* expr ::= expr CROSSPROD expr */
#line 1522 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_CrossProduct);
	yylhsminor.yy318 = expr2;
}
#line 4768 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,38,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 247: /* expr ::= expr DOTPROD expr */
#line 1527 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_DotProduct);
	yylhsminor.yy318 = expr2;
}
#line 4778 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,39,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 248: /* expr ::= expr LSH expr */
#line 1532 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_LeftShift);
	yylhsminor.yy318 = expr2;
}
#line 4788 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,30,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 249: /* expr ::= expr RSH expr */
#line 1537 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_RightShift);
	yylhsminor.yy318 = expr2;
}
#line 4798 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,31,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 250: /* expr ::= expr URSH expr */
#line 1542 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_URightShift);
	yylhsminor.yy318 = expr2;
}
#line 4808 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,32,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 251: /* expr ::= expr DOTDOT expr */
#line 1547 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Concat);
	yylhsminor.yy318 = expr2;
}
#line 4818 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,26,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 252: /* expr ::= expr LT expr */
#line 1553 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_LT);
	yylhsminor.yy318 = expr2;
}
#line 4828 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,20,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 253: /* expr ::= expr GT expr */
#line 1558 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_GT);
	yylhsminor.yy318 = expr2;
}
#line 4838 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,21,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 254: /* expr ::= expr LTEQ expr */
#line 1563 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_LTEQ);
	yylhsminor.yy318 = expr2;
}
#line 4848 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,22,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 255: /* expr ::= expr GTEQ expr */
#line 1568 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_GTEQ);
	yylhsminor.yy318 = expr2;
}
#line 4858 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,23,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 256: /* expr ::= expr LTGTEQ expr */
#line 1573 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_LTGTEQ);
	yylhsminor.yy318 = expr2;
}
#line 4868 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,24,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 257: /* expr ::= expr IS expr */
#line 1578 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Is);
	yylhsminor.yy318 = expr2;
}
#line 4878 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,25,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 258: /* expr ::= expr EQEQ expr */
#line 1584 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_EQEQ);
	yylhsminor.yy318 = expr2;
}
#line 4888 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,17,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 259: /* expr ::= expr NEQ expr */
#line 1589 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_NEQ);
	yylhsminor.yy318 = expr2;
}
#line 4898 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,18,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 260: /* expr ::= expr APPROXEQ expr */
#line 1594 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_APREQ);
	yylhsminor.yy318 = expr2;
}
#line 4908 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,19,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 261: /* expr ::= expr AND expr */
#line 1600 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_BitAnd);
	yylhsminor.yy318 = expr2;
}
#line 4918 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,29,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 262: /* expr ::= expr XOR expr */
#line 1605 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_BitXor);
	yylhsminor.yy318 = expr2;
}
#line 4928 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,28,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 263: /* expr ::= expr OR expr */
#line 1610 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_BitOr);
	yylhsminor.yy318 = expr2;
}
#line 4938 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,27,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 264: /* expr ::= expr ANDAND expr */
#line 1615 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_BoolAnd);
	yylhsminor.yy318 = expr2;
}
#line 4948 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,16,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 265: /* expr ::= expr OROR expr */
#line 1620 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_BoolOr);
	yylhsminor.yy318 = expr2;
}
#line 4958 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,15,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 266: /* expr ::= expr EQ expr */
#line 1625 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Assign);
	yylhsminor.yy318 = expr2;
}
#line 4968 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 267: /* expr ::= expr ADDEQ expr */
#line 1630 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_AddAssign);
	yylhsminor.yy318 = expr2;
}
#line 4978 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,5,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 268: /* expr ::= expr SUBEQ expr */
#line 1635 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_SubAssign);
	yylhsminor.yy318 = expr2;
}
#line 4988 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,6,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 269: /* expr ::= expr MULEQ expr */
#line 1640 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_MulAssign);
	yylhsminor.yy318 = expr2;
}
#line 4998 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,2,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 270: /* expr ::= expr DIVEQ expr */
#line 1645 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_DivAssign);
	yylhsminor.yy318 = expr2;
}
#line 5008 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,3,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 271: /* expr ::= expr MODEQ expr */
#line 1650 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_ModAssign);
	yylhsminor.yy318 = expr2;
}
#line 5018 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,4,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 272: /* expr ::= expr LSHEQ expr */
#line 1655 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_LshAssign);
	yylhsminor.yy318 = expr2;
}
#line 5028 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,7,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 273: /* expr ::= expr RSHEQ expr */
#line 1660 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_RshAssign);
	yylhsminor.yy318 = expr2;
}
#line 5038 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,8,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 274: /* expr ::= expr URSHEQ expr */
#line 1665 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_URshAssign);
	yylhsminor.yy318 = expr2;
}
#line 5048 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,12,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 275: /* expr ::= expr ANDEQ expr */
#line 1670 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_AndAssign);
	yylhsminor.yy318 = expr2;
}
#line 5058 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,9,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 276: /* expr ::= expr OREQ expr */
#line 1675 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_OrAssign);
	yylhsminor.yy318 = expr2;
}
#line 5068 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,10,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 277: /* expr ::= expr XOREQ expr */
#line 1680 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_XorAssign);
	yylhsminor.yy318 = expr2;
}
#line 5078 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,11,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 278: /* expr ::= expr SCOPE expr */
#line 1687 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	BINARY_EXPR(yymsp[-2].minor.yy318,yymsp[0].minor.yy318,PEX_Scope);
	yylhsminor.yy318 = expr2;
}
#line 5088 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,47,&yymsp[-1].minor);
  yymsp[-2].minor.yy318 = yylhsminor.yy318;
        break;
      case 279: /* expr ::= expr QUESTION expr COLON expr */
#line 1695 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprTrinary, expr, yymsp[-4].minor.yy318);
	expr->Operation = PEX_Trinary;
	expr->Type = NULL;
	expr->Test = yymsp[-4].minor.yy318;
	expr->Left = yymsp[-2].minor.yy318;
	expr->Right = yymsp[0].minor.yy318;
	yylhsminor.yy318 = expr;
}
#line 5103 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,13,&yymsp[-3].minor);
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-4].minor.yy318 = yylhsminor.yy318;
        break;
      case 280: /* expr_list ::= expr_list COMMA expr */
#line 1711 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy318 = yymsp[-2].minor.yy318;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy318, yymsp[0].minor.yy318);
}
#line 5114 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 281: /* func_expr_list ::= func_expr_list COMMA func_expr_item */
#line 1727 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	// Omitted parameters still need to appear as nodes in the list.
	if (yymsp[-2].minor.yy138 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_a,yymsp[-1].minor.yy0);
		nil_a->Value = NULL;
		nil_a->Label = NAME_None;
		yymsp[-2].minor.yy138 = nil_a;
	}
	if (yymsp[0].minor.yy138 == NULL)
	{
		NEW_AST_NODE(FuncParm,nil_b,yymsp[-1].minor.yy0);
		nil_b->Value = NULL;
		nil_b->Label = NAME_None;
		yymsp[0].minor.yy138 = nil_b;
	}
	yymsp[-2].minor.yy138 = yymsp[-2].minor.yy138;	/*X-overwrites-A*/
	AppendTreeNodeSibling(yymsp[-2].minor.yy138, yymsp[0].minor.yy138);
}
#line 5138 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 282: /* func_expr_item ::= */
#line 1748 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[1].minor.yy138 = NULL;
}
#line 5145 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 283: /* named_expr ::= IDENTIFIER COLON expr */
#line 1754 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[-2].minor.yy0);
	parm->Value = yymsp[0].minor.yy318;
	parm->Label = ENamedName(yymsp[-2].minor.yy0.Int);
	yylhsminor.yy138 = parm;
}
#line 5155 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[-1].minor);
  yymsp[-2].minor.yy138 = yylhsminor.yy138;
        break;
      case 284: /* named_expr ::= expr */
#line 1761 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(FuncParm, parm, yymsp[0].minor.yy318);
	parm->Value = yymsp[0].minor.yy318;
	parm->Label = NAME_None;
	yylhsminor.yy138 = parm;
}
#line 5167 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy138 = yylhsminor.yy138;
        break;
      case 286: /* string_constant ::= string_constant STRCONST */
#line 1782 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, strconst, yymsp[-1].minor.yy471);
	strconst->Operation = PEX_ConstValue;
	strconst->Type = TypeString;
	strconst->StringVal = stat->Strings.Alloc(*(yymsp[-1].minor.yy471->StringVal) + *(yymsp[0].minor.yy0.String));
	yylhsminor.yy471 = strconst;
}
#line 5179 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy471 = yylhsminor.yy471;
        break;
      case 287: /* constant ::= INTCONST */
#line 1792 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeSInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy471 = intconst;
}
#line 5188 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 288: /* constant ::= UINTCONST */
#line 1797 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(intconst, TypeUInt32, yymsp[0].minor.yy0.Int, yymsp[0].minor.yy0);
	yylhsminor.yy471 = intconst;
}
#line 5197 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 289: /* constant ::= FLOATCONST */
#line 1802 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeFloat64;
	floatconst->DoubleVal = yymsp[0].minor.yy0.Float;
	yylhsminor.yy471 = floatconst;
}
#line 5209 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 290: /* constant ::= NAMECONST */
#line 1810 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, floatconst, yymsp[0].minor.yy0);
	floatconst->Operation = PEX_ConstValue;
	floatconst->Type = TypeName;
	floatconst->IntVal = yymsp[0].minor.yy0.Int;
	yylhsminor.yy471 = floatconst;
}
#line 5221 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 291: /* constant ::= FALSE */
#line 1818 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, false, yymsp[0].minor.yy0);
	yylhsminor.yy471 = boolconst;
}
#line 5230 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 292: /* constant ::= TRUE */
#line 1823 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_INTCONST_NODE(boolconst, TypeBool, true, yymsp[0].minor.yy0);
	yylhsminor.yy471 = boolconst;
}
#line 5239 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 293: /* constant ::= NULLPTR */
#line 1828 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExprConstant, nullptrconst, yymsp[0].minor.yy0);
	nullptrconst->Operation = PEX_ConstValue;
	nullptrconst->Type = TypeNullPtr;
	nullptrconst->StringVal = nullptr;
	yylhsminor.yy471 = nullptrconst;
}
#line 5251 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy471 = yylhsminor.yy471;
        break;
      case 295: /* statement ::= labeled_statement */
#line 1842 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy442; /*X-overwrites-A*/ }
#line 5257 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 296: /* statement ::= compound_statement */
#line 1843 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy55; /*X-overwrites-A*/ }
#line 5262 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 297: /* statement ::= expression_statement SEMICOLON */
#line 1844 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy156 = yymsp[-1].minor.yy302; /*X-overwrites-A*/ }
#line 5267 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 298: /* statement ::= assign_statement SEMICOLON */
#line 1849 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy156 = yymsp[-1].minor.yy271; /*X-overwrites-A*/ }
#line 5273 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 299: /* statement ::= assign_decl_statement SEMICOLON */
#line 1850 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy156 = yymsp[-1].minor.yy251; /*X-overwrites-A*/ }
#line 5279 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 300: /* statement ::= local_var SEMICOLON */
#line 1851 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-1].minor.yy156 = yymsp[-1].minor.yy66; /*X-overwrites-A*/ }
#line 5285 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 302: /* statement ::= staticarray_statement */
#line 1853 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy106; /*X-overwrites-A*/ }
#line 5291 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 303: /* staticarray_statement ::= STATICCONST type IDENTIFIER LBRACKET RBRACKET EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,146,&yymsp[-9].minor);
#line 1860 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy104);
	stmt->Type = yymsp[-8].minor.yy104;
	stmt->Id = ENamedName(yymsp[-7].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy318;
	yymsp[-9].minor.yy106 = stmt;
}
#line 5303 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-6].minor);
  yy_destructor(yypParser,118,&yymsp[-5].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,66,&yymsp[-3].minor);
  yy_destructor(yypParser,67,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 304: /* staticarray_statement ::= STATICCONST type LBRACKET RBRACKET IDENTIFIER EQ LBRACE expr_list RBRACE SEMICOLON */
{  yy_destructor(yypParser,146,&yymsp[-9].minor);
#line 1869 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(StaticArrayStatement, stmt, yymsp[-8].minor.yy104);
	stmt->Type = yymsp[-8].minor.yy104;
	stmt->Id = ENamedName(yymsp[-5].minor.yy0.Int);
	stmt->Values = yymsp[-2].minor.yy318;
	yymsp[-9].minor.yy106 = stmt;
}
#line 5322 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-7].minor);
  yy_destructor(yypParser,118,&yymsp[-6].minor);
  yy_destructor(yypParser,1,&yymsp[-4].minor);
  yy_destructor(yypParser,66,&yymsp[-3].minor);
  yy_destructor(yypParser,67,&yymsp[-1].minor);
  yy_destructor(yypParser,49,&yymsp[0].minor);
}
        break;
      case 305: /* jump_statement ::= CONTINUE SEMICOLON */
#line 1882 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ContinueStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy156 = stmt;
}
#line 5337 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy156 = yylhsminor.yy156;
        break;
      case 306: /* jump_statement ::= BREAK SEMICOLON */
#line 1887 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(BreakStmt, stmt, yymsp[-1].minor.yy0);
	yylhsminor.yy156 = stmt;
}
#line 5347 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy156 = yylhsminor.yy156;
        break;
      case 307: /* jump_statement ::= RETURN SEMICOLON */
#line 1892 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-1].minor.yy0);
	stmt->Values = NULL;
	yylhsminor.yy156 = stmt;
}
#line 5358 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-1].minor.yy156 = yylhsminor.yy156;
        break;
      case 308: /* jump_statement ::= RETURN expr_list SEMICOLON */
#line 1898 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ReturnStmt, stmt, yymsp[-2].minor.yy0);
	stmt->Values = yymsp[-1].minor.yy318;
	yylhsminor.yy156 = stmt;
}
#line 5369 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
  yymsp[-2].minor.yy156 = yylhsminor.yy156;
        break;
      case 309: /* compound_statement ::= LBRACE RBRACE */
#line 1910 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy55 = stmt;
}
#line 5380 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-1].minor.yy55 = yylhsminor.yy55;
        break;
      case 310: /* compound_statement ::= LBRACE statement_list RBRACE */
#line 1916 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = yymsp[-1].minor.yy156;
	yylhsminor.yy55 = stmt;
}
#line 5391 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-2].minor.yy55 = yylhsminor.yy55;
        break;
      case 311: /* compound_statement ::= LBRACE error RBRACE */
#line 1922 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CompoundStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Content = NULL;
	yylhsminor.yy55 = stmt;
}
#line 5402 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-2].minor.yy55 = yylhsminor.yy55;
        break;
      case 314: /* expression_statement ::= expr */
#line 1942 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ExpressionStmt, stmt, yymsp[0].minor.yy318);
	stmt->Expression = yymsp[0].minor.yy318;
	yylhsminor.yy302 = stmt;
}
#line 5413 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy302 = yylhsminor.yy302;
        break;
      case 315: /* iteration_statement ::= while_or_until LPAREN expr RPAREN statement */
#line 1954 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-4].minor.yy0);
	if (yymsp[-4].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-2].minor.yy318,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-2].minor.yy318;
	}
	iter->LoopStatement = yymsp[0].minor.yy156;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::Start;
	yylhsminor.yy156 = iter;
}
#line 5434 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy156 = yylhsminor.yy156;
        break;
      case 316: /* iteration_statement ::= DO statement while_or_until LPAREN expr RPAREN */
#line 1972 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-5].minor.yy0);
	if (yymsp[-3].minor.yy0.Int == ZCC_UNTIL)
	{ // Negate the loop condition
		UNARY_EXPR(yymsp[-1].minor.yy318,PEX_BoolNot);
		iter->LoopCondition = expr1;
	}
	else
	{
		iter->LoopCondition = yymsp[-1].minor.yy318;
	}
	iter->LoopStatement = yymsp[-4].minor.yy156;
	iter->LoopBumper = NULL;
	iter->CheckAt = ZCC_IterationStmt::End;
	yylhsminor.yy156 = iter;
}
#line 5457 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-2].minor);
  yy_destructor(yypParser,62,&yymsp[0].minor);
  yymsp[-5].minor.yy156 = yylhsminor.yy156;
        break;
      case 317: /* iteration_statement ::= FOR LPAREN for_init SEMICOLON opt_expr SEMICOLON for_bump RPAREN statement */
#line 1990 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IterationStmt, iter, yymsp[-8].minor.yy0);
	iter->LoopCondition = yymsp[-4].minor.yy318;
	iter->LoopStatement = yymsp[0].minor.yy156;
	iter->LoopBumper = yymsp[-2].minor.yy156;
	iter->CheckAt = ZCC_IterationStmt::Start;
	// The initialization expression appears outside the loop
	// for_init may be NULL if there is no initialization.
	SAFE_APPEND(yymsp[-6].minor.yy156, iter);
	// And the whole thing gets wrapped inside a compound statement in case the loop
	// initializer defined any variables.
	NEW_AST_NODE(CompoundStmt, wrap, yymsp[-8].minor.yy0);
	wrap->Content = yymsp[-6].minor.yy156;
	yylhsminor.yy156 = wrap;
}
#line 5479 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-7].minor);
  yy_destructor(yypParser,49,&yymsp[-5].minor);
  yy_destructor(yypParser,49,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-8].minor.yy156 = yylhsminor.yy156;
        break;
      case 318: /* array_iteration_statement ::= FOREACH LPAREN variable_name COLON expr RPAREN statement */
#line 2009 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(ArrayIterationStmt, iter, yymsp[-6].minor.yy0);
	iter->ItName = yymsp[-4].minor.yy180;
	iter->ItArray = yymsp[-2].minor.yy318;
	iter->LoopStatement = yymsp[0].minor.yy156;
	yylhsminor.yy156 = iter;
}
#line 5495 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-5].minor);
  yy_destructor(yypParser,14,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-6].minor.yy156 = yylhsminor.yy156;
        break;
      case 319: /* while_or_until ::= WHILE */
#line 2018 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_WHILE;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5507 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 320: /* while_or_until ::= UNTIL */
#line 2023 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yylhsminor.yy0.Int = ZCC_UNTIL;
	yylhsminor.yy0.SourceLoc = yymsp[0].minor.yy0.SourceLoc;
}
#line 5516 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 321: /* for_init ::= local_var */
#line 2029 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy66 /*X-overwrites-A*/; }
#line 5522 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 322: /* for_init ::= for_bump */
#line 2030 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy156 /*X-overwrites-A*/; }
#line 5527 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 323: /* for_bump ::= */
#line 2033 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[1].minor.yy156 = NULL; }
#line 5532 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 324: /* for_bump ::= expression_statement */
#line 2034 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[0].minor.yy156 = yymsp[0].minor.yy302; /*X-overwrites-A*/ }
#line 5537 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 325: /* for_bump ::= for_bump COMMA expression_statement */
#line 2035 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ yymsp[-2].minor.yy156 = yymsp[-2].minor.yy156; /*X-overwrites-A*/ AppendTreeNodeSibling(yymsp[-2].minor.yy156, yymsp[0].minor.yy302); }
#line 5542 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 326: /* selection_statement ::= if_front */
#line 2049 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[0].minor.yy156 = yymsp[0].minor.yy481; /*X-overwrites-A*/
}
#line 5550 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
        break;
      case 327: /* selection_statement ::= if_front ELSE statement */
#line 2053 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	yymsp[-2].minor.yy481->FalsePath = yymsp[0].minor.yy156;
	yymsp[-2].minor.yy156 = yymsp[-2].minor.yy481; /*X-overwrites-A*/
}
#line 5558 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,156,&yymsp[-1].minor);
        break;
      case 328: /* if_front ::= IF LPAREN expr RPAREN statement */
#line 2059 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(IfStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy318;
	stmt->TruePath = yymsp[0].minor.yy156;
	stmt->FalsePath = NULL;
	yylhsminor.yy481 = stmt;
}
#line 5570 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy481 = yylhsminor.yy481;
        break;
      case 329: /* selection_statement ::= SWITCH LPAREN expr RPAREN statement */
#line 2070 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(SwitchStmt,stmt,yymsp[-4].minor.yy0);
	stmt->Condition = yymsp[-2].minor.yy318;
	stmt->Content = yymsp[0].minor.yy156;
	yylhsminor.yy156 = stmt;
}
#line 5583 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,45,&yymsp[-3].minor);
  yy_destructor(yypParser,62,&yymsp[-1].minor);
  yymsp[-4].minor.yy156 = yylhsminor.yy156;
        break;
      case 330: /* labeled_statement ::= CASE expr COLON */
#line 2082 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-2].minor.yy0);
	stmt->Condition = yymsp[-1].minor.yy318;
	yylhsminor.yy442 = stmt;
}
#line 5595 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-2].minor.yy442 = yylhsminor.yy442;
        break;
      case 331: /* labeled_statement ::= DEFAULT COLON */
#line 2088 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(CaseStmt,stmt,yymsp[-1].minor.yy0);
	stmt->Condition = NULL;
	yylhsminor.yy442 = stmt;
}
#line 5606 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,14,&yymsp[0].minor);
  yymsp[-1].minor.yy442 = yylhsminor.yy442;
        break;
      case 332: /* assign_statement ::= LBRACKET expr_list RBRACKET EQ expr */
{  yy_destructor(yypParser,46,&yymsp[-4].minor);
#line 2101 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignStmt,stmt,yymsp[-3].minor.yy318);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy318;
	stmt->Sources = yymsp[0].minor.yy318;
	yymsp[-4].minor.yy271 = stmt;
}
#line 5620 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,118,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 333: /* assign_decl_statement ::= LET LBRACKET identifier_list RBRACKET EQ expr */
{  yy_destructor(yypParser,106,&yymsp[-5].minor);
#line 2112 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(AssignDeclStmt,stmt,yymsp[-3].minor.yy165);
	stmt->AssignOp = ZCC_EQ;
	stmt->Dests = yymsp[-3].minor.yy165;
	stmt->Sources = yymsp[0].minor.yy318;
	yymsp[-5].minor.yy251 = stmt;
}
#line 5635 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,46,&yymsp[-4].minor);
  yy_destructor(yypParser,118,&yymsp[-2].minor);
  yy_destructor(yypParser,1,&yymsp[-1].minor);
}
        break;
      case 334: /* local_var ::= type variable_list_with_init */
#line 2125 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(LocalVarStmt,vardef,yymsp[-1].minor.yy104);
	vardef->Type = yymsp[-1].minor.yy104;
	vardef->Vars = yymsp[0].minor.yy275;
	yylhsminor.yy66 = vardef;
}
#line 5649 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy66 = yylhsminor.yy66;
        break;
      case 335: /* var_init ::= IDENTIFIER */
#line 2134 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[0].minor.yy0);
	var->Name = ENamedName(yymsp[0].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy275 = var;
}
#line 5662 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[0].minor.yy275 = yylhsminor.yy275;
        break;
      case 336: /* var_init ::= IDENTIFIER array_size */
#line 2144 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	NEW_AST_NODE(VarInit,var,yymsp[-1].minor.yy0);
	var->Name = ENamedName(yymsp[-1].minor.yy0.Int);
	var->ArraySize = yymsp[0].minor.yy318;
	var->Init = NULL;
	var->InitIsArray = false;
	yylhsminor.yy275 = var;
}
#line 5675 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yymsp[-1].minor.yy275 = yylhsminor.yy275;
        break;
      case 337: /* var_init ::= IDENTIFIER EQ expr */
#line 2154 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-2].minor.yy0);
	var->Name = ENamedName(yymsp[-2].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[0].minor.yy318;
	var->InitIsArray = false;
	yylhsminor.yy275 = var;
}
#line 5688 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-1].minor);
  yymsp[-2].minor.yy275 = yylhsminor.yy275;
        break;
      case 338: /* var_init ::= IDENTIFIER EQ LBRACE expr_list RBRACE */
#line 2164 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-4].minor.yy0);
	var->Name = ENamedName(yymsp[-4].minor.yy0.Int);
	var->ArraySize = NULL;
	var->Init = yymsp[-1].minor.yy318;
	var->InitIsArray = true;
	yylhsminor.yy275 = var;
}
#line 5702 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-2].minor);
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-4].minor.yy275 = yylhsminor.yy275;
        break;
      case 339: /* var_init ::= IDENTIFIER array_size EQ LBRACE expr_list RBRACE */
#line 2174 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	NEW_AST_NODE(VarInit,var,yymsp[-5].minor.yy0);
	var->Name = ENamedName(yymsp[-5].minor.yy0.Int);
	var->ArraySize = yymsp[-4].minor.yy318;
	var->Init = yymsp[-1].minor.yy318;
	var->InitIsArray = true;
	yylhsminor.yy275 = var;
}
#line 5718 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-2].minor);
  yy_destructor(yypParser,67,&yymsp[0].minor);
  yymsp[-5].minor.yy275 = yylhsminor.yy275;
        break;
      case 340: /* var_init ::= IDENTIFIER EQ LBRACE error RBRACE */
{  yy_destructor(yypParser,54,&yymsp[-4].minor);
#line 2184 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{ 
	yymsp[-4].minor.yy275 = NULL;
}
#line 5730 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,1,&yymsp[-3].minor);
  yy_destructor(yypParser,66,&yymsp[-2].minor);
  yy_destructor(yypParser,67,&yymsp[0].minor);
}
        break;
      case 341: /* variable_list_with_init ::= variable_list_with_init COMMA var_init */
#line 2192 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
	AppendTreeNodeSibling(yymsp[-2].minor.yy275, yymsp[0].minor.yy275);
	yymsp[-2].minor.yy275 = yymsp[-2].minor.yy275; /*X-overwrites-A*/
}
#line 5742 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,50,&yymsp[-1].minor);
        break;
      case 342: /* translation_unit ::= translation_unit EOF */
#line 178 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5749 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,48,&yymsp[0].minor);
        break;
      case 344: /* opt_semicolon ::= SEMICOLON */
{  yy_destructor(yypParser,49,&yymsp[0].minor);
#line 191 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5757 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 346: /* opt_comma ::= COMMA */
{  yy_destructor(yypParser,50,&yymsp[0].minor);
#line 194 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5765 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
}
        break;
      case 352: /* state_flow ::= state_flow_type scanner_mode SEMICOLON */
#line 657 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5772 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,49,&yymsp[0].minor);
        break;
      case 362: /* primary ::= LPAREN error RPAREN */
{  yy_destructor(yypParser,45,&yymsp[-2].minor);
#line 1359 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
{
}
#line 5780 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
  yy_destructor(yypParser,62,&yymsp[0].minor);
}
        break;
      default:
      /* (343) opt_semicolon ::= */ yytestcase(yyruleno==343);
      /* (345) opt_comma ::= */ yytestcase(yyruleno==345);
      /* (347) opt_expr ::= expr */ yytestcase(yyruleno==347);
      /* (348) opt_struct_body ::= struct_body */ yytestcase(yyruleno==348);
      /* (349) struct_body ::= struct_member */ yytestcase(yyruleno==349);
      /* (350) enum_list ::= enumerator */ yytestcase(yyruleno==350);
      /* (351) opt_enum_list ::= enum_list opt_comma */ yytestcase(yyruleno==351);
      /* (353) type_name1 ::= int_type */ yytestcase(yyruleno==353);
      /* (354) type_or_array ::= type */ yytestcase(yyruleno==354);
      /* (355) type_list ::= type_or_array */ yytestcase(yyruleno==355);
      /* (356) type_list_or_void ::= type_list */ yytestcase(yyruleno==356);
      /* (357) array_size ::= array_size_expr */ yytestcase(yyruleno==357);
      /* (358) variable_list ::= variable_name */ yytestcase(yyruleno==358);
      /* (359) opt_func_body ::= function_body */ yytestcase(yyruleno==359);
      /* (360) func_params ::= func_param_list */ yytestcase(yyruleno==360);
      /* (361) func_param_list ::= func_param */ yytestcase(yyruleno==361);
      /* (363) unary_expr ::= primary */ yytestcase(yyruleno==363);
      /* (364) expr ::= unary_expr */ yytestcase(yyruleno==364);
      /* (365) expr_list ::= expr */ yytestcase(yyruleno==365);
      /* (366) func_expr_list ::= func_expr_item */ yytestcase(yyruleno==366);
      /* (367) func_expr_item ::= named_expr */ yytestcase(yyruleno==367);
      /* (368) constant ::= string_constant */ yytestcase(yyruleno==368);
      /* (369) function_body ::= compound_statement */ yytestcase(yyruleno==369);
      /* (370) statement ::= selection_statement */ yytestcase(yyruleno==370);
      /* (371) statement ::= iteration_statement */ yytestcase(yyruleno==371);
      /* (372) statement ::= array_iteration_statement */ yytestcase(yyruleno==372);
      /* (373) statement ::= jump_statement */ yytestcase(yyruleno==373);
      /* (374) variable_list_with_init ::= var_init */ yytestcase(yyruleno==374);
       break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
#line 148 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
 /**failed = true;*/ 
#line 5856 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
/************ End %parse_failure code *****************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  ZCCParseTOKENTYPE yyminor         /* The minor type of the error token */
){
  ZCCParseARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 121 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"

	FString unexpected, expecting;

	int i;
	int stateno = yypParser->yytos->stateno;

	unexpected << "Unexpected " << ZCCTokenName(yymajor);

	// Determine all the terminals that the parser would have accepted at this point
	// (see yy_find_shift_action). This list can get quite long. Is it worthwhile to
	// print it when not debugging the grammar, or would that be too confusing to
	// the average user?
	if (stateno < YY_SHIFT_MAX && (i = yy_shift_ofst[stateno])!=YY_SHIFT_USE_DFLT)
	{
		for (int j = 1; j < YYERRORSYMBOL; ++j)
		{
			int k = i + j;
			if (k >= 0 && k < YY_ACTTAB_COUNT && yy_lookahead[k] == j)
			{
				expecting << (expecting.IsEmpty() ? "Expecting " : " or ") << ZCCTokenName(j);
			}
		}
	}
	stat->sc->ScriptMessage("%s\n%s\n", unexpected.GetChars(), expecting.GetChars());
	FScriptPosition::ErrorCounter++;
#line 5899 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
/************ End %syntax_error code ******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  ZCCParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
    fflush(yyTraceFILE);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
#if 0
  assert( yypParser->yytos==yypParser->yystack );
#else
  while (yypParser->yytos>yypParser->yystack) yy_pop_parser_stack(yypParser);
#endif
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
#line 147 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/src/common/scripting/frontend/zcc-parse.lemon"
 DPrintf(DMSG_SPAMMY, "Input accepted\n"); 
#line 5930 "/home/iurt/rpmbuild/BUILD/gzdoom-g4.11.3/build/src/zcc-parse.c"
/*********** End %parse_accept code *******************************************/
  ZCCParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "ZCCParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void ZCCParse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  ZCCParseTOKENTYPE yyminor       /* The value for the token */
  ZCCParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  ZCCParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
    fflush(yyTraceFILE);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
        fflush(yyTraceFILE);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
          fflush(yyTraceFILE);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack );
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
    fflush(yyTraceFILE);
  }
#endif
  return;
}
